@@ -25,8 +25,8 @@
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/lang/IndexOutOfBoundsException.hpp>
+#include <comphelper/accessiblecontexthelper.hxx>
 #include <cppuhelper/supportsservice.hxx>
-#include <unotools/accessiblestatesethelper.hxx>
 
 
 namespace accessibility
@@ -45,7 +45,7 @@ namespace accessibility
 
     AccessibleListBox::AccessibleListBox( SvTreeListBox const & _rListBox, const Reference< XAccessible >& _xParent ) :
 
-        VCLXAccessibleComponent( _rListBox.GetWindowPeer() ),
+        ImplInheritanceHelper( _rListBox.GetWindowPeer() ),
         m_xParent( _xParent )
     {
     }
@@ -59,8 +59,6 @@ namespace accessibility
             dispose();
         }
     }
-    IMPLEMENT_FORWARD_XINTERFACE2(AccessibleListBox, VCLXAccessibleComponent, ImplHelper2)
-    IMPLEMENT_FORWARD_XTYPEPROVIDER2(AccessibleListBox, VCLXAccessibleComponent, ImplHelper2)
 
     void AccessibleListBox::ProcessWindowEvent( const VclWindowEvent& rVclWindowEvent )
     {
@@ -301,7 +299,7 @@ namespace accessibility
 
     // XAccessibleContext
 
-    sal_Int32 SAL_CALL AccessibleListBox::getAccessibleChildCount(  )
+    sal_Int64 SAL_CALL AccessibleListBox::getAccessibleChildCount(  )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
@@ -313,7 +311,7 @@ namespace accessibility
         return nCount;
     }
 
-    Reference< XAccessible > SAL_CALL AccessibleListBox::getAccessibleChild( sal_Int32 i )
+    Reference< XAccessible > SAL_CALL AccessibleListBox::getAccessibleChild( sal_Int64 i )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
@@ -395,7 +393,7 @@ namespace accessibility
 
     // XAccessibleSelection
 
-    void SAL_CALL AccessibleListBox::selectAccessibleChild( sal_Int32 nChildIndex )
+    void SAL_CALL AccessibleListBox::selectAccessibleChild( sal_Int64 nChildIndex )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
@@ -406,10 +404,13 @@ namespace accessibility
         getListBox()->Select( pEntry );
     }
 
-    sal_Bool SAL_CALL AccessibleListBox::isAccessibleChildSelected( sal_Int32 nChildIndex )
+    sal_Bool SAL_CALL AccessibleListBox::isAccessibleChildSelected( sal_Int64 nChildIndex )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
+        if (nChildIndex < 0 || nChildIndex >= getAccessibleChildCount())
+            throw IndexOutOfBoundsException();
+
         SvTreeListEntry* pEntry = getListBox()->GetEntry( nChildIndex );
         if ( !pEntry )
             throw IndexOutOfBoundsException();
@@ -443,14 +444,14 @@ namespace accessibility
         }
     }
 
-    sal_Int32 SAL_CALL AccessibleListBox::getSelectedAccessibleChildCount(  )
+    sal_Int64 SAL_CALL AccessibleListBox::getSelectedAccessibleChildCount(  )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
         return getListBox()->GetSelectionCount();
     }
 
-    Reference< XAccessible > SAL_CALL AccessibleListBox::getSelectedAccessibleChild( sal_Int32 nSelectedChildIndex )
+    Reference< XAccessible > SAL_CALL AccessibleListBox::getSelectedAccessibleChild( sal_Int64 nSelectedChildIndex )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
@@ -458,7 +459,7 @@ namespace accessibility
             throw IndexOutOfBoundsException();
 
         Reference< XAccessible > xChild;
-        sal_Int32 nSelCount= 0;
+        sal_Int64 nSelCount= 0;
         sal_Int32 nCount = getListBox()->GetLevelChildCount( nullptr );
         for ( sal_Int32 i = 0; i < nCount; ++i )
         {
@@ -479,7 +480,7 @@ namespace accessibility
         return xChild;
     }
 
-    void SAL_CALL AccessibleListBox::deselectAccessibleChild( sal_Int32 nSelectedChildIndex )
+    void SAL_CALL AccessibleListBox::deselectAccessibleChild( sal_Int64 nSelectedChildIndex )
     {
         ::comphelper::OExternalLockGuard aGuard( this );
 
@@ -490,15 +491,15 @@ namespace accessibility
         getListBox()->Select( pEntry, false );
     }
 
-    void AccessibleListBox::FillAccessibleStateSet( utl::AccessibleStateSetHelper& rStateSet )
+    void AccessibleListBox::FillAccessibleStateSet( sal_Int64& rStateSet )
     {
         VCLXAccessibleComponent::FillAccessibleStateSet( rStateSet );
         if ( getListBox() && isAlive() )
         {
-            rStateSet.AddState( AccessibleStateType::FOCUSABLE );
-            rStateSet.AddState( AccessibleStateType::MANAGES_DESCENDANTS );
+            rStateSet |= AccessibleStateType::FOCUSABLE;
+            rStateSet |= AccessibleStateType::MANAGES_DESCENDANTS;
             if ( getListBox()->GetSelectionMode() == SelectionMode::Multiple )
-                rStateSet.AddState( AccessibleStateType::MULTI_SELECTABLE );
+                rStateSet |= AccessibleStateType::MULTI_SELECTABLE;
         }
     }
 
