@@ -176,15 +176,13 @@ com_sun_star_comp_rendering_Canvas_Cairo_get_implementation(
     css::uno::XComponentContext* context, css::uno::Sequence<css::uno::Any> const& args)
 {
     rtl::Reference<cairocanvas::Canvas> p = new cairocanvas::Canvas(args, context);
-    p->acquire();
     try {
         p->initialize();
     } catch (css::uno::Exception&) {
         p->dispose();
-        p->release();
         throw;
     }
-    return static_cast<cppu::OWeakObject*>(p.get());
+    return cppu::acquire(p.get());
 }
 
 
