@@ -60,7 +60,7 @@ ShapeController::~ShapeController()
 }
 
 // WeakComponentImplHelperBase
-void ShapeController::disposing()
+void ShapeController::disposing(std::unique_lock<std::mutex>& /*rGuard*/)
 {
 }
 
@@ -353,7 +353,7 @@ void ShapeController::executeDispatch_TransformDialog()
     if ( pSelectedObj && pSelectedObj->GetObjIdentifier() == SdrObjKind::Caption )
     {
         // item set for caption
-        SfxItemSet aAttr( pDrawViewWrapper->GetModel()->GetItemPool() );
+        SfxItemSet aAttr(pDrawViewWrapper->GetModel().GetItemPool());
         pDrawViewWrapper->GetAttributes( aAttr );
         // item set for position and size
         SfxItemSet aGeoAttr( pDrawViewWrapper->GetGeoAttrFromMarked() );
@@ -402,16 +402,19 @@ void ShapeController::executeDispatch_ObjectTitleDescription()
 
     OUString aTitle( pSelectedObj->GetTitle() );
     OUString aDescription( pSelectedObj->GetDescription() );
+    bool isDecorative(pSelectedObj->IsDecorative());
     SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
     weld::Window* pChartWindow(m_pChartController->GetChartFrame());
     ScopedVclPtr< AbstractSvxObjectTitleDescDialog > pDlg(
-        pFact->CreateSvxObjectTitleDescDialog(pChartWindow, aTitle, aDescription));
+        pFact->CreateSvxObjectTitleDescDialog(pChartWindow, aTitle, aDescription, isDecorative));
     if ( pDlg->Execute() == RET_OK )
     {
         pDlg->GetTitle( aTitle );
         pDlg->GetDescription( aDescription );
+        pDlg->IsDecorative(isDecorative);
         pSelectedObj->SetTitle( aTitle );
         pSelectedObj->SetDescription( aDescription );
+        pSelectedObj->SetDecorative(isDecorative);
     }
 }
 
@@ -505,7 +508,7 @@ void ShapeController::executeDispatch_FontDialog()
     DrawViewWrapper* pDrawViewWrapper = m_pChartController->GetDrawViewWrapper();
     if ( pChartWindow && pDrawModelWrapper && pDrawViewWrapper )
     {
-        SfxItemSet aAttr( pDrawViewWrapper->GetModel()->GetItemPool() );
+        SfxItemSet aAttr(pDrawViewWrapper->GetModel().GetItemPool());
         pDrawViewWrapper->GetAttributes( aAttr );
         ViewElementListProvider aViewElementListProvider( pDrawModelWrapper );
         ShapeFontDialog aDlg(pChartWindow, &aAttr, &aViewElementListProvider);
@@ -528,7 +531,7 @@ void ShapeController::executeDispatch_ParagraphDialog()
     if ( !(pChartWindow && pDrawViewWrapper) )
         return;
 
-    SfxItemPool& rPool = pDrawViewWrapper->GetModel()->GetItemPool();
+    SfxItemPool& rPool = pDrawViewWrapper->GetModel().GetItemPool();
     SfxItemSet aAttr( rPool );
     pDrawViewWrapper->GetAttributes( aAttr );
 
