@@ -27,6 +27,7 @@
 #include <ChartModel.hxx>
 #include <ChartModelHelper.hxx>
 #include <ChartType.hxx>
+#include <GridProperties.hxx>
 #include <Axis.hxx>
 #include <AxisHelper.hxx>
 #include <servicenames_charttypes.hxx>
@@ -42,9 +43,10 @@
 #include <com/sun/star/drawing/XShape.hpp>
 
 #include <rtl/ustrbuf.hxx>
-#include <tools/diagnose_ex.h>
+#include <comphelper/diagnose_ex.hxx>
 #include <o3tl/safeint.hxx>
 #include <o3tl/string_view.hxx>
+#include <utility>
 
 namespace com::sun::star::drawing { class XShape; }
 
@@ -56,10 +58,10 @@ using namespace ::com::sun::star::chart2;
 using ::com::sun::star::uno::Reference;
 using ::com::sun::star::uno::Any;
 
-const sal_Unicode m_aMultiClick[] = u"MultiClick";
-const sal_Unicode m_aDragMethodEquals[] = u"DragMethod=";
-const sal_Unicode m_aDragParameterEquals[] = u"DragParameter=";
-const sal_Unicode m_aProtocol[] = u"CID/";
+const OUStringLiteral m_aMultiClick = u"MultiClick";
+const OUStringLiteral m_aDragMethodEquals = u"DragMethod=";
+const OUStringLiteral m_aDragParameterEquals = u"DragParameter=";
+const OUStringLiteral m_aProtocol = u"CID/";
 const OUString m_aPieSegmentDragMethodServiceName("PieSegmentDragging");
 
 namespace
@@ -89,15 +91,13 @@ OUString lcl_createClassificationStringForType( ObjectType eObjectType
     {
         if( !aRet.isEmpty() )
             aRet.append(":");
-        aRet.append( m_aDragMethodEquals );
-        aRet.append( rDragMethodServiceName );
+        aRet.append( OUString::Concat(m_aDragMethodEquals) + rDragMethodServiceName );
 
         if( !rDragParameterString.empty() )
         {
             if( !aRet.isEmpty() )
                 aRet.append(":");
-            aRet.append( m_aDragParameterEquals );
-            aRet.append( rDragParameterString );
+            aRet.append( OUString::Concat(m_aDragParameterEquals) + rDragParameterString );
         }
     }
     return aRet.makeStringAndClear();
@@ -132,7 +132,7 @@ OUString lcl_getTitleParentParticle( TitleHelper::eTitleType aTitleType )
 
 rtl::Reference<ChartType> lcl_getFirstStockChartType( const rtl::Reference<::chart::ChartModel>& xChartModel )
 {
-    rtl::Reference< Diagram > xDiagram( ChartModelHelper::findDiagram( xChartModel ) );
+    rtl::Reference< Diagram > xDiagram( xChartModel->getFirstChartDiagram() );
     if(!xDiagram.is())
         return nullptr;
 
@@ -152,22 +152,17 @@ rtl::Reference<ChartType> lcl_getFirstStockChartType( const rtl::Reference<::cha
     return nullptr;
 }
 
-OUString lcl_getIndexStringAfterString( const OUString& rString, const OUString& rSearchString )
+std::u16string_view lcl_getIndexStringAfterString( std::u16string_view rString, std::u16string_view rSearchString )
 {
-    OUStringBuffer aRet;
-
-    sal_Int32 nIndexStart = rString.lastIndexOf( rSearchString );
-    if( nIndexStart != -1 )
-    {
-        nIndexStart += rSearchString.getLength();
-        sal_Int32 nIndexEnd = rString.getLength();
-        sal_Int32 nNextColon = rString.indexOf( ':', nIndexStart );
-        if( nNextColon != -1 )
-            nIndexEnd = nNextColon;
-        aRet = rString.subView(nIndexStart,nIndexEnd-nIndexStart);
-    }
-
-    return aRet.makeStringAndClear();
+    size_t nIndexStart = rString.rfind( rSearchString );
+    if( nIndexStart == std::u16string_view::npos )
+        return std::u16string_view();
+    nIndexStart += rSearchString.size();
+    size_t nIndexEnd = rString.size();
+    size_t nNextColon = rString.find( ':', nIndexStart );
+    if( nNextColon != std::u16string_view::npos )
+        nIndexEnd = nNextColon;
+    return rString.substr(nIndexStart,nIndexEnd-nIndexStart);
 }
 
 sal_Int32 lcl_StringToIndex( std::u16string_view rIndexString )
@@ -182,34 +177,34 @@ sal_Int32 lcl_StringToIndex( std::u16string_view rIndexString )
     return nRet;
 }
 
-void lcl_parseCooSysIndices( sal_Int32& rnDiagram, sal_Int32& rnCooSys, const OUString& rString )
+void lcl_parseCooSysIndices( sal_Int32& rnDiagram, sal_Int32& rnCooSys, std::u16string_view rString )
 {
-    rnDiagram = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, "D=" ) );
-    rnCooSys = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, "CS=" ) );
+    rnDiagram = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u"D=" ) );
+    rnCooSys = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u"CS=" ) );
 }
 
-void lcl_parseAxisIndices( sal_Int32& rnDimensionIndex, sal_Int32& rnAxisIndex, const OUString& rString )
+void lcl_parseAxisIndices( sal_Int32& rnDimensionIndex, sal_Int32& rnAxisIndex, std::u16string_view rString )
 {
-    OUString aAxisIndexString = lcl_getIndexStringAfterString( rString, ":Axis=" );
+    std::u16string_view aAxisIndexString = lcl_getIndexStringAfterString( rString, u":Axis=" );
     sal_Int32 nCharacterIndex=0;
     rnDimensionIndex = lcl_StringToIndex( o3tl::getToken(aAxisIndexString, 0, ',', nCharacterIndex ) );
     rnAxisIndex = lcl_StringToIndex( o3tl::getToken(aAxisIndexString, 0, ',', nCharacterIndex ) );
 }
 
-void lcl_parseGridIndices( sal_Int32& rnSubGridIndex, const OUString& rString )
+void lcl_parseGridIndices( sal_Int32& rnSubGridIndex, std::u16string_view rString )
 {
     rnSubGridIndex = -1;
-    rnSubGridIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, ":SubGrid=" ) );
+    rnSubGridIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u":SubGrid=" ) );
 }
 
-void lcl_parseSeriesIndices( sal_Int32& rnChartTypeIndex, sal_Int32& rnSeriesIndex, sal_Int32& rnPointIndex, const OUString& rString )
+void lcl_parseSeriesIndices( sal_Int32& rnChartTypeIndex, sal_Int32& rnSeriesIndex, sal_Int32& rnPointIndex, std::u16string_view rString )
 {
-    rnChartTypeIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, "CT=" ) );
-    rnSeriesIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, "Series=" ) );
-    rnPointIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, "Point=" ) );
+    rnChartTypeIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u"CT=" ) );
+    rnSeriesIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u"Series=" ) );
+    rnPointIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rString, u"Point=" ) );
 }
 
-void lcl_getDiagramAndCooSys( const OUString& rObjectCID
+void lcl_getDiagramAndCooSys( std::u16string_view rObjectCID
                 , const rtl::Reference<::chart::ChartModel>& xChartModel
                 , rtl::Reference< Diagram >& xDiagram
                 , rtl::Reference< BaseCoordinateSystem >& xCooSys )
@@ -217,7 +212,7 @@ void lcl_getDiagramAndCooSys( const OUString& rObjectCID
     sal_Int32 nDiagramIndex = -1;
     sal_Int32 nCooSysIndex = -1;
     lcl_parseCooSysIndices( nDiagramIndex, nCooSysIndex, rObjectCID );
-    xDiagram = ChartModelHelper::findDiagram( xChartModel );//todo use nDiagramIndex when more than one diagram is possible in future
+    xDiagram = xChartModel->getFirstChartDiagram();//todo use nDiagramIndex when more than one diagram is possible in future
     if( !xDiagram.is() )
         return;
 
@@ -235,8 +230,8 @@ ObjectIdentifier::ObjectIdentifier()
 {
 }
 
-ObjectIdentifier::ObjectIdentifier( const OUString& rObjectCID )
-    :m_aObjectCID( rObjectCID )
+ObjectIdentifier::ObjectIdentifier( OUString aObjectCID )
+    :m_aObjectCID(std::move( aObjectCID ))
 {
 }
 
@@ -291,6 +286,25 @@ bool ObjectIdentifier::operator<( const ObjectIdentifier& rOID ) const
     return bReturn;
 }
 
+OUString ObjectIdentifier::createClassifiedIdentifierForObject(
+          const rtl::Reference< ::chart::Title >& xTitle
+        , const rtl::Reference<::chart::ChartModel>& xChartModel )
+{
+    TitleHelper::eTitleType aTitleType;
+    OUString aRet;
+    const std::u16string_view aObjectID;
+    const std::u16string_view aDragMethodServiceName;
+    const std::u16string_view aDragParameterString;
+    if( TitleHelper::getTitleType( aTitleType, xTitle, xChartModel ) )
+    {
+        enum ObjectType eObjectType = OBJECTTYPE_TITLE;
+        OUString aParentParticle = lcl_getTitleParentParticle( aTitleType );
+        aRet = ObjectIdentifier::createClassifiedIdentifierWithParent(
+            eObjectType, aObjectID, aParentParticle, aDragMethodServiceName, aDragParameterString );
+    }
+    return aRet;
+}
+
 OUString ObjectIdentifier::createClassifiedIdentifierForObject(
           const Reference< uno::XInterface >& xObject
         , const rtl::Reference<::chart::ChartModel>& xChartModel )
@@ -306,26 +320,21 @@ OUString ObjectIdentifier::createClassifiedIdentifierForObject(
     try
     {
         //title
-        Reference< XTitle > xTitle( xObject, uno::UNO_QUERY );
-        if( xTitle.is() )
-        {
-            TitleHelper::eTitleType aTitleType;
-            if( TitleHelper::getTitleType( aTitleType, xTitle, xChartModel ) )
-            {
-                eObjectType = OBJECTTYPE_TITLE;
-                aParentParticle = lcl_getTitleParentParticle( aTitleType );
-                aRet = ObjectIdentifier::createClassifiedIdentifierWithParent(
-                    eObjectType, aObjectID, aParentParticle, aDragMethodServiceName, aDragParameterString );
-            }
-            return aRet;
+        if( ::chart::Title* pTitle = dynamic_cast<::chart::Title*>(xObject.get()) )
+            return createClassifiedIdentifierForObject(rtl::Reference<Title>(pTitle), xChartModel);
 
+        uno::Reference<chart2::XDataTable> xDataTable(xObject, uno::UNO_QUERY);
+        if (xDataTable.is())
+        {
+            return createClassifiedIdentifierForParticle(createParticleForDataTable(xChartModel));
         }
 
         //axis
-        Reference< XAxis > xAxis( xObject, uno::UNO_QUERY );
+        rtl::Reference< Axis > xAxis = dynamic_cast<Axis*>( xObject.get() );
         if( xAxis.is() )
         {
-            rtl::Reference< BaseCoordinateSystem > xCooSys( AxisHelper::getCoordinateSystemOfAxis( xAxis, ChartModelHelper::findDiagram( xChartModel ) ) );
+            rtl::Reference<Diagram> xDiagram = xChartModel->getFirstChartDiagram();
+            rtl::Reference< BaseCoordinateSystem > xCooSys( AxisHelper::getCoordinateSystemOfAxis( xAxis, xDiagram ) );
             OUString aCooSysParticle( createParticleForCoordinateSystem( xCooSys, xChartModel ) );
             sal_Int32 nDimensionIndex=-1;
             sal_Int32 nAxisIndex=-1;
@@ -403,7 +412,8 @@ OUString ObjectIdentifier::createClassifiedIdentifierForObject(
         //axis
         if( xAxis.is() )
         {
-            rtl::Reference< BaseCoordinateSystem > xCooSys( AxisHelper::getCoordinateSystemOfAxis( xAxis, ChartModelHelper::findDiagram( xChartModel ) ) );
+            rtl::Reference<Diagram> xDiagram = xChartModel->getFirstChartDiagram();
+            rtl::Reference< BaseCoordinateSystem > xCooSys( AxisHelper::getCoordinateSystemOfAxis( xAxis, xDiagram ) );
             OUString aCooSysParticle( createParticleForCoordinateSystem( xCooSys, xChartModel ) );
             sal_Int32 nDimensionIndex=-1;
             sal_Int32 nAxisIndex=-1;
@@ -438,9 +448,9 @@ OUString ObjectIdentifier::createClassifiedIdentifierForParticles(
     if( eObjectType == OBJECTTYPE_UNKNOWN )
         eObjectType = ObjectIdentifier::getObjectType( rParentParticle );
 
-    OUStringBuffer aRet( m_aProtocol );
-    aRet.append( lcl_createClassificationStringForType( eObjectType, rDragMethodServiceName, rDragParameterString ));
-    if(o3tl::make_unsigned(aRet.getLength()) >= std::size(m_aProtocol))
+    OUStringBuffer aRet( m_aProtocol +
+        lcl_createClassificationStringForType( eObjectType, rDragMethodServiceName, rDragParameterString ));
+    if(aRet.getLength() > m_aProtocol.getLength())
         aRet.append("/");
 
     if(!rParentParticle.empty())
@@ -466,7 +476,7 @@ OUString ObjectIdentifier::createParticleForCoordinateSystem(
 {
     OUString aRet;
 
-    rtl::Reference< Diagram > xDiagram( ChartModelHelper::findDiagram( xChartModel ) );
+    rtl::Reference< Diagram > xDiagram( xChartModel->getFirstChartDiagram() );
     if( xDiagram.is() )
     {
         std::size_t nCooSysIndex = 0;
@@ -543,6 +553,11 @@ OUString ObjectIdentifier::createParticleForLegend(
     return ObjectIdentifier::createParticleForDiagram() + ":" + getStringForType( OBJECTTYPE_LEGEND ) + "=";
 }
 
+OUString ObjectIdentifier::createParticleForDataTable(const rtl::Reference<::chart::ChartModel>& /* xChartModel */)
+{
+    return ObjectIdentifier::createParticleForDiagram() + ":" + getStringForType(OBJECTTYPE_DATA_TABLE) + "=";
+}
+
 OUString ObjectIdentifier::createClassifiedIdentifier(
         enum ObjectType eObjectType //e.g. OBJECTTYPE_DATA_SERIES
         , std::u16string_view rParticleID )//e.g. SeriesID
@@ -562,17 +577,15 @@ OUString ObjectIdentifier::createClassifiedIdentifierWithParent(
 {
     //e.g. "MultiClick/Series=2:Point=34"
 
-    OUStringBuffer aRet( m_aProtocol );
-    aRet.append( lcl_createClassificationStringForType( eObjectType, rDragMethodServiceName, rDragParameterString ));
-    if(o3tl::make_unsigned(aRet.getLength()) >= std::size(m_aProtocol))
+    OUStringBuffer aRet( m_aProtocol +
+        lcl_createClassificationStringForType( eObjectType, rDragMethodServiceName, rDragParameterString ));
+    if(aRet.getLength() > m_aProtocol.getLength())
         aRet.append("/");
     aRet.append(rParentPartical);
     if(!rParentPartical.empty())
         aRet.append(":");
 
-    aRet.append(getStringForType( eObjectType ));
-    aRet.append("=");
-    aRet.append(rParticleID);
+    aRet.append(getStringForType( eObjectType ) + "=" + rParticleID);
 
     return aRet.makeStringAndClear();
 }
@@ -740,18 +753,18 @@ bool ObjectIdentifier::isMultiClickObject( std::u16string_view rClassifiedIdenti
     //was selected before;
 
     //!!!!! by definition the name of a MultiClickObject starts with "CID/MultiClick:"
-    bool bRet = o3tl::starts_with(rClassifiedIdentifier.substr( std::size(m_aProtocol)-1 ), m_aMultiClick);
+    bool bRet = o3tl::starts_with(rClassifiedIdentifier.substr( m_aProtocol.getLength() ), m_aMultiClick);
     return bRet;
 }
 
-bool ObjectIdentifier::areSiblings( const OUString& rCID1, const OUString& rCID2 )
+bool ObjectIdentifier::areSiblings( std::u16string_view rCID1, std::u16string_view rCID2 )
 {
     bool bRet=false;
-    sal_Int32 nLastSign1 = rCID1.lastIndexOf( '=' );
-    sal_Int32 nLastSign2 = rCID2.lastIndexOf( '=' );
-    if( nLastSign1 == rCID1.indexOf( '=' ) )//CID cannot be sibling if only one "=" occurs
+    size_t nLastSign1 = rCID1.rfind( '=' );
+    size_t nLastSign2 = rCID2.rfind( '=' );
+    if( nLastSign1 == rCID1.find( '=' ) )//CID cannot be sibling if only one "=" occurs
         bRet=false;
-    else if( nLastSign2 == rCID2.indexOf( '=' ) )//CID cannot be sibling if only one "=" occurs
+    else if( nLastSign2 == rCID2.find( '=' ) )//CID cannot be sibling if only one "=" occurs
         bRet=false;
     else if( ObjectIdentifier::areIdenticalObjects( rCID1, rCID2 ) )
         bRet=false;
@@ -774,14 +787,14 @@ bool ObjectIdentifier::areSiblings( const OUString& rCID1, const OUString& rCID2
     return bRet;
 }
 
-bool ObjectIdentifier::areIdenticalObjects( const OUString& rCID1, const OUString& rCID2 )
+bool ObjectIdentifier::areIdenticalObjects( std::u16string_view rCID1, std::u16string_view rCID2 )
 {
     if( rCID1 == rCID2 )
         return true;
     //draggable pie or donut segments need special treatment, as their CIDs do change with offset
     {
-        if( rCID1.indexOf( m_aPieSegmentDragMethodServiceName ) < 0
-            || rCID2.indexOf( m_aPieSegmentDragMethodServiceName ) < 0 )
+        if( rCID1.find( m_aPieSegmentDragMethodServiceName ) == std::u16string_view::npos
+            || rCID2.find( m_aPieSegmentDragMethodServiceName ) == std::u16string_view::npos )
             return false;
 
         OUString aID1( ObjectIdentifier::getObjectID( rCID1 ) );
@@ -869,6 +882,9 @@ OUString ObjectIdentifier::getStringForType( ObjectType eObjectType )
         case OBJECTTYPE_DATA_STOCK_GAIN:
                 aRet="StockGain";
                 break;
+        case OBJECTTYPE_DATA_TABLE:
+                aRet="DataTable";
+                break;
         default: //OBJECTTYPE_UNKNOWN
             ;
     }
@@ -940,6 +956,8 @@ ObjectType ObjectIdentifier::getObjectType( std::u16string_view aCID )
         eRet = OBJECTTYPE_DATA_STOCK_LOSS;
     else if( o3tl::starts_with(aCID, u"StockGain") )
         eRet = OBJECTTYPE_DATA_STOCK_GAIN;
+    else if( o3tl::starts_with(aCID, u"DataTable") )
+        eRet = OBJECTTYPE_DATA_TABLE;
     else
         eRet = OBJECTTYPE_UNKNOWN;
 
@@ -995,15 +1013,14 @@ OUString ObjectIdentifier::createChildParticleWithIndex( ObjectType eObjectType,
     OUStringBuffer aRet( getStringForType( eObjectType ) );
     if( !aRet.isEmpty() )
     {
-        aRet.append("=");
-        aRet.append(nIndex);
+        aRet.append("=" + OUString::number(nIndex));
     }
     return aRet.makeStringAndClear();
 }
 
-sal_Int32 ObjectIdentifier::getIndexFromParticleOrCID( const OUString& rParticleOrCID )
+sal_Int32 ObjectIdentifier::getIndexFromParticleOrCID( std::u16string_view rParticleOrCID )
 {
-    const OUString aIndexString = lcl_getIndexStringAfterString( rParticleOrCID, "=" );
+    const std::u16string_view aIndexString = lcl_getIndexStringAfterString( rParticleOrCID, u"=" );
     return lcl_StringToIndex( o3tl::getToken(aIndexString, 0, ',' ) );
 }
 
@@ -1051,16 +1068,16 @@ std::u16string_view ObjectIdentifier::getFullParentParticle( std::u16string_view
     return aRet;
 }
 
-OUString ObjectIdentifier::getObjectID( const OUString& rCID )
+OUString ObjectIdentifier::getObjectID( std::u16string_view rCID )
 {
     OUString aRet;
 
-    sal_Int32 nStartPos = rCID.lastIndexOf('/');
-    if( nStartPos>=0 )
+    size_t nStartPos = rCID.rfind('/');
+    if( nStartPos != std::u16string_view::npos )
     {
         nStartPos++;
-        sal_Int32 nEndPos = rCID.getLength();
-        aRet = rCID.copy(nStartPos,nEndPos-nStartPos);
+        size_t nEndPos = rCID.size();
+        aRet = rCID.substr(nStartPos,nEndPos-nStartPos);
     }
 
     return aRet;
@@ -1072,11 +1089,11 @@ bool ObjectIdentifier::isCID( std::u16string_view rName )
 }
 
 Reference< beans::XPropertySet > ObjectIdentifier::getObjectPropertySet(
-                const OUString& rObjectCID
+                std::u16string_view rObjectCID
                 , const rtl::Reference<::chart::ChartModel>& xChartModel )
 {
     //return the model object that is indicated by rObjectCID
-    if(rObjectCID.isEmpty())
+    if(rObjectCID.empty())
         return nullptr;
     if(!xChartModel.is())
         return nullptr;
@@ -1101,8 +1118,8 @@ Reference< beans::XPropertySet > ObjectIdentifier::getObjectPropertySet(
             case OBJECTTYPE_TITLE:
                 {
                     TitleHelper::eTitleType aTitleType = getTitleTypeForCID( rObjectCID );
-                    Reference< XTitle > xTitle( TitleHelper::getTitle( aTitleType, xChartModel ) );
-                    xObjectProperties.set( xTitle, uno::UNO_QUERY );
+                    rtl::Reference< Title > xTitle( TitleHelper::getTitle( aTitleType, xChartModel ) );
+                    xObjectProperties = xTitle;
                 }
                 break;
             case OBJECTTYPE_LEGEND:
@@ -1154,7 +1171,7 @@ Reference< beans::XPropertySet > ObjectIdentifier::getObjectPropertySet(
                     sal_Int32 nSubGridIndex = -1;
                     lcl_parseGridIndices( nSubGridIndex, rObjectCID );
 
-                    xObjectProperties.set( AxisHelper::getGridProperties( xCooSys , nDimensionIndex, nAxisIndex, nSubGridIndex ) );
+                    xObjectProperties = AxisHelper::getGridProperties( xCooSys , nDimensionIndex, nAxisIndex, nSubGridIndex );
                 }
                 break;
             case OBJECTTYPE_DATA_LABELS:
@@ -1239,6 +1256,13 @@ Reference< beans::XPropertySet > ObjectIdentifier::getObjectPropertySet(
                             xChartType->getPropertyValue( "WhiteDay" ) >>= xObjectProperties;
                     }
                     break;
+            case OBJECTTYPE_DATA_TABLE:
+                    {
+                        if (xDiagram.is())
+                            xObjectProperties.set(xDiagram->getDataTable(), uno::UNO_QUERY);
+                    }
+                break;
+                    break;
             default: //OBJECTTYPE_UNKNOWN
                     break;
         }
@@ -1251,7 +1275,7 @@ Reference< beans::XPropertySet > ObjectIdentifier::getObjectPropertySet(
 }
 
 rtl::Reference< Axis > ObjectIdentifier::getAxisForCID(
-                const OUString& rObjectCID
+                std::u16string_view rObjectCID
                 , const rtl::Reference<::chart::ChartModel>& xChartModel )
 {
     rtl::Reference< Diagram > xDiagram;
@@ -1266,7 +1290,7 @@ rtl::Reference< Axis > ObjectIdentifier::getAxisForCID(
 }
 
 rtl::Reference< DataSeries > ObjectIdentifier::getDataSeriesForCID(
-                const OUString& rObjectCID
+                std::u16string_view rObjectCID
                 , const rtl::Reference<::chart::ChartModel>& xChartModel )
 {
     rtl::Reference< Diagram > xDiagram;
@@ -1279,19 +1303,21 @@ rtl::Reference< DataSeries > ObjectIdentifier::getDataSeriesForCID(
     lcl_parseSeriesIndices( nChartTypeIndex, nSeriesIndex, nPointIndex, rObjectCID );
 
     rtl::Reference< DataSeries > xSeries;
-    rtl::Reference< ChartType > xDataSeriesContainer( DiagramHelper::getChartTypeByIndex( xDiagram, nChartTypeIndex ) );
-    if( xDataSeriesContainer.is() )
+    if (xDiagram)
     {
-        const std::vector< rtl::Reference< DataSeries > > & aDataSeriesSeq( xDataSeriesContainer->getDataSeries2() );
-        if( nSeriesIndex >= 0 && o3tl::make_unsigned(nSeriesIndex) < aDataSeriesSeq.size() )
-            xSeries = aDataSeriesSeq[nSeriesIndex];
+        rtl::Reference< ChartType > xDataSeriesContainer( xDiagram->getChartTypeByIndex( nChartTypeIndex ) );
+        if( xDataSeriesContainer.is() )
+        {
+            const std::vector< rtl::Reference< DataSeries > > & aDataSeriesSeq( xDataSeriesContainer->getDataSeries2() );
+            if( nSeriesIndex >= 0 && o3tl::make_unsigned(nSeriesIndex) < aDataSeriesSeq.size() )
+                xSeries = aDataSeriesSeq[nSeriesIndex];
+        }
     }
-
     return xSeries;
 }
 
 rtl::Reference< Diagram > ObjectIdentifier::getDiagramForCID(
-                  const OUString& rObjectCID
+                  std::u16string_view rObjectCID
                 , const rtl::Reference<::chart::ChartModel>& xChartModel )
 {
     rtl::Reference< Diagram > xDiagram;
@@ -1315,7 +1341,7 @@ TitleHelper::eTitleType ObjectIdentifier::getTitleTypeForCID( std::u16string_vie
     return eRet;
 }
 
-OUString ObjectIdentifier::getSeriesParticleFromCID( const OUString& rCID )
+OUString ObjectIdentifier::getSeriesParticleFromCID( std::u16string_view rCID )
 {
     sal_Int32 nDiagramIndex = -1;
     sal_Int32 nCooSysIndex = -1;
@@ -1329,12 +1355,12 @@ OUString ObjectIdentifier::getSeriesParticleFromCID( const OUString& rCID )
     return ObjectIdentifier::createParticleForSeries( nDiagramIndex, nCooSysIndex, nChartTypeIndex, nSeriesIndex );
 }
 
-OUString ObjectIdentifier::getMovedSeriesCID( const OUString& rObjectCID, bool bForward )
+OUString ObjectIdentifier::getMovedSeriesCID( std::u16string_view rObjectCID, bool bForward )
 {
-    sal_Int32 nDiagramIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, "CID/D=" ) );
-    sal_Int32 nCooSysIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, "CS=" ) );
-    sal_Int32 nChartTypeIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, "CT=" ) );
-    sal_Int32 nSeriesIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, "Series=" ) );
+    sal_Int32 nDiagramIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, u"CID/D=" ) );
+    sal_Int32 nCooSysIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, u"CS=" ) );
+    sal_Int32 nChartTypeIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, u"CT=" ) );
+    sal_Int32 nSeriesIndex = lcl_StringToIndex( lcl_getIndexStringAfterString( rObjectCID, u"Series=" ) );
 
     if( bForward )
         nSeriesIndex--;
