@@ -56,6 +56,7 @@
 #include <DateHelper.hxx>
 #include <ExplicitCategoriesProvider.hxx>
 #include <defines.hxx>
+#include <dumpxmltostring.hxx>
 #include <unonames.hxx>
 #include <editeng/frmdiritem.hxx>
 #include <editeng/eeitem.hxx>
@@ -164,7 +165,6 @@ ChartView::ChartView(
         ChartModel& rModel)
     : m_xCC(std::move(xContext))
     , mrChartModel(rModel)
-    , m_aListenerContainer( m_aMutex )
     , m_bViewDirty(true)
     , m_bInViewUpdate(false)
     , m_bViewUpdatePending(false)
@@ -307,12 +307,6 @@ sal_Bool SAL_CALL ChartView::isDataFlavorSupported( const datatransfer::DataFlav
              aFlavor.MimeType == lcl_aGDIMetaFileMIMETypeHighContrast );
 }
 
-// ____ XUnoTunnel ___
-::sal_Int64 SAL_CALL ChartView::getSomething( const uno::Sequence< ::sal_Int8 >& aIdentifier )
-{
-    return comphelper::getSomethingImpl<ExplicitValueProvider>(aIdentifier, this);
-}
-
 // lang::XServiceInfo
 
 OUString SAL_CALL ChartView::getImplementationName()
@@ -350,13 +344,13 @@ bool lcl_IsPieOrDonut( const rtl::Reference< Diagram >& xDiagram )
     //the size is checked after complete creation to get the datalabels into the given space
 
     //todo: this is just a workaround at the moment for pie and donut labels
-    return DiagramHelper::isPieOrDonutChart( xDiagram );
+    return xDiagram->isPieOrDonutChart();
 }
 
 void lcl_setDefaultWritingMode( const std::shared_ptr< DrawModelWrapper >& pDrawModelWrapper, ChartModel& rModel)
 {
     //get writing mode from parent document:
-    if( !SvtCTLOptions().IsCTLFontEnabled() )
+    if( !SvtCTLOptions::IsCTLFontEnabled() )
         return;
 
     try
@@ -511,7 +505,7 @@ awt::Rectangle ChartView::impl_createDiagramAndContent( const CreateShapeParam2D
     if( !xDiagram.is())
         return aUsedOuterRect;
 
-    sal_Int32 nDimensionCount = DiagramHelper::getDimension( xDiagram );
+    sal_Int32 nDimensionCount = xDiagram->getDimension();
     if(!nDimensionCount)
     {
         //@todo handle mixed dimension
@@ -786,7 +780,7 @@ awt::Rectangle ChartView::impl_createDiagramAndContent( const CreateShapeParam2D
 }
 
 bool ChartView::getExplicitValuesForAxis(
-                     uno::Reference< XAxis > xAxis
+                     rtl::Reference< Axis > xAxis
                      , ExplicitScaleData&  rExplicitScale
                      , ExplicitIncrementData& rExplicitIncrement )
 {
@@ -924,15 +918,29 @@ namespace
 {
 
 constexpr double constPageLayoutDistancePercentage = 0.02;
+constexpr sal_Int32 constPageLayoutFixedDistance = 350;
 
 bool getAvailablePosAndSizeForDiagram(
-    CreateShapeParam2D& rParam, const awt::Size & rPageSize, const uno::Reference< beans::XPropertySet >& xProp)
+    CreateShapeParam2D& rParam, const awt::Size & rPageSize, rtl::Reference<Diagram> const& xDiagram)
 {
+    uno::Reference<beans::XPropertySet> const& xProp(xDiagram);
     rParam.mbUseFixedInnerSize = false;
 
     //@todo: we need a size dependent on the axis labels
-    sal_Int32 nYDistance = static_cast<sal_Int32>(rPageSize.Height * constPageLayoutDistancePercentage);
-    sal_Int32 nXDistance = static_cast<sal_Int32>(rPageSize.Width * constPageLayoutDistancePercentage);
+    rtl::Reference<ChartType> xChartType;
+    if (xDiagram)
+        xChartType = xDiagram->getChartTypeByIndex(0);
+
+    sal_Int32 nXDistance = sal_Int32(rPageSize.Width * constPageLayoutDistancePercentage);
+    sal_Int32 nYDistance = sal_Int32(rPageSize.Height * constPageLayoutDistancePercentage);
+
+    // Only pie chart uses fixed size margins
+    if (xChartType.is() && xChartType->getChartType() == CHART2_SERVICE_NAME_CHARTTYPE_PIE)
+    {
+        nXDistance = constPageLayoutFixedDistance;
+        nYDistance = constPageLayoutFixedDistance;
+    }
+
     rParam.maRemainingSpace.X += nXDistance;
     rParam.maRemainingSpace.Width -= 2*nXDistance;
     rParam.maRemainingSpace.Y += nYDistance;
@@ -1064,7 +1072,7 @@ std::shared_ptr<VTitle> lcl_createTitle( TitleHelper::eTitleType eType
         nXDistance = 450; // 1/100 mm
     }
 
-    uno::Reference< XTitle > xTitle( TitleHelper::getTitle( eType, rModel ) );
+    rtl::Reference< Title > xTitle( TitleHelper::getTitle( eType, rModel ) );
     OUString aCompleteString = TitleHelper::getCompleteString(xTitle);
     if (aCompleteString.isEmpty() || !VTitle::isVisible(xTitle))
         return apVTitle;
@@ -1101,8 +1109,7 @@ std::shared_ptr<VTitle> lcl_createTitle( TitleHelper::eTitleType eType
     rbAutoPosition = true;
     awt::Point aNewPosition(0,0);
     chart2::RelativePosition aRelativePosition;
-    uno::Reference<beans::XPropertySet> xProp(xTitle, uno::UNO_QUERY);
-    if (xProp.is() && (xProp->getPropertyValue("RelativePosition") >>= aRelativePosition))
+    if (xTitle.is() && (xTitle->getPropertyValue("RelativePosition") >>= aRelativePosition))
     {
         rbAutoPosition = false;
 
@@ -1350,7 +1357,7 @@ void ChartView::createShapes()
 {
     SolarMutexGuard aSolarGuard;
 
-    osl::MutexGuard aTimedGuard(maTimeMutex);
+    std::unique_lock aTimedGuard(maTimeMutex);
     if(mrChartModel.isTimeBased())
     {
         maTimeBased.bTimeBased = true;
@@ -1552,16 +1559,11 @@ void ChartView::impl_notifyModeChangeListener( const OUString& rNewMode )
 {
     try
     {
-        comphelper::OInterfaceContainerHelper2* pIC = m_aListenerContainer
-            .getContainer( cppu::UnoType<util::XModeChangeListener>::get());
-        if( pIC )
+        std::unique_lock g(m_aMutex);
+        if( m_aModeChangeListeners.getLength(g) )
         {
             util::ModeChangeEvent aEvent( static_cast< uno::XWeak* >( this ), rNewMode );
-            comphelper::OInterfaceIteratorHelper2 aIt( *pIC );
-            while( aIt.hasMoreElements() )
-            {
-                static_cast< util::XModeChangeListener* >( aIt.next() )->modeChanged( aEvent );
-            }
+            m_aModeChangeListeners.notifyEach( g, &css::util::XModeChangeListener::modeChanged, aEvent);
         }
     }
     catch( const uno::Exception& )
@@ -1574,13 +1576,13 @@ void ChartView::impl_notifyModeChangeListener( const OUString& rNewMode )
 
 void SAL_CALL ChartView::addModeChangeListener( const uno::Reference< util::XModeChangeListener >& xListener )
 {
-    m_aListenerContainer.addInterface(
-        cppu::UnoType<util::XModeChangeListener>::get(), xListener );
+    std::unique_lock g(m_aMutex);
+    m_aModeChangeListeners.addInterface(g, xListener );
 }
 void SAL_CALL ChartView::removeModeChangeListener( const uno::Reference< util::XModeChangeListener >& xListener )
 {
-    m_aListenerContainer.removeInterface(
-        cppu::UnoType<util::XModeChangeListener>::get(), xListener );
+    std::unique_lock g(m_aMutex);
+    m_aModeChangeListeners.removeInterface(g, xListener );
 }
 void SAL_CALL ChartView::addModeChangeApproveListener( const uno::Reference< util::XModeChangeApproveListener >& /* _rxListener */ )
 {
@@ -1784,8 +1786,13 @@ uno::Sequence< OUString > ChartView::getAvailableServiceNames()
     return aServiceNames;
 }
 
-OUString ChartView::dump()
+OUString ChartView::dump(OUString const & kind)
 {
+    if (kind.isEmpty()) {
+        return dumpXmlToString([this](auto writer) { return dumpAsXml(writer); });
+    }
+
+    // kind == "shapes":
 #if HAVE_FEATURE_DESKTOP
     // Used for unit tests and in chartcontroller only, no need to drag in this when cross-compiling
     // for non-desktop
@@ -1832,7 +1839,7 @@ void ChartView::dumpAsXml(xmlTextWriterPtr pWriter) const
 
 void ChartView::setViewDirty()
 {
-    osl::MutexGuard aGuard(maTimeMutex);
+    std::unique_lock aGuard(maTimeMutex);
     m_bViewDirty = true;
 }
 
@@ -1923,7 +1930,7 @@ void ChartView::createShapes2D( const awt::Size& rPageSize )
         return;
 
     bool bDummy = false;
-    bool bIsVertical = DiagramHelper::getVertical(xDiagram, bDummy, bDummy);
+    bool bIsVertical = xDiagram && xDiagram->getVertical(bDummy, bDummy);
 
     if (getAvailablePosAndSizeForDiagram(aParam, rPageSize, xDiagram))
     {
@@ -1986,8 +1993,13 @@ bool ChartView::createAxisTitleShapes2D( CreateShapeParam2D& rParam, const css::
 {
     rtl::Reference<Diagram> xDiagram = mrChartModel.getFirstChartDiagram();
 
-    rtl::Reference< ChartType > xChartType( DiagramHelper::getChartTypeByIndex( xDiagram, 0 ) );
-    sal_Int32 nDimension = DiagramHelper::getDimension( xDiagram );
+    rtl::Reference< ChartType > xChartType;
+    sal_Int32 nDimension = 0;
+    if (xDiagram)
+    {
+        xChartType = xDiagram->getChartTypeByIndex( 0 );
+        nDimension = xDiagram->getDimension();
+    }
 
     if( ChartTypeHelper::isSupportingMainAxis( xChartType, nDimension, 0 ) )
         rParam.mpVTitleX = lcl_createTitle( TitleHelper::TITLE_AT_STANDARD_X_AXIS_POSITION, mxRootShape, mrChartModel
@@ -2008,7 +2020,7 @@ bool ChartView::createAxisTitleShapes2D( CreateShapeParam2D& rParam, const css::
         return false;
 
     bool bDummy = false;
-    bool bIsVertical = DiagramHelper::getVertical( xDiagram, bDummy, bDummy );
+    bool bIsVertical = xDiagram && xDiagram->getVertical( bDummy, bDummy );
 
     if( ChartTypeHelper::isSupportingSecondaryAxis( xChartType, nDimension ) )
         rParam.mpVTitleSecondX = lcl_createTitle( TitleHelper::SECONDARY_X_AXIS_TITLE, mxRootShape, mrChartModel
