@@ -128,7 +128,7 @@ namespace dbaui
             case  ::dbaccess::DST_MYSQL_ODBC:
             case  ::dbaccess::DST_ODBC:
                 m_xFT_Connection->set_label(DBA_RES(STR_NAME_OF_ODBC_DATASOURCE));
-                m_xConnectionURL->set_help_id( eType ==  ::dbaccess::DST_MYSQL_ODBC ? OString(HID_DSADMIN_MYSQL_ODBC_DATASOURCE) : OString(HID_DSADMIN_ODBC_DATASOURCE));
+                m_xConnectionURL->set_help_id( eType ==  ::dbaccess::DST_MYSQL_ODBC ? OUString(HID_DSADMIN_MYSQL_ODBC_DATASOURCE) : OUString(HID_DSADMIN_ODBC_DATASOURCE));
                 break;
             case  ::dbaccess::DST_LDAP:
                 m_xFT_Connection->set_label(DBA_RES(STR_HOSTNAME));
@@ -204,7 +204,7 @@ namespace dbaui
         m_xJavaDriverLabel->set_visible(bEnableJDBC);
         m_xJavaDriver->set_visible(bEnableJDBC);
         m_xTestJavaDriver->set_visible(bEnableJDBC);
-        m_xTestJavaDriver->set_sensitive( !m_xJavaDriver->get_text().trim().isEmpty() );
+        m_xTestJavaDriver->set_sensitive( !o3tl::trim(m_xJavaDriver->get_text()).empty() );
         m_xFL3->set_visible(bEnableJDBC);
 
         checkTestConnection();
@@ -244,7 +244,7 @@ namespace dbaui
 #if HAVE_FEATURE_JAVA
         try
         {
-            if ( !m_xJavaDriver->get_text().trim().isEmpty() )
+            if ( !o3tl::trim(m_xJavaDriver->get_text()).empty() )
             {
                 ::rtl::Reference< jvmaccess::VirtualMachine > xJVM = ::connectivity::getJavaVM( m_pAdminDialog->getORB() );
                 m_xJavaDriver->set_text(m_xJavaDriver->get_text().trim()); // fdo#68341
@@ -266,14 +266,14 @@ namespace dbaui
         OSL_ENSURE(m_pAdminDialog,"No Admin dialog set! ->GPF");
         bool bEnableTestConnection = !m_xConnectionURL->get_visible() || !m_xConnectionURL->GetTextNoPrefix().isEmpty();
         if ( m_pCollection->determineType(m_eType) ==  ::dbaccess::DST_JDBC )
-            bEnableTestConnection = bEnableTestConnection && (!m_xJavaDriver->get_text().trim().isEmpty());
+            bEnableTestConnection = bEnableTestConnection && (!o3tl::trim(m_xJavaDriver->get_text()).empty());
         m_xTestConnection->set_sensitive(bEnableTestConnection);
         return true;
     }
     IMPL_LINK(OConnectionTabPage, OnEditModified, weld::Entry&, rEdit, void)
     {
         if (&rEdit == m_xJavaDriver.get())
-            m_xTestJavaDriver->set_sensitive( !m_xJavaDriver->get_text().trim().isEmpty() );
+            m_xTestJavaDriver->set_sensitive( !o3tl::trim(m_xJavaDriver->get_text()).empty() );
 
         checkTestConnection();
         // tell the listener we were modified
