@@ -82,6 +82,7 @@
 #include <desktop/exithelper.h>
 #include <sal/log.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
+#include <comphelper/lok.hxx>
 #include <comphelper/configuration.hxx>
 #include <comphelper/fileurl.hxx>
 #include <comphelper/threadpool.hxx>
@@ -341,6 +342,8 @@ namespace {
 
 void runGraphicsRenderTests()
 {
+    if (comphelper::LibreOfficeKit::isActive())
+        return;
 #if !ENABLE_WASM_STRIP_PINGUSER
     if (!utl::isProductVersionUpgraded(false))
     {
@@ -474,30 +477,27 @@ void Desktop::Init()
     // the UserConfiguration directory
     comphelper::BackupFileHelper::reactOnSafeMode(Application::IsSafeModeEnabled());
 
-    if ( m_aBootstrapError == BE_OK )
+    try
     {
-        try
+        if (!langselect::prepareLocale())
         {
-            if (!langselect::prepareLocale())
-            {
-                SetBootstrapError( BE_LANGUAGE_MISSING, OUString() );
-            }
-        }
-        catch (css::uno::Exception & e)
-        {
-            SetBootstrapError( BE_OFFICECONFIG_BROKEN, e.Message );
+            SetBootstrapError( BE_LANGUAGE_MISSING, OUString() );
         }
+    }
+    catch (css::uno::Exception & e)
+    {
+        SetBootstrapError( BE_OFFICECONFIG_BROKEN, e.Message );
+    }
 
-        // test code for ProfileSafeMode to allow testing the fail
-        // of loading the office configuration initially. To use,
-        // either set to true and compile, or set a breakpoint
-        // in debugger and change the local bool
-        static bool bTryHardOfficeconfigBroken(false); // loplugin:constvars:ignore
+    // test code for ProfileSafeMode to allow testing the fail
+    // of loading the office configuration initially. To use,
+    // either set to true and compile, or set a breakpoint
+    // in debugger and change the local bool
+    static bool bTryHardOfficeconfigBroken(false); // loplugin:constvars:ignore
 
-        if (bTryHardOfficeconfigBroken)
-        {
-            SetBootstrapError(BE_OFFICECONFIG_BROKEN, OUString());
-        }
+    if (bTryHardOfficeconfigBroken)
+    {
+        SetBootstrapError(BE_OFFICECONFIG_BROKEN, OUString());
     }
 
     // start ipc thread only for non-remote offices
@@ -589,7 +589,7 @@ bool Desktop::QueryExit()
     {
         xPropertySet->setPropertyValue( SUSPEND_QUICKSTARTVETO, Any(false) );
     }
-    else if (!Application::IsEventTestingModeEnabled())
+    else
     {
         FlushConfiguration();
         try
@@ -1227,14 +1227,12 @@ struct ExecuteGlobals
 {
     Reference < css::document::XDocumentEventListener > xGlobalBroadcaster;
     bool bRestartRequested;
-    bool bUseSystemFileDialog;
     std::unique_ptr<SvtCTLOptions> pCTLLanguageOptions;
     std::unique_ptr<SvtPathOptions> pPathOptions;
     rtl::Reference< JVMloadThread > xJVMloadThread;
 
     ExecuteGlobals()
     : bRestartRequested( false )
-    , bUseSystemFileDialog( true )
     {}
 };
 
@@ -1511,18 +1509,6 @@ int Desktop::Main()
         }
     }
 
-    if ( rCmdLineArgs.IsHeadless() || rCmdLineArgs.IsEventTesting() )
-    {
-        // Ensure that we use not the system file dialogs as
-        // headless mode relies on Application::EnableHeadlessMode()
-        // which does only work for VCL dialogs!!
-        pExecGlobals->bUseSystemFileDialog = officecfg::Office::Common::Misc::UseSystemFileDialog::get();
-        std::shared_ptr< comphelper::ConfigurationChanges > xChanges(
-                comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Misc::UseSystemFileDialog::set( false, xChanges );
-        xChanges->commit();
-    }
-
     pExecGlobals->bRestartRequested = xRestartManager->isRestartRequested(true);
     if ( !pExecGlobals->bRestartRequested )
     {
@@ -1540,11 +1526,9 @@ int Desktop::Main()
 
     svtools::ApplyFontSubstitutionsToVcl();
 
-    SvtTabAppearanceCfg aAppearanceCfg;
     SvtTabAppearanceCfg::SetInitialized();
-    aAppearanceCfg.SetApplicationDefaults( this );
-    SvtAccessibilityOptions aOptions;
-    aOptions.SetVCLSettings();
+    SvtTabAppearanceCfg::SetApplicationDefaults( this );
+    SvtAccessibilityOptions::SetVCLSettings();
     SetSplashScreenProgress(60);
 
     if ( !pExecGlobals->bRestartRequested )
@@ -1572,12 +1556,14 @@ int Desktop::Main()
         CheckOpenCLCompute(xDesktop);
 #endif
 
+#if !defined(EMSCRIPTEN)
         //Running the VCL graphics rendering tests
         const char * pDisplay = std::getenv("DISPLAY");
         if (!pDisplay || pDisplay[0] == ':')
         {
             runGraphicsRenderTests();
         }
+#endif
 
         // Post user event to startup first application component window
         // We have to send this OpenClients message short before execute() to
@@ -1636,16 +1622,7 @@ int Desktop::doShutdown()
     if ( pExecGlobals->bRestartRequested )
         SetRestartState();
 
-    // Restore old value
     const CommandLineArgs& rCmdLineArgs = GetCommandLineArgs();
-    if ( rCmdLineArgs.IsHeadless() || rCmdLineArgs.IsEventTesting() )
-    {
-        std::shared_ptr< comphelper::ConfigurationChanges > xChanges(
-                comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Misc::UseSystemFileDialog::set( pExecGlobals->bUseSystemFileDialog, xChanges );
-        xChanges->commit();
-    }
-
     OUString pidfileName = rCmdLineArgs.GetPidfileName();
     if ( !pidfileName.isEmpty() )
     {
@@ -1850,8 +1827,7 @@ void Desktop::OverrideSystemSettings( AllSettings& rSettings )
 
     DragFullOptions nDragFullOptions = hStyleSettings.GetDragFullOptions();
 
-    SvtTabAppearanceCfg aAppearanceCfg;
-    DragMode nDragMode = aAppearanceCfg.GetDragMode();
+    DragMode nDragMode = static_cast<DragMode>(officecfg::Office::Common::View::Window::Drag::get());
     switch ( nDragMode )
     {
     case DragMode::FullWindow:
@@ -1866,7 +1842,8 @@ void Desktop::OverrideSystemSettings( AllSettings& rSettings )
     }
 
     MouseFollowFlags nFollow = hMouseSettings.GetFollow();
-    hMouseSettings.SetFollow( aAppearanceCfg.IsMenuMouseFollow() ? (nFollow|MouseFollowFlags::Menu) : (nFollow&~MouseFollowFlags::Menu));
+    bool bMenuFollowMouse = officecfg::Office::Common::View::Menu::FollowMouse::get();
+    hMouseSettings.SetFollow( bMenuFollowMouse ? (nFollow|MouseFollowFlags::Menu) : (nFollow&~MouseFollowFlags::Menu));
     rSettings.SetMouseSettings(hMouseSettings);
 
     bool bMenuIcons = officecfg::Office::Common::View::Menu::ShowIconsInMenues::get();
