@@ -24,6 +24,8 @@
 #include <dp_identifier.hxx>
 #include <tools/extendapplicationenvironment.hxx>
 #include <rtl/bootstrap.hxx>
+#include <rtl/textenc.h>
+#include <rtl/ustring.hxx>
 #include <osl/process.h>
 #include <osl/conditn.hxx>
 #include <unotools/tempfile.hxx>
@@ -48,6 +50,7 @@
 #if defined(UNX)
   #include <unistd.h>
 #endif
+#include <iostream>
 #include <utility>
 #include <vector>
 
@@ -89,7 +92,7 @@ u"\n"
 " remove                  remove extensions by identifier\n"
 " reinstall               expert feature: reinstall all deployed extensions\n"
 " list                    list information about deployed extensions\n"
-" gui                     raise Extension Manager Graphical User Interface (GUI)\n"
+" gui                     raise Extensions dialog\n"
 "\n"
 "options:\n"
 " -h, --help              this help\n"
@@ -107,7 +110,7 @@ u"\n"
 " --deployment-context    expert feature: explicit deployment context\n"
 "     <context>\n"
 "\n"
-"To learn more about the Extension Manager and extensions, see:\n"
+"To learn more about extensions, see:\n"
 "https://wiki.documentfoundation.org/Documentation/DevGuide/Extensions\n\n";
 
 
@@ -125,6 +128,21 @@ const OptionInfo s_option_infos [] = {
     { nullptr, 0, '\0', false }
 };
 
+void logFatal(
+    comphelper::EventLogger const * logger, sal_Int32 level, OUString const & message,
+    OUString const & argument)
+{
+    if (logger == nullptr) {
+        // Best effort; potentially loses data due to conversion failures (stray surrogate halves)
+        // and embedded null characters:
+        std::cerr
+            << OUStringToOString(message.replaceFirst("$1$", argument), RTL_TEXTENCODING_UTF8)
+            << '\n';
+    } else {
+        logger->log(level, message, argument);
+    }
+}
+
 class DialogClosedListenerImpl :
     public ::cppu::WeakImplHelper< ui::dialogs::XDialogClosedListener >
 {
@@ -198,7 +216,7 @@ extern "C" int unopkg_main()
     Reference<XLogHandler> xFileHandler;
     Reference<XLogHandler> xConsoleHandler;
     std::unique_ptr<comphelper::EventLogger> logger;
-    std::unique_ptr<utl::TempFile> pUserProfileTempDir;
+    std::unique_ptr<utl::TempFileNamed> pUserProfileTempDir;
 
     OptionInfo const * info_shared = getOptionInfo(
         s_option_infos, "shared" );
@@ -272,7 +290,7 @@ extern "C" int unopkg_main()
                     if (cmdArg[ 0 ] == '-')
                     {
                         // is option:
-                        dp_misc::writeConsoleError(OUStringConcatenation(
+                        dp_misc::writeConsoleError(Concat2View(
                                  "\nERROR: unexpected option " +
                                  cmdArg +
                                  "!\n       Use " APP_NAME " " +
@@ -296,7 +314,7 @@ extern "C" int unopkg_main()
         // tdf#129917 Use temp user profile when installing shared extensions
         if (option_shared)
         {
-            pUserProfileTempDir.reset(new utl::TempFile(nullptr, true));
+            pUserProfileTempDir.reset(new utl::TempFileNamed(nullptr, true));
             pUserProfileTempDir->EnableKillingFile();
         }
 
@@ -479,7 +497,7 @@ extern "C" int unopkg_main()
                       vec_packages.size(), false);
 
                 dp_misc::writeConsole(
-                    OUStringConcatenation("All deployed " + repository + " extensions:\n\n"));
+                    Concat2View("All deployed " + repository + " extensions:\n\n"));
             }
             else
             {
@@ -598,32 +616,33 @@ extern "C" int unopkg_main()
     }
     catch (const ucb::CommandFailedException &e)
     {
-        logger->log(LogLevel::SEVERE, "Exception occurred: $1$", e.Message);
+        logFatal(logger.get(), LogLevel::SEVERE, "Exception occurred: $1$", e.Message);
     }
     catch (const ucb::CommandAbortedException &)
     {
-        logger->log(LogLevel::SEVERE, "$1$ aborted.", APP_NAME);
+        logFatal(logger.get(), LogLevel::SEVERE, "$1$ aborted.", APP_NAME);
         bShowFailedMsg = false;
     }
     catch (const deployment::DeploymentException & exc)
     {
-        logger->log(LogLevel::SEVERE, "Exception occurred: $1$", exc.Message);
-        logger->log(LogLevel::INFO, "    Cause: $1$", comphelper::anyToString(exc.Cause));
+        logFatal(logger.get(), LogLevel::SEVERE, "Exception occurred: $1$", exc.Message);
+        logFatal(
+            logger.get(), LogLevel::INFO, "    Cause: $1$", comphelper::anyToString(exc.Cause));
     }
     catch (const LockFileException & e)
     {
         // No logger since it requires UNO which we don't have here
-        dp_misc::writeConsoleError(OUStringConcatenation(e.Message + "\n"));
+        dp_misc::writeConsoleError(Concat2View(e.Message + "\n"));
         bShowFailedMsg = false;
     }
     catch (const css::uno::Exception & e ) {
         Any exc( ::cppu::getCaughtException() );
 
-        logger->log(LogLevel::SEVERE, "Exception occurred: $1$", e.Message);
-        logger->log(LogLevel::INFO, "    Cause: $1$", comphelper::anyToString(exc));
+        logFatal(logger.get(), LogLevel::SEVERE, "Exception occurred: $1$", e.Message);
+        logFatal(logger.get(), LogLevel::INFO, "    Cause: $1$", comphelper::anyToString(exc));
     }
     if (bShowFailedMsg)
-        logger->log(LogLevel::SEVERE, "$1$ failed.", APP_NAME);
+        logFatal(logger.get(), LogLevel::SEVERE, "$1$ failed.", APP_NAME);
     dp_misc::disposeBridges(xLocalComponentContext);
     if (xLocalComponentContext.is()) {
         css::uno::Reference<css::lang::XComponent>(
