@@ -234,7 +234,7 @@ VclPtr<VirtualDevice> VDevBuffer::alloc(OutputDevice& rOutDev, const Size& rSize
     // no success yet, create new buffer
     if (!pRetval)
     {
-        pRetval = VclPtr<VirtualDevice>::Create(rOutDev, DeviceFormat::DEFAULT);
+        pRetval = VclPtr<VirtualDevice>::Create(rOutDev, DeviceFormat::WITHOUT_ALPHA);
         maDeviceTemplates[pRetval] = &rOutDev;
         pRetval->SetOutputSizePixel(rSizePixel, true);
     }
@@ -535,7 +535,7 @@ void impBufferDevice::paint(double fTrans)
             // use Former for now.
             //
             // To easily allow to change this (maybe system-dependent) I add a static switch here,
-            // also for evetually experimenting (hint: can be changed in the debugger).
+            // also for eventually experimenting (hint: can be changed in the debugger).
             static bool bUseNew(false);
 
             if (bUseNew)
