@@ -24,18 +24,10 @@
 #include <cstddef>
 
 #include "StdAfx2.h"
+#include <so_activex.h>
 #include "SOComWindowPeer.h"
 #include <sal/macros.h>
 
-#if defined __clang__
-#pragma clang diagnostic push
-#pragma clang diagnostic ignored "-Wnon-virtual-dtor"
-#endif
-#include <so_activex.h>
-#if defined __clang__
-#pragma clang diagnostic pop
-#endif
-
 COM_DECLSPEC_NOTHROW STDMETHODIMP SOComWindowPeer::InterfaceSupportsErrorInfo(REFIID riid)
 {
     static const IID* arr[] = {
@@ -44,11 +36,7 @@ COM_DECLSPEC_NOTHROW STDMETHODIMP SOComWindowPeer::InterfaceSupportsErrorInfo(RE
 
     for (std::size_t i = 0; i < SAL_N_ELEMENTS(arr); i++)
     {
-#ifdef _MSC_VER
         if (InlineIsEqualGUID(*arr[i], riid))
-#else
-        if (::ATL::InlineIsEqualGUID(*arr[i], riid))
-#endif
             return S_OK;
     }
     return S_FALSE;
