@@ -42,7 +42,9 @@
 #include <svtools/acceleratorexecute.hxx>
 #include <com/sun/star/ui/XUIConfigurationManagerSupplier.hpp>
 #include <com/sun/star/ui/XUIConfigurationManager.hpp>
-#include <map>
+#include <frozen/bits/defines.h>
+#include <frozen/bits/elsa_std.h>
+#include <frozen/unordered_map.h>
 
 using namespace ::com::sun::star;
 
@@ -56,12 +58,12 @@ OUString makeMacroURL( std::u16string_view sMacroName )
     return sUrlPart0 + sMacroName + sUrlPart1;
 }
 
-OUString extractMacroName( const OUString& rMacroUrl )
+OUString extractMacroName( std::u16string_view rMacroUrl )
 {
-    if( rMacroUrl.startsWith( sUrlPart0 ) && rMacroUrl.endsWith( sUrlPart1 ) )
+    if( o3tl::starts_with(rMacroUrl, sUrlPart0 ) && o3tl::ends_with(rMacroUrl, sUrlPart1 ) )
     {
-        return rMacroUrl.copy( sUrlPart0.getLength(),
-            rMacroUrl.getLength() - sUrlPart0.getLength() - sUrlPart1.getLength() );
+        return OUString(rMacroUrl.substr( sUrlPart0.getLength(),
+            rMacroUrl.size() - sUrlPart0.getLength() - sUrlPart1.getLength() ));
     }
     return OUString();
 }
@@ -171,48 +173,66 @@ static SfxObjectShell* findShellForUrl( const OUString& sMacroURLOrPath )
 // sMod can be empty ( but we really need the library to search in )
 // if sMod is empty and a macro is found then sMod is updated
 // if sMod is empty, only standard modules will be searched (no class, document, form modules)
-static bool hasMacro( SfxObjectShell const * pShell, const OUString& sLibrary, OUString& sMod, const OUString& sMacro )
+static bool hasMacro(SfxObjectShell const* pShell, const OUString& sLibrary, OUString& sMod,
+                     const OUString& sMacro, bool bOnlyPublic, const OUString& sSkipModule)
 {
 #if !HAVE_FEATURE_SCRIPTING
     (void) pShell;
     (void) sLibrary;
     (void) sMod;
     (void) sMacro;
+    (void) bOnlyPublic;
+    (void) sSkipModule;
 #else
-    if ( !sLibrary.isEmpty() && !sMacro.isEmpty() )
+    if (sLibrary.isEmpty() || sMacro.isEmpty())
+        return false;
+
+    BasicManager* pBasicMgr = pShell->GetBasicManager();
+    if (!pBasicMgr)
+        return false;
+
+    StarBASIC* pBasic = pBasicMgr->GetLib(sLibrary);
+    if (!pBasic)
     {
-        BasicManager* pBasicMgr = pShell-> GetBasicManager();
-        if ( pBasicMgr )
+        sal_uInt16 nId = pBasicMgr->GetLibId(sLibrary);
+        pBasicMgr->LoadLib(nId);
+        pBasic = pBasicMgr->GetLib(sLibrary);
+    }
+    if (!pBasic)
+        return false;
+
+    if (!sMod.isEmpty()) // we wish to find the macro is a specific module
+    {
+        SbModule* pModule = pBasic->FindModule(sMod);
+        if (!pModule)
+            return false;
+        SbMethod* pMeth = pModule->FindMethod(sMacro, SbxClassType::Method);
+
+        // Must be compiled before we can trust SbxFlagBits::Private
+        if (pMeth && bOnlyPublic && !pModule->IsCompiled())
+            pModule->Compile();
+
+        return pMeth && (!bOnlyPublic || !pMeth->IsSet(SbxFlagBits::Private));
+    }
+
+    for (auto const& rModuleRef : pBasic->GetModules())
+    {
+        SbMethod* pMeth = rModuleRef->FindMethod(sMacro, SbxClassType::Method);
+        if (pMeth)
         {
-            StarBASIC* pBasic = pBasicMgr->GetLib( sLibrary );
-            if ( !pBasic )
+            if (rModuleRef->GetName() == sSkipModule)
+                continue;
+
+            if (bOnlyPublic)
             {
-                sal_uInt16 nId = pBasicMgr->GetLibId( sLibrary );
-                pBasicMgr->LoadLib( nId );
-                pBasic = pBasicMgr->GetLib( sLibrary );
-            }
-            if ( pBasic )
-            {
-                if ( !sMod.isEmpty() ) // we wish to find the macro is a specific module
-                {
-                    SbModule* pModule = pBasic->FindModule( sMod );
-                    if ( pModule && pModule->FindMethod( sMacro, SbxClassType::Method ))
-                    {
-                        return true;
-                    }
-                }
-                else
-                {
-                    for (auto const& rModuleRef : pBasic->GetModules())
-                    {
-                        if (rModuleRef && rModuleRef->FindMethod(sMacro, SbxClassType::Method))
-                        {
-                            sMod = rModuleRef->GetName();
-                            return true;
-                        }
-                    }
-                }
+                if (!rModuleRef->IsCompiled())
+                    rModuleRef->Compile();
+
+                if (pMeth->IsSet(SbxFlagBits::Private))
+                    continue;
             }
+            sMod = rModuleRef->GetName();
+            return true;
         }
     }
 #endif
@@ -243,7 +263,7 @@ static void parseMacro( const OUString& sMacro, OUString& sContainer, OUString&
     {
         sProcedure = sMacro.copy( nMacroDot + 1 );
 
-        sal_Int32 nContainerDot = sMacro.lastIndexOf( '.',  nMacroDot - 1 );
+        const sal_Int32 nContainerDot = sMacro.lastIndexOf('.',  nMacroDot);
         if ( nContainerDot != -1 )
         {
             sModule = sMacro.copy( nContainerDot + 1, nMacroDot - nContainerDot - 1 );
@@ -258,19 +278,23 @@ static void parseMacro( const OUString& sMacro, OUString& sContainer, OUString&
 
 #endif
 
-OUString resolveVBAMacro( SfxObjectShell const * pShell, const OUString& rLibName, const OUString& rModuleName, const OUString& rMacroName )
+OUString resolveVBAMacro(SfxObjectShell const* pShell, const OUString& rLibName,
+                         const OUString& rModuleName, const OUString& rMacroName,
+                         bool bOnlyPublic, const OUString& sSkipModule)
 {
 #if !HAVE_FEATURE_SCRIPTING
     (void) pShell;
     (void) rLibName;
     (void) rModuleName;
     (void) rMacroName;
+    (void) bOnlyPublic;
+    (void) sSkipModule;
 #else
     if( pShell )
     {
         OUString aLibName = rLibName.isEmpty() ?  getDefaultProjectName( pShell ) : rLibName ;
         OUString aModuleName = rModuleName;
-        if( hasMacro( pShell, aLibName, aModuleName, rMacroName ) )
+        if (hasMacro(pShell, aLibName, aModuleName, rMacroName, bOnlyPublic, sSkipModule))
             return aLibName + "." + aModuleName + "." + rMacroName;
     }
 #endif
@@ -441,7 +465,7 @@ MacroResolvedInfo resolveVBAMacro( SfxObjectShell* pShell, const OUString& Macro
 
     for (auto const& search : sSearchList)
     {
-        aRes.mbFound = hasMacro( pShell, search, sModule, sProcedure );
+        aRes.mbFound = hasMacro(pShell, search, sModule, sProcedure, /*bOnlyPublic=*/false, "");
         if ( aRes.mbFound )
         {
             sContainer = search;
@@ -621,95 +645,82 @@ static sal_uInt16 parseChar( sal_Unicode c )
     return nVclKey;
 }
 
-namespace {
-
-struct KeyCodeEntry
+namespace
 {
-   const char* sName;
-   sal_uInt16 nCode;
+
+constexpr frozen::unordered_map<std::u16string_view, sal_uInt16, 34> s_KeyCodes
+{
+    { u"BACKSPACE", KEY_BACKSPACE },
+    { u"BS", KEY_BACKSPACE },
+    { u"DELETE", KEY_DELETE },
+    { u"DEL", KEY_DELETE },
+    { u"DOWN", KEY_DOWN },
+    { u"UP", KEY_UP },
+    { u"LEFT", KEY_LEFT },
+    { u"RIGHT", KEY_RIGHT },
+    { u"END", KEY_END },
+    { u"ESCAPE", KEY_ESCAPE },
+    { u"ESC", KEY_ESCAPE },
+    { u"HELP", KEY_HELP },
+    { u"HOME", KEY_HOME },
+    { u"PGDN", KEY_PAGEDOWN },
+    { u"PGUP", KEY_PAGEUP },
+    { u"INSERT", KEY_INSERT },
+    { u"SCROLLLOCK", KEY_SCROLLLOCK },
+    { u"NUMLOCK", KEY_NUMLOCK },
+    { u"TAB", KEY_TAB },
+    { u"F1", KEY_F1 },
+    { u"F2", KEY_F2 },
+    { u"F3", KEY_F3 },
+    { u"F4", KEY_F4 },
+    { u"F5", KEY_F5 },
+    { u"F6", KEY_F6 },
+    { u"F7", KEY_F7 },
+    { u"F8", KEY_F8 },
+    { u"F9", KEY_F9 },
+    { u"F10", KEY_F10 },
+    { u"F11", KEY_F11 },
+    { u"F12", KEY_F12 },
+    { u"F13", KEY_F13 },
+    { u"F14", KEY_F14 },
+    { u"F15", KEY_F15 }
 };
 
-}
+} // end anonymous namespace
 
-KeyCodeEntry const aMSKeyCodesData[] = {
-    { "BACKSPACE", KEY_BACKSPACE },
-    { "BS", KEY_BACKSPACE },
-    { "DELETE", KEY_DELETE },
-    { "DEL", KEY_DELETE },
-    { "DOWN", KEY_DOWN },
-    { "UP", KEY_UP },
-    { "LEFT", KEY_LEFT },
-    { "RIGHT", KEY_RIGHT },
-    { "END", KEY_END },
-    { "ESCAPE", KEY_ESCAPE },
-    { "ESC", KEY_ESCAPE },
-    { "HELP", KEY_HELP },
-    { "HOME", KEY_HOME },
-    { "PGDN", KEY_PAGEDOWN },
-    { "PGUP", KEY_PAGEUP },
-    { "INSERT", KEY_INSERT },
-    { "SCROLLLOCK", KEY_SCROLLLOCK },
-    { "NUMLOCK", KEY_NUMLOCK },
-    { "TAB", KEY_TAB },
-    { "F1", KEY_F1 },
-    { "F2", KEY_F2 },
-    { "F3", KEY_F3 },
-    { "F4", KEY_F4 },
-    { "F5", KEY_F5 },
-    { "F6", KEY_F6 },
-    { "F7", KEY_F7 },
-    { "F8", KEY_F8 },
-    { "F9", KEY_F9 },
-    { "F10", KEY_F10 },
-    { "F11", KEY_F11 },
-    { "F12", KEY_F12 },
-    { "F13", KEY_F13 },
-    { "F14", KEY_F14 },
-    { "F15", KEY_F15 },
-};
-
-awt::KeyEvent parseKeyEvent( const OUString& Key )
+awt::KeyEvent parseKeyEvent( std::u16string_view Key )
 {
-    static std::map< OUString, sal_uInt16 > s_KeyCodes = []()
-    {
-        std::map< OUString, sal_uInt16 > tmp;
-        for (KeyCodeEntry const & i : aMSKeyCodesData)
-        {
-            tmp[ OUString::createFromAscii( i.sName ) ] = i.nCode;
-        }
-        return tmp;
-    }();
-    OUString sKeyCode;
+    std::u16string_view sKeyCode;
     sal_uInt16 nVclKey = 0;
 
     // parse the modifier if any
-    for ( int i=0; i<Key.getLength(); ++i )
+    for ( size_t i=0; i<Key.size(); ++i )
     {
         if ( ! getModifier( Key[ i ], nVclKey ) )
         {
-            sKeyCode = Key.copy( i );
+            sKeyCode = Key.substr( i );
             break;
         }
     }
 
     // check if keycode is surrounded by '{}', if so scoop out the contents
     // else it should be just one char of ( 'a-z,A-Z,0-9' )
-    if ( sKeyCode.getLength() == 1 ) // ( a single char )
+    if ( sKeyCode.size() == 1 ) // ( a single char )
     {
         nVclKey |= parseChar( sKeyCode[ 0 ] );
     }
     else // key should be enclosed in '{}'
     {
-        if ( sKeyCode.getLength() < 3 || sKeyCode[0] != '{' || sKeyCode[sKeyCode.getLength() - 1 ] != '}' )
+        if ( sKeyCode.size() < 3 || sKeyCode[0] != '{' || sKeyCode[sKeyCode.size() - 1 ] != '}' )
             throw uno::RuntimeException();
 
-        sKeyCode = sKeyCode.copy(1, sKeyCode.getLength() - 2 );
+        sKeyCode = sKeyCode.substr(1, sKeyCode.size() - 2 );
 
-        if ( sKeyCode.getLength() == 1 )
+        if ( sKeyCode.size() == 1 )
             nVclKey |= parseChar( sKeyCode[ 0 ] );
         else
         {
-            auto it = s_KeyCodes.find( sKeyCode );
+            auto it = s_KeyCodes.find(sKeyCode);
             if ( it == s_KeyCodes.end() ) // unknown or unsupported
                 throw uno::RuntimeException();
             nVclKey |= it->second;
