@@ -24,9 +24,11 @@
 #include <property.hxx>
 #include <strings.hrc>
 #include "convert.hxx"
+#include <comphelper/processfactory.hxx>
 
 #include <com/sun/star/xsd/DataTypeClass.hpp>
 #include <com/sun/star/xsd/WhiteSpaceTreatment.hpp>
+#include <o3tl/string_view.hxx>
 #include <tools/datetime.hxx>
 #include <rtl/math.hxx>
 #include <sal/log.hxx>
@@ -512,7 +514,7 @@ namespace xforms
             {
                 sal_Int32 nValue( 0 );
                 OSL_VERIFY( _rNewValue >>= nValue );
-                if ( nValue <= 0 )
+                if ( nValue < 0 )
                     _rErrorMessage = "Length limits must denote positive integer values.";
                         // TODO/eforms: localize the error message
             }
@@ -575,6 +577,133 @@ namespace xforms
         return sInfo.makeStringAndClear();
     }
 
+
+    OAnyURIType::OAnyURIType( const OUString& _rName, sal_Int16 _nTypeClass )
+        :OAnyURIType_Base( _rName, _nTypeClass )
+    {
+        m_xURLTransformer = css::util::URLTransformer::create(::comphelper::getProcessComponentContext());
+    }
+
+
+    void OAnyURIType::registerProperties()
+    {
+        OAnyURIType_Base::registerProperties();
+
+        registerMayBeVoidProperty( PROPERTY_XSD_LENGTH, PROPERTY_ID_XSD_LENGTH, css::beans::PropertyAttribute::BOUND | css::beans::PropertyAttribute::MAYBEVOID,
+            &m_aLength, cppu::UnoType<sal_Int32>::get() );
+
+        registerMayBeVoidProperty( PROPERTY_XSD_MIN_LENGTH, PROPERTY_ID_XSD_MIN_LENGTH, css::beans::PropertyAttribute::BOUND | css::beans::PropertyAttribute::MAYBEVOID,
+            &m_aMinLength, cppu::UnoType<sal_Int32>::get() );
+
+        registerMayBeVoidProperty( PROPERTY_XSD_MAX_LENGTH, PROPERTY_ID_XSD_MAX_LENGTH, css::beans::PropertyAttribute::BOUND | css::beans::PropertyAttribute::MAYBEVOID,
+            &m_aMaxLength, cppu::UnoType<sal_Int32>::get() );
+    }
+
+
+    rtl::Reference<OXSDDataType> OAnyURIType::createClone( const OUString& _rName ) const
+    {
+        return new OAnyURIType( _rName, getTypeClass() );
+    }
+    void OAnyURIType::initializeClone( const OXSDDataType& _rCloneSource )
+    {
+        OAnyURIType_Base::initializeClone( _rCloneSource );
+        initializeTypedClone( static_cast< const OAnyURIType& >( _rCloneSource ) );
+    }
+
+
+
+    void OAnyURIType::initializeTypedClone( const OAnyURIType& _rCloneSource )
+    {
+        m_aLength       = _rCloneSource.m_aLength;
+        m_aMinLength    = _rCloneSource.m_aMinLength;
+        m_aMaxLength    = _rCloneSource.m_aMaxLength;
+    }
+
+
+    bool OAnyURIType::checkPropertySanity( sal_Int32 _nHandle, const Any& _rNewValue, OUString& _rErrorMessage )
+    {
+        // let the base class do the conversion
+        if ( !OAnyURIType_Base::checkPropertySanity( _nHandle, _rNewValue, _rErrorMessage ) )
+            return false;
+
+        _rErrorMessage.clear();
+        switch ( _nHandle )
+        {
+            case PROPERTY_ID_XSD_LENGTH:
+            case PROPERTY_ID_XSD_MIN_LENGTH:
+            case PROPERTY_ID_XSD_MAX_LENGTH:
+            {
+                sal_Int32 nValue( 0 );
+                OSL_VERIFY( _rNewValue >>= nValue );
+                if ( nValue < 0 )
+                    _rErrorMessage = "Length limits must denote positive integer values.";
+                        // TODO/eforms: localize the error message
+            }
+            break;
+        }
+
+        return _rErrorMessage.isEmpty();
+    }
+
+
+    TranslateId OAnyURIType::_validate( const OUString& rValue )
+    {
+        // check regexp, whitespace etc. in parent class
+        TranslateId pReason = OAnyURIType_Base::_validate( rValue );
+
+        if (!pReason)
+        {
+            // check AnyURI constraints
+            sal_Int32 nLength = rValue.getLength();
+            sal_Int32 nLimit = 0;
+            if ( m_aLength >>= nLimit )
+            {
+                if ( nLimit != nLength )
+                    pReason = RID_STR_XFORMS_VALUE_LENGTH;
+            }
+            else
+            {
+                if ( ( m_aMaxLength >>= nLimit ) && ( nLength > nLimit ) )
+                    pReason = RID_STR_XFORMS_VALUE_MAX_LENGTH;
+                else if ( ( m_aMinLength >>= nLimit ) && ( nLength < nLimit ) )
+                    pReason = RID_STR_XFORMS_VALUE_MIN_LENGTH;
+            }
+            // check URL
+            css::util::URL aCommandURL;
+            aCommandURL.Complete = rValue;
+            if (!m_xURLTransformer->parseStrict(aCommandURL))
+                pReason = RID_STR_XFORMS_INVALID_VALUE;
+
+        }
+        return pReason;
+    }
+
+    OUString OAnyURIType::_explainInvalid(TranslateId rReason)
+    {
+        sal_Int32 nValue = 0;
+        OUStringBuffer sInfo;
+        if (rReason == RID_STR_XFORMS_VALUE_LENGTH)
+        {
+            if( m_aLength >>= nValue )
+                sInfo.append( nValue );
+        }
+        else if (rReason == RID_STR_XFORMS_VALUE_MAX_LENGTH)
+        {
+            if( m_aMaxLength >>= nValue )
+                sInfo.append( nValue );
+        }
+        else if (rReason == RID_STR_XFORMS_VALUE_MIN_LENGTH)
+        {
+            if( m_aMinLength >>= nValue )
+                sInfo.append( nValue );
+        }
+        else if (rReason)
+        {
+            sInfo.append(OAnyURIType_Base::_explainInvalid(rReason));
+        }
+        return sInfo.makeStringAndClear();
+    }
+
     OBooleanType::OBooleanType( const OUString& _rName )
         :OBooleanType_Base( _rName, DataTypeClass::BOOLEAN )
     {
@@ -730,7 +859,15 @@ namespace xforms
 
     bool ODateType::_getValue( const OUString& value, double& fValue )
     {
-        Any aTypeValue = Convert::get().toAny( value, getCppuType() );
+        Any aTypeValue;
+        try
+        {
+            aTypeValue = Convert::get().toAny( value, getCppuType() );
+        }
+        catch (com::sun::star::lang::IllegalArgumentException)
+        {
+            return false;
+        }
 
         Date aValue;
         if ( !( aTypeValue >>= aValue ) )
@@ -779,7 +916,15 @@ namespace xforms
 
     bool OTimeType::_getValue( const OUString& value, double& fValue )
     {
-        Any aTypedValue = Convert::get().toAny( value, getCppuType() );
+        Any aTypedValue;
+        try
+        {
+            aTypedValue = Convert::get().toAny( value, getCppuType() );
+        }
+        catch (com::sun::star::lang::IllegalArgumentException)
+        {
+            return false;
+        }
 
         css::util::Time aValue;
         if ( !( aTypedValue >>= aValue ) )
@@ -851,7 +996,15 @@ namespace xforms
 
     bool ODateTimeType::_getValue( const OUString& value, double& fValue )
     {
-        Any aTypedValue = Convert::get().toAny( value, getCppuType() );
+        Any aTypedValue;
+        try
+        {
+            aTypedValue = Convert::get().toAny( value, getCppuType() );
+        }
+        catch (com::sun::star::uno::RuntimeException)
+        {
+            return false;
+        }
 
         DateTime aValue;
         if ( !( aTypedValue >>= aValue ) )
@@ -896,19 +1049,91 @@ namespace xforms
         initializeTypedClone( static_cast< const OShortIntegerType& >( _rCloneSource ) );
     }
 
+    static bool lcl_getValueYear( std::u16string_view value, double& fValue )
+    {
+        if (value.size() > 4)
+        {
+             fValue = 0;
+             return false;
+        }
+        if (o3tl::equalsAscii(value, "0"))
+        {
+            fValue = 0;
+            return true;
+        }
+        sal_Int32 int32Value = o3tl::toInt32(value);
+        if (
+            int32Value == 0 ||
+            int32Value < 0 ||
+            int32Value > 10000
+           )
+        {
+             fValue = 0;
+             return false;
+        }
+        fValue = static_cast<double>(static_cast<sal_Int16>(int32Value));
+        return true;
+    }
+
+    static bool lcl_getValueMonth( std::u16string_view value, double& fValue )
+    {
+        if (value.size() > 2)
+        {
+             fValue = 0;
+             return false;
+        }
+        sal_Int32 int32Value = o3tl::toInt32(value);
+        if (
+            int32Value == 0 ||
+            int32Value < 1 ||
+            int32Value > 12
+           )
+        {
+             fValue = 0;
+             return false;
+        }
+        fValue = static_cast<double>(static_cast<sal_Int16>(int32Value));
+        return true;
+    }
+
+    static bool lcl_getValueDay( std::u16string_view value, double& fValue )
+    {
+        if (value.size() > 2)
+        {
+             fValue = 0;
+             return false;
+        }
+        sal_Int32 int32Value = o3tl::toInt32(value);
+        if (
+            int32Value == 0 ||
+            int32Value < 1 ||
+            int32Value > 31
+           )
+        {
+             fValue = 0;
+             return false;
+        }
+        fValue = static_cast<double>(static_cast<sal_Int16>(int32Value));
+        return true;
+    }
+
     bool OShortIntegerType::_getValue( const OUString& value, double& fValue )
     {
-        fValue = static_cast<double>(static_cast<sal_Int16>(value.toInt32()));
-        // TODO/eforms
-        // this does not care for values which do not fit into a sal_Int16, but simply
-        // cuts them down. A better implementation here should probably return <FALSE/>
-        // for those values.
-        // Else, we may have a situation where the UI claims an input to be valid
-        // (say "12345678"), while internally, and at submission time, this is cut to
-        // some smaller value.
+        switch (this->getTypeClass())
+        {
+            case css::xsd::DataTypeClass::gYear:
+                return lcl_getValueYear(value, fValue);
 
-        // Additionally, this of course does not care for strings which are no numbers...
-        return true;
+            case css::xsd::DataTypeClass::gMonth:
+                return lcl_getValueMonth(value, fValue);
+
+            case css::xsd::DataTypeClass::gDay:
+                return lcl_getValueDay(value, fValue);
+            default:
+                // for the moment, the only types which derive from OShortIntegerType are:
+                // gYear, gMonth and gDay, see ODataTypeRepository ctr
+                return false;
+        }
     }
 
 
