@@ -125,6 +125,7 @@ public:
     virtual void SAL_CALL insertSettings( const OUString& NewResourceURL, const css::uno::Reference< css::container::XIndexAccess >& aNewData ) override;
     virtual css::uno::Reference< css::uno::XInterface > SAL_CALL getImageManager() override;
     virtual css::uno::Reference< css::ui::XAcceleratorConfiguration > SAL_CALL getShortCutManager() override;
+    virtual css::uno::Reference< css::ui::XAcceleratorConfiguration > SAL_CALL createShortCutManager() override;
     virtual css::uno::Reference< css::uno::XInterface > SAL_CALL getEventsManager() override;
 
     // XModuleUIConfigurationManager
@@ -236,16 +237,15 @@ std::u16string_view UIELEMENTTYPENAMES[] =
     u"" UIELEMENTTYPE_TOOLPANEL_NAME
 };
 
-const char       RESOURCEURL_PREFIX[] = "private:resource/";
-const sal_Int32  RESOURCEURL_PREFIX_SIZE = strlen(RESOURCEURL_PREFIX);
+constexpr std::u16string_view RESOURCEURL_PREFIX = u"private:resource/";
 
-sal_Int16 RetrieveTypeFromResourceURL( const OUString& aResourceURL )
+sal_Int16 RetrieveTypeFromResourceURL( std::u16string_view aResourceURL )
 {
 
-    if (( aResourceURL.startsWith( RESOURCEURL_PREFIX ) ) &&
-        ( aResourceURL.getLength() > RESOURCEURL_PREFIX_SIZE ))
+    if (( o3tl::starts_with(aResourceURL, RESOURCEURL_PREFIX ) ) &&
+        ( aResourceURL.size() > RESOURCEURL_PREFIX.size() ))
     {
-        std::u16string_view aTmpStr = aResourceURL.subView( RESOURCEURL_PREFIX_SIZE );
+        std::u16string_view aTmpStr = aResourceURL.substr( RESOURCEURL_PREFIX.size() );
         size_t nIndex = aTmpStr.find( '/' );
         if (( nIndex > 0 ) &&  ( aTmpStr.size() > nIndex ))
         {
@@ -261,14 +261,15 @@ sal_Int16 RetrieveTypeFromResourceURL( const OUString& aResourceURL )
     return ui::UIElementType::UNKNOWN;
 }
 
-OUString RetrieveNameFromResourceURL( const OUString& aResourceURL )
+OUString RetrieveNameFromResourceURL( std::u16string_view aResourceURL )
 {
-    if (( aResourceURL.startsWith( RESOURCEURL_PREFIX ) ) &&
-        ( aResourceURL.getLength() > RESOURCEURL_PREFIX_SIZE ))
+    if (( o3tl::starts_with(aResourceURL, RESOURCEURL_PREFIX ) ) &&
+        ( aResourceURL.size() > RESOURCEURL_PREFIX.size() ))
     {
-        sal_Int32 nIndex = aResourceURL.lastIndexOf( '/' );
-        if (( nIndex > 0 ) && (( nIndex+1 ) < aResourceURL.getLength()))
-            return aResourceURL.copy( nIndex+1 );
+        size_t nIndex = aResourceURL.rfind( '/' );
+
+        if ( nIndex > 0 && nIndex != std::u16string_view::npos && (( nIndex+1 ) < aResourceURL.size()) )
+            return OUString(aResourceURL.substr( nIndex+1 ));
     }
 
     return OUString();
@@ -285,8 +286,8 @@ void ModuleUIConfigurationManager::impl_fillSequenceWithElementTypeInfo( UIEleme
     OUString aCustomUrlPrefix( "custom_" );
     for (auto const& userElement : rUserElements)
     {
-        sal_Int32 nIndex = userElement.second.aResourceURL.indexOf( aCustomUrlPrefix, RESOURCEURL_PREFIX_SIZE );
-        if ( nIndex > RESOURCEURL_PREFIX_SIZE )
+        sal_Int32 nIndex = userElement.second.aResourceURL.indexOf( aCustomUrlPrefix, RESOURCEURL_PREFIX.size() );
+        if ( nIndex > static_cast<sal_Int32>(RESOURCEURL_PREFIX.size()) )
         {
             // Performance: Retrieve user interface name only for custom user interface elements.
             // It's only used by them!
@@ -321,8 +322,8 @@ void ModuleUIConfigurationManager::impl_fillSequenceWithElementTypeInfo( UIEleme
         UIElementInfoHashMap::const_iterator pIterInfo = aUIElementInfoCollection.find( defaultElement.second.aResourceURL );
         if ( pIterInfo == aUIElementInfoCollection.end() )
         {
-            sal_Int32 nIndex = defaultElement.second.aResourceURL.indexOf( aCustomUrlPrefix, RESOURCEURL_PREFIX_SIZE );
-            if ( nIndex > RESOURCEURL_PREFIX_SIZE )
+            sal_Int32 nIndex = defaultElement.second.aResourceURL.indexOf( aCustomUrlPrefix, RESOURCEURL_PREFIX.size() );
+            if ( nIndex > static_cast<sal_Int32>(RESOURCEURL_PREFIX.size()) )
             {
                 // Performance: Retrieve user interface name only for custom user interface elements.
                 // It's only used by them!
@@ -429,7 +430,7 @@ void ModuleUIConfigurationManager::impl_requestUIElementData( sal_Int16 nElement
                         {
                             MenuConfiguration aMenuCfg( m_xContext );
                             Reference< XIndexAccess > xContainer( aMenuCfg.CreateMenuBarConfigurationFromXML( xInputStream ));
-                            auto pRootItemContainer = comphelper::getFromUnoTunnel<RootItemContainer>( xContainer );
+                            auto pRootItemContainer = dynamic_cast<RootItemContainer*>( xContainer.get() );
                             if ( pRootItemContainer )
                                 aUIElementData.xSettings = new ConstItemContainer( pRootItemContainer, true );
                             else
@@ -448,7 +449,7 @@ void ModuleUIConfigurationManager::impl_requestUIElementData( sal_Int16 nElement
                         {
                             Reference< XIndexContainer > xIndexContainer( new RootItemContainer() );
                             ToolBoxConfiguration::LoadToolBox( m_xContext, xInputStream, xIndexContainer );
-                            auto pRootItemContainer = comphelper::getFromUnoTunnel<RootItemContainer>( xIndexContainer );
+                            auto pRootItemContainer = dynamic_cast<RootItemContainer*>( xIndexContainer.get() );
                             aUIElementData.xSettings = new ConstItemContainer( pRootItemContainer, true );
                             return;
                         }
@@ -465,7 +466,7 @@ void ModuleUIConfigurationManager::impl_requestUIElementData( sal_Int16 nElement
                         {
                             Reference< XIndexContainer > xIndexContainer( new RootItemContainer() );
                             StatusBarConfiguration::LoadStatusBar( m_xContext, xInputStream, xIndexContainer );
-                            auto pRootItemContainer = comphelper::getFromUnoTunnel<RootItemContainer>( xIndexContainer );
+                            auto pRootItemContainer = dynamic_cast<RootItemContainer*>( xIndexContainer.get() );
                             aUIElementData.xSettings = new ConstItemContainer( pRootItemContainer, true );
                             return;
                         }
@@ -1422,6 +1423,11 @@ Reference< XInterface > SAL_CALL ModuleUIConfigurationManager::getImageManager()
     return Reference< XInterface >( static_cast<cppu::OWeakObject*>(m_xModuleImageManager.get()), UNO_QUERY );
 }
 
+Reference< ui::XAcceleratorConfiguration > SAL_CALL ModuleUIConfigurationManager::createShortCutManager()
+{
+    return ui::ModuleAcceleratorConfiguration::createWithModuleIdentifier(m_xContext, m_aModuleIdentifier);
+}
+
 Reference< ui::XAcceleratorConfiguration > SAL_CALL ModuleUIConfigurationManager::getShortCutManager()
 {
     SolarMutexGuard g;
