@@ -29,12 +29,15 @@
 #include <oox/helper/propertyset.hxx>
 #include <oox/token/properties.hxx>
 #include <oox/token/tokens.hxx>
+#include <oox/token/tokenmap.hxx>
 #include <tools/color.hxx>
 #include <com/sun/star/table/BorderLineStyle.hpp>
 #include <com/sun/star/table/BorderLine2.hpp>
 #include <com/sun/star/drawing/TextVerticalAdjust.hpp>
 #include <com/sun/star/text/XText.hpp>
 #include <com/sun/star/text/WritingMode.hpp>
+#include <comphelper/propertysequence.hxx>
+#include <comphelper/propertyvalue.hxx>
 
 using namespace ::oox::core;
 using namespace ::com::sun::star;
@@ -583,10 +586,36 @@ void TableCell::pushToXCell( const ::oox::core::XmlFilterBase& rFilterBase, cons
         }
     }
 
-    if (getVertToken() == XML_vert)
+    if ( getVertToken() == XML_vert )
+    {
         xPropSet->setPropertyValue("RotateAngle", Any(short(27000)));
-    else if (getVertToken() == XML_vert270)
+    }
+    else if ( getVertToken() == XML_vert270 )
+    {
         xPropSet->setPropertyValue("RotateAngle", Any(short(9000)));
+    }
+    else if ( getVertToken() != XML_horz && getVertToken() != XML_eaVert )
+    {
+        // put the vert value in the grab bag for roundtrip
+        const Sequence<sal_Int8>& aTokenNameSeq = StaticTokenMap().getUtf8TokenName(getVertToken());
+        const OUString aTokenName{ reinterpret_cast<const char*>(aTokenNameSeq.getConstArray()),
+                                   aTokenNameSeq.getLength(), RTL_TEXTENCODING_UTF8 };
+
+        Sequence<PropertyValue> aGrabBag;
+        xPropSet->getPropertyValue("CellInteropGrabBag") >>= aGrabBag;
+        PropertyValue aPropertyValue = comphelper::makePropertyValue("mso-tcPr-vert-value", aTokenName);
+        if (aGrabBag.hasElements())
+        {
+            sal_Int32 nLength = aGrabBag.getLength();
+            aGrabBag.realloc(nLength + 1);
+            aGrabBag.getArray()[nLength] = aPropertyValue;
+        }
+        else
+        {
+            aGrabBag = { aPropertyValue };
+        }
+        xPropSet->setPropertyValue("CellInteropGrabBag", Any(aGrabBag));
+    }
 }
 
 }
