@@ -206,7 +206,8 @@ void PPTShape::addShape(
                    case XML_obj :
                 {
                     sServiceName = sOutlinerShapeService;
-                    aMasterTextListStyle = rSlidePersist.getMasterPersist() ? rSlidePersist.getMasterPersist()->getBodyTextStyle() : rSlidePersist.getBodyTextStyle();
+                    if (getSubTypeIndex().has_value())
+                        aMasterTextListStyle = rSlidePersist.getMasterPersist() ? rSlidePersist.getMasterPersist()->getBodyTextStyle() : rSlidePersist.getBodyTextStyle();
                 }
                 break;
                 case XML_body :
@@ -335,8 +336,10 @@ void PPTShape::addShape(
         // Need to use service name css.drawing.CustomShape if they have a non default shape.
         // This workaround has the drawback of them not really being processed as placeholders
         // so it is only done for slide footers...
-        if ((mnSubType == XML_sldNum || mnSubType == XML_dt || mnSubType == XML_ftr)
-            && meShapeLocation == Slide && !mpCustomShapePropertiesPtr->representsDefaultShape())
+        bool convertInSlideMode = meShapeLocation == Slide &&
+            (mnSubType == XML_sldNum || mnSubType == XML_dt || mnSubType == XML_ftr || mnSubType == XML_body);
+        bool convertInLayoutMode = meShapeLocation == Layout && (mnSubType == XML_body);
+        if ((convertInSlideMode || convertInLayoutMode) && !mpCustomShapePropertiesPtr->representsDefaultShape())
         {
             sServiceName = "com.sun.star.drawing.CustomShape";
         }
@@ -454,6 +457,10 @@ void PPTShape::addShape(
                 Reference < XText > xText(mxShape, UNO_QUERY);
                 if (xText.is())
                 {
+                    if (mpPlaceholder && mpPlaceholder->getTextBody() && !mpPlaceholder->getTextBody()->isEmpty()
+                        && mpPlaceholder->hasCustomPrompt())
+                        xText->setString(mpPlaceholder->getTextBody()->toString());
+
                     TextCharacterProperties aCharStyleProperties;
                     getTextBody()->ApplyStyleEmpty(rFilterBase, xText, aCharStyleProperties, mpMasterTextListStyle);
                 }
