@@ -42,6 +42,7 @@
 #include <com/sun/star/awt/PopupMenuDirection.hpp>
 #include <com/sun/star/frame/XPopupMenuController.hpp>
 #include <comphelper/propertyvalue.hxx>
+#include <toolkit/awt/vclxmenu.hxx>
 #include <toolkit/helper/convert.hxx>
 #include <comphelper/diagnose_ex.hxx>
 #include <RptDef.hxx>
@@ -267,7 +268,7 @@ void OReportSection::Paste(const uno::Sequence< beans::NamedValue >& _aAllreadyC
                                 pNewObj->SetLogicRect(aRet);
                             }
                         }
-                        m_pView->AddUndo( m_pView->GetModel()->GetSdrUndoFactory().CreateUndoNewObject( *pNewObj ) );
+                        m_pView->AddUndo(m_pView->GetModel().GetSdrUndoFactory().CreateUndoNewObject(*pNewObj));
                         m_pView->MarkObj( pNewObj.get(), m_pView->GetSdrPageView() );
                         if ( m_xSection.is() && (o3tl::make_unsigned(aRet.getOpenHeight() + aRet.Top()) > m_xSection->getHeight()) )
                             m_xSection->setHeight(aRet.getOpenHeight() + aRet.Top());
@@ -329,7 +330,7 @@ void OReportSection::Copy(uno::Sequence< beans::NamedValue >& _rAllreadyCopiedOb
     ::std::vector< uno::Reference<report::XReportComponent> > aCopies;
     aCopies.reserve(nMark);
 
-    SdrUndoFactory& rUndo = m_pView->GetModel()->GetSdrUndoFactory();
+    SdrUndoFactory& rUndo = m_pView->GetModel().GetSdrUndoFactory();
 
     for( size_t i = nMark; i > 0; )
     {
@@ -434,9 +435,7 @@ void OReportSection::Command( const CommandEvent& _rCEvt )
     if (!xMenuController.is())
         return;
 
-    css::uno::Reference<css::awt::XPopupMenu> xPopupMenu(
-        xContext->getServiceManager()->createInstanceWithContext(
-        "com.sun.star.awt.PopupMenu", xContext), css::uno::UNO_QUERY);
+    rtl::Reference<VCLXPopupMenu> xPopupMenu = new VCLXPopupMenu();
 
     if (!xPopupMenu.is())
         return;
