@@ -133,7 +133,7 @@ SfxPrinter* ScDocument::GetPrinter(bool bCreateIfNotExist)
         mpPrinter = VclPtr<SfxPrinter>::Create( std::move(pSet) );
         mpPrinter->SetMapMode(MapMode(MapUnit::Map100thMM));
         UpdateDrawPrinter();
-        mpPrinter->SetDigitLanguage( SC_MOD()->GetOptDigitLanguage() );
+        mpPrinter->SetDigitLanguage( ScModule::GetOptDigitLanguage() );
     }
 
     return mpPrinter;
@@ -153,7 +153,7 @@ void ScDocument::SetPrinter( VclPtr<SfxPrinter> const & pNewPrinter )
         ScopedVclPtr<SfxPrinter> xKeepAlive( mpPrinter );
         mpPrinter = pNewPrinter;
         UpdateDrawPrinter();
-        mpPrinter->SetDigitLanguage( SC_MOD()->GetOptDigitLanguage() );
+        mpPrinter->SetDigitLanguage( ScModule::GetOptDigitLanguage() );
     }
     InvalidateTextWidth(nullptr, nullptr, false);     // in both cases
 }
@@ -186,7 +186,7 @@ VirtualDevice* ScDocument::GetVirtualDevice_100th_mm()
 #ifdef IOS
         mpVirtualDevice_100th_mm = VclPtr<VirtualDevice>::Create(DeviceFormat::GRAYSCALE);
 #else
-        mpVirtualDevice_100th_mm = VclPtr<VirtualDevice>::Create(DeviceFormat::DEFAULT);
+        mpVirtualDevice_100th_mm = VclPtr<VirtualDevice>::Create(DeviceFormat::WITHOUT_ALPHA);
 #endif
         mpVirtualDevice_100th_mm->SetReferenceDevice(VirtualDevice::RefDevMode::MSO1);
         MapMode aMapMode( mpVirtualDevice_100th_mm->GetMapMode() );
@@ -225,7 +225,7 @@ void ScDocument::ModifyStyleSheet( SfxStyleSheetBase& rStyleSheet,
                 if ( (nOldScale != nNewScale) || (nOldScaleToPages != nNewScaleToPages) )
                     InvalidateTextWidth( rStyleSheet.GetName() );
 
-                if( SvtCTLOptions().IsCTLFontEnabled() )
+                if( SvtCTLOptions::IsCTLFontEnabled() )
                 {
                     if( rChanges.GetItemState(ATTR_WRITINGDIR ) == SfxItemState::SET )
                         ScChartHelper::DoUpdateAllCharts( *this );
