@@ -74,7 +74,7 @@ struct ScFuncDescCore
     /*
      * Help ID, HID_FUNC_...
      */
-    const char* pHelpId;
+    OUString pHelpId;
     /*
      * Number of parameters. VAR_ARGS if variable number, or
      * VAR_ARGS+number if number of fixed parameters and variable
@@ -161,8 +161,7 @@ OUString ScFuncDesc::GetParamList() const
                 aSig.append(maDefArgNames[i]);
                 if ( i != nArgCount-1 )
                 {
-                    aSig.append(sep);
-                    aSig.append( " " );
+                    aSig.append(sep + " " );
                 }
             }
             // If only suppressed parameters follow the last added parameter,
@@ -175,46 +174,35 @@ OUString ScFuncDesc::GetParamList() const
         {
             for ( sal_uInt16 nArg = 0; nArg < nVarArgsStart; nArg++ )
             {
-                aSig.append(maDefArgNames[nArg]);
-                aSig.append(sep);
-                aSig.append( " " );
+                aSig.append(maDefArgNames[nArg] + sep + " ");
             }
             /* NOTE: Currently there are no suppressed var args parameters. If
              * there were, we'd have to cope with it here and above for the fix
              * parameters. For now parameters are always added, so no special
              * treatment of a trailing "; " necessary. */
-            aSig.append(maDefArgNames[nVarArgsStart]);
-            aSig.append('1');
-            aSig.append(sep);
-            aSig.append(' ');
-            aSig.append(maDefArgNames[nVarArgsStart]);
-            aSig.append('2');
-            aSig.append(sep);
-            aSig.append(" ... ");
+            aSig.append(maDefArgNames[nVarArgsStart]
+                + "1"
+                + sep + " "
+                + maDefArgNames[nVarArgsStart]
+                + "2"
+                + sep + " ... ");
         }
         else
         {
             for ( sal_uInt16 nArg = 0; nArg < nVarArgsStart; nArg++ )
             {
-                aSig.append(maDefArgNames[nArg]);
-                aSig.append(sep);
-                aSig.append( " " );
+                aSig.append(maDefArgNames[nArg] + sep + " ");
             }
 
-            aSig.append(maDefArgNames[nVarArgsStart]);
-            aSig.append('1');
-            aSig.append(sep);
-            aSig.append(maDefArgNames[nVarArgsStart+1]);
-            aSig.append('1');
-            aSig.append(sep);
-            aSig.append( " " );
-            aSig.append(maDefArgNames[nVarArgsStart]);
-            aSig.append('2');
-            aSig.append(sep);
-            aSig.append(maDefArgNames[nVarArgsStart+1]);
-            aSig.append('2');
-            aSig.append(sep);
-            aSig.append( " ... " );
+            aSig.append(maDefArgNames[nVarArgsStart]
+                + "1" + sep
+                + maDefArgNames[nVarArgsStart+1]
+                + "1" + sep
+                + " "
+                + maDefArgNames[nVarArgsStart]
+                + "2" + sep
+                + maDefArgNames[nVarArgsStart+1]
+                + "2" + sep + " ... " );
         }
     }
 
@@ -232,11 +220,9 @@ OUString ScFuncDesc::getSignature() const
         OUString aParamList = GetParamList();
         if( !aParamList.isEmpty() )
         {
-            aSig.append( "( " );
-            aSig.append(aParamList);
+            aSig.append( "( " + aParamList
             // U+00A0 (NBSP) prevents automatic line break
-            aSig.append( u'\x00A0' );
-            aSig.append( ")" );
+                + u"\x00A0" ")" );
         }
         else
             aSig.append( "()" );
@@ -252,9 +238,7 @@ OUString ScFuncDesc::getFormula( const ::std::vector< OUString >& _aArguments )
 
     if(mxFuncName)
     {
-        aFormula.append( *mxFuncName );
-
-        aFormula.append( "(" );
+        aFormula.append( *mxFuncName + "(" );
         if ( nArgCount > 0 && !_aArguments.empty() && !_aArguments[0].isEmpty())
         {
             ::std::vector< OUString >::const_iterator aIter = _aArguments.begin();
@@ -264,8 +248,7 @@ OUString ScFuncDesc::getFormula( const ::std::vector< OUString >& _aArguments )
             ++aIter;
             while( aIter != aEnd && !aIter->isEmpty() )
             {
-                aFormula.append( sep );
-                aFormula.append( *aIter );
+                aFormula.append( sep + *aIter );
                 ++aIter;
             }
         }
@@ -350,7 +333,7 @@ void ScFuncDesc::initArgumentInfo()  const
     }
 }
 
-OString ScFuncDesc::getHelpId() const
+OUString ScFuncDesc::getHelpId() const
 {
     return sHelpId;
 }
@@ -397,7 +380,8 @@ bool ScFuncDesc::compareByName(const ScFuncDesc* a, const ScFuncDesc* b)
 
 #define ENTRY(CODE) CODE, SAL_N_ELEMENTS(CODE)
 
-ScFunctionList::ScFunctionList()
+ScFunctionList::ScFunctionList( bool bEnglishFunctionNames )
+    : mbEnglishFunctionNames( bEnglishFunctionNames )
 {
     sal_Int32  nMaxFuncNameLen = 0; // Length of longest function name
 
@@ -601,7 +585,7 @@ ScFunctionList::ScFunctionList()
         { SC_OPCODE_AREAS, ENTRY(SC_OPCODE_AREAS_ARY), 0, ID_FUNCTION_GRP_TABLE, HID_FUNC_BEREICHE, 1, { 0 }, 0 },
         { SC_OPCODE_CURRENCY, ENTRY(SC_OPCODE_CURRENCY_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_DM, 2, { 0, 1 }, 0 },
         { SC_OPCODE_REPLACE, ENTRY(SC_OPCODE_REPLACE_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_ERSETZEN, 4, { 0, 0, 0, 0 }, 0 },
-        { SC_OPCODE_FIXED, ENTRY(SC_OPCODE_FIXED_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_FEST, 3, { 0, 0, 1 }, 0 },
+        { SC_OPCODE_FIXED, ENTRY(SC_OPCODE_FIXED_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_FEST, 3, { 0, 1, 1 }, 0 },
         { SC_OPCODE_FIND, ENTRY(SC_OPCODE_FIND_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_FINDEN, 3, { 0, 0, 1 }, 0 },
         { SC_OPCODE_EXACT, ENTRY(SC_OPCODE_EXACT_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_IDENTISCH, 2, { 0, 0 }, 0 },
         { SC_OPCODE_LEFT, ENTRY(SC_OPCODE_LEFT_ARY), 0, ID_FUNCTION_GRP_TEXT, HID_FUNC_LINKS, 2, { 0, 1 }, 0 },
@@ -958,7 +942,7 @@ ScFunctionList::ScFunctionList()
         pDesc = new ScFuncDesc;
         pDesc->nFIndex = nNextId++;
 
-        if ( pUnoAddIns->FillFunctionDesc( nFunc, *pDesc ) )
+        if ( pUnoAddIns->FillFunctionDesc( nFunc, *pDesc, mbEnglishFunctionNames ) )
         {
             tmpFuncVector.push_back(pDesc);
             nStrLen = pDesc->mxFuncName->getLength();
