@@ -158,7 +158,8 @@ bool ScQueryEvaluator::isQueryByValue(ScQueryOp eOp, ScQueryEntry::QueryType eTy
 
 bool ScQueryEvaluator::isQueryByValueForCell(const ScRefCellValue& rCell)
 {
-    if (rCell.meType == CELLTYPE_FORMULA && rCell.mpFormula->GetErrCode() != FormulaError::NONE)
+    if (rCell.getType() == CELLTYPE_FORMULA
+        && rCell.getFormula()->GetErrCode() != FormulaError::NONE)
         // Error values are compared as string.
         return false;
 
@@ -202,13 +203,13 @@ std::pair<bool, bool> ScQueryEvaluator::compareByValue(const ScRefCellValue& rCe
     // reason.
     sal_uInt32 nNumFmt = NUMBERFORMAT_ENTRY_NOT_FOUND;
 
-    switch (rCell.meType)
+    switch (rCell.getType())
     {
         case CELLTYPE_VALUE:
-            nCellVal = rCell.mfValue;
+            nCellVal = rCell.getDouble();
             break;
         case CELLTYPE_FORMULA:
-            nCellVal = rCell.mpFormula->GetValue();
+            nCellVal = rCell.getFormula()->GetValue();
             break;
         default:
             nCellVal = 0.0;
@@ -218,7 +219,7 @@ std::pair<bool, bool> ScQueryEvaluator::compareByValue(const ScRefCellValue& rCe
         nNumFmt = getNumFmt(nCol, nRow);
         if (nNumFmt)
         {
-            switch (rCell.meType)
+            switch (rCell.getType())
             {
                 case CELLTYPE_VALUE:
                 case CELLTYPE_FORMULA:
@@ -300,10 +301,11 @@ std::pair<bool, bool> ScQueryEvaluator::compareByValue(const ScRefCellValue& rCe
 OUString ScQueryEvaluator::getCellString(const ScRefCellValue& rCell, SCROW nRow, SCCOL nCol,
                                          const svl::SharedString** sharedString)
 {
-    if (rCell.meType == CELLTYPE_FORMULA && rCell.mpFormula->GetErrCode() != FormulaError::NONE)
+    if (rCell.getType() == CELLTYPE_FORMULA
+        && rCell.getFormula()->GetErrCode() != FormulaError::NONE)
     {
         // Error cell is evaluated as string (for now).
-        const FormulaError error = rCell.mpFormula->GetErrCode();
+        const FormulaError error = rCell.getFormula()->GetErrCode();
         auto it = mCachedSharedErrorStrings.find(error);
         if (it == mCachedSharedErrorStrings.end())
         {
@@ -315,9 +317,9 @@ OUString ScQueryEvaluator::getCellString(const ScRefCellValue& rCell, SCROW nRow
         *sharedString = &it->second;
         return OUString();
     }
-    else if (rCell.meType == CELLTYPE_STRING)
+    else if (rCell.getType() == CELLTYPE_STRING)
     {
-        *sharedString = rCell.mpString;
+        *sharedString = rCell.getSharedString();
         return OUString();
     }
     else
@@ -591,26 +593,7 @@ std::pair<bool, bool> ScQueryEvaluator::compareByTextColor(SCCOL nCol, SCROW nRo
                                                            const ScQueryEntry::Item& rItem)
 {
     ScAddress aPos(nCol, nRow, mrTab.GetTab());
-    Color color;
-    bool bHasConditionalColor = false;
-    // Text color can be set via conditional formatting - check that first
-    const ScPatternAttr* pPattern = mrDoc.GetPattern(nCol, nRow, mrTab.GetTab());
-    if (pPattern)
-    {
-        if (!pPattern->GetItem(ATTR_CONDITIONAL).GetCondFormatData().empty())
-        {
-            const SfxItemSet* pCondSet = mrDoc.GetCondResult(nCol, nRow, mrTab.GetTab());
-            const SvxColorItem* pColor = &pPattern->GetItem(ATTR_FONT_COLOR, pCondSet);
-            color = pColor->GetValue();
-            bHasConditionalColor = true;
-        }
-    }
-
-    if (!bHasConditionalColor)
-    {
-        const SvxColorItem* pColor = mrDoc.GetAttr(aPos, ATTR_FONT_COLOR);
-        color = pColor->GetValue();
-    }
+    Color color = mrTab.GetCellTextColor(aPos);
 
     bool bMatch = rItem.maColor == color;
     return std::pair<bool, bool>(bMatch, false);
@@ -620,43 +603,7 @@ std::pair<bool, bool> ScQueryEvaluator::compareByBackgroundColor(SCCOL nCol, SCR
                                                                  const ScQueryEntry::Item& rItem)
 {
     ScAddress aPos(nCol, nRow, mrTab.GetTab());
-    Color color;
-
-    // Background color can be set via conditional formatting - check that first
-    bool bHasConditionalColor = false;
-    const ScPatternAttr* pPattern = mrDoc.GetPattern(nCol, nRow, mrTab.GetTab());
-    if (pPattern)
-    {
-        if (!pPattern->GetItem(ATTR_CONDITIONAL).GetCondFormatData().empty())
-        {
-            const SfxItemSet* pCondSet = mrDoc.GetCondResult(nCol, nRow, mrTab.GetTab());
-            const SvxBrushItem* pBackgroundColor = &pPattern->GetItem(ATTR_BACKGROUND, pCondSet);
-            color = pBackgroundColor->GetColor();
-            bHasConditionalColor = true;
-        }
-    }
-
-    ScConditionalFormat* pCondFormat = mrDoc.GetCondFormat(nCol, nRow, mrTab.GetTab());
-    if (pCondFormat)
-    {
-        for (size_t i = 0; i < pCondFormat->size(); i++)
-        {
-            auto aEntry = pCondFormat->GetEntry(i);
-            if (aEntry->GetType() == ScFormatEntry::Type::Colorscale)
-            {
-                const ScColorScaleFormat* pColFormat
-                    = static_cast<const ScColorScaleFormat*>(aEntry);
-                color = *(pColFormat->GetColor(aPos));
-                bHasConditionalColor = true;
-            }
-        }
-    }
-
-    if (!bHasConditionalColor)
-    {
-        const SvxBrushItem* pBrush = mrDoc.GetAttr(aPos, ATTR_BACKGROUND);
-        color = pBrush->GetColor();
-    }
+    Color color = mrTab.GetCellBackgroundColor(aPos);
 
     bool bMatch = rItem.maColor == color;
     return std::pair<bool, bool>(bMatch, false);
@@ -681,7 +628,8 @@ std::pair<bool, bool> ScQueryEvaluator::compareByRangeLookup(const ScRefCellValu
 
     if (rItem.meType == ScQueryEntry::ByString)
     {
-        if (rCell.meType == CELLTYPE_FORMULA && rCell.mpFormula->GetErrCode() != FormulaError::NONE)
+        if (rCell.getType() == CELLTYPE_FORMULA
+            && rCell.getFormula()->GetErrCode() != FormulaError::NONE)
             // Error values are compared as string.
             return std::pair<bool, bool>(false, bTestEqual);
 
@@ -717,13 +665,13 @@ std::pair<bool, bool> ScQueryEvaluator::processEntry(SCROW nRow, SCCOL nCol, ScR
         // For ScQueryEntry::ByValue check that the cell either is a value or is a formula
         // that has a value and is not an error (those are compared as strings). This
         // is basically simplified isQueryByValue().
-        if (aCell.meType == CELLTYPE_VALUE)
-            value = aCell.mfValue;
-        else if (aCell.meType == CELLTYPE_FORMULA
-                 && aCell.mpFormula->GetErrCode() != FormulaError::NONE
-                 && aCell.mpFormula->IsValue())
+        if (aCell.getType() == CELLTYPE_VALUE)
+            value = aCell.getDouble();
+        else if (aCell.getType() == CELLTYPE_FORMULA
+                 && aCell.getFormula()->GetErrCode() != FormulaError::NONE
+                 && aCell.getFormula()->IsValue())
         {
-            value = aCell.mpFormula->GetValue();
+            value = aCell.getFormula()->GetValue();
         }
         else
             valid = false;
@@ -763,19 +711,15 @@ std::pair<bool, bool> ScQueryEvaluator::processEntry(SCROW nRow, SCCOL nCol, ScR
         }
     }
     const svl::SharedString* cellSharedString = nullptr;
-    OUString cellString;
-    bool cellStringSet = false;
+    std::optional<OUString> oCellString;
     const bool bFastCompareByString = isFastCompareByString(rEntry);
     if (rEntry.eOp == SC_EQUAL && rItems.size() >= 10 && bFastCompareByString)
     {
         // The same as above but for strings. Try to optimize the case when
         // it's a svl::SharedString comparison. That happens when SC_EQUAL is used
         // and simple matching is used, see compareByString()
-        if (!cellStringSet)
-        {
-            cellString = getCellString(aCell, nRow, rEntry.nField, &cellSharedString);
-            cellStringSet = true;
-        }
+        if (!oCellString)
+            oCellString = getCellString(aCell, nRow, rEntry.nField, &cellSharedString);
         // Allow also checking ScQueryEntry::ByValue if the cell is not numeric,
         // as in that case isQueryByNumeric() would be false and isQueryByString() would
         // be true because of SC_EQUAL making isTextMatchOp() true.
@@ -855,18 +799,15 @@ std::pair<bool, bool> ScQueryEvaluator::processEntry(SCROW nRow, SCCOL nCol, ScR
         }
         else if (isQueryByString(rEntry.eOp, rItem.meType, aCell))
         {
-            if (!cellStringSet)
-            {
-                cellString = getCellString(aCell, nRow, rEntry.nField, &cellSharedString);
-                cellStringSet = true;
-            }
+            if (!oCellString)
+                oCellString = getCellString(aCell, nRow, rEntry.nField, &cellSharedString);
             std::pair<bool, bool> aThisRes;
             if (cellSharedString && bFastCompareByString) // fast
                 aThisRes = compareByString<true>(rEntry, rItem, cellSharedString, nullptr);
             else if (cellSharedString)
                 aThisRes = compareByString(rEntry, rItem, cellSharedString, nullptr);
             else
-                aThisRes = compareByString(rEntry, rItem, nullptr, &cellString);
+                aThisRes = compareByString(rEntry, rItem, nullptr, &*oCellString);
             aRes.first |= aThisRes.first;
             aRes.second |= aThisRes.second;
         }
