@@ -17,6 +17,10 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
+
+#include <string_view>
+
 #include <worksheetbuffer.hxx>
 
 #include <com/sun/star/container/XIndexAccess.hpp>
@@ -130,7 +134,7 @@ void WorksheetBuffer::convertSheetNameRef( OUString& sSheetNameRef ) const
         ScRange aRange;
         if ((aRange.ParseAny( sSheetNameRef.copy( nSepPos + 1 ), getScDocument(),
                         formula::FormulaGrammar::CONV_XL_R1C1) & ScRefFlags::VALID) == ScRefFlags::ZERO)
-            sSheetNameRef = sSheetNameRef.replaceAt( nSepPos, 1, OUString( '.' ) );
+            sSheetNameRef = sSheetNameRef.replaceAt( nSepPos, 1, rtl::OUStringChar( '.' ) );
     }
     // #i66592# convert sheet names that have been renamed on import
     OUString aSheetName = sSheetNameRef.copy( 1, nSepPos - 1 );
@@ -159,7 +163,7 @@ OUString WorksheetBuffer::getCalcSheetName( const OUString& rWorksheetName ) con
 
 namespace {
 
-OUString lclQuoteName( const OUString& rName )
+OUString lclQuoteName( std::u16string_view rName )
 {
     OUStringBuffer aBuffer( rName );
     // duplicate all quote characters
