@@ -373,6 +373,27 @@ void ScCheckListMenuControl::endSubMenu(ScListSubMenuControl& rSubMenu)
     }
 }
 
+void ScCheckListMenuControl::addFields(const std::vector<OUString>& aFields)
+{
+    if (!mbIsMultiField)
+        return;
+
+    mxFieldsCombo->clear();
+
+    for (auto& aField: aFields)
+        mxFieldsCombo->append_text(aField);
+
+    mxFieldsCombo->set_active(0);
+}
+
+tools::Long ScCheckListMenuControl::getField()
+{
+    if (!mbIsMultiField)
+        return -1;
+
+    return mxFieldsCombo->get_active();
+}
+
 void ScCheckListMenuControl::selectMenuItem(size_t nPos, bool bSubMenuTimer)
 {
     mxMenu->select(nPos == MENU_NOT_SELECTED ? -1 : nPos);
@@ -476,13 +497,15 @@ constexpr int nCheckListVisibleRows = 9;
 constexpr int nColorListVisibleRows = 9;
 
 ScCheckListMenuControl::ScCheckListMenuControl(weld::Widget* pParent, ScViewData& rViewData,
-                                               bool bHasDates, int nWidth)
+                                               bool bHasDates, int nWidth, bool bIsMultiField)
     : mxBuilder(Application::CreateBuilder(pParent, "modules/scalc/ui/filterdropdown.ui"))
     , mxPopover(mxBuilder->weld_popover("FilterDropDown"))
     , mxContainer(mxBuilder->weld_container("container"))
     , mxMenu(mxBuilder->weld_tree_view("menu"))
     , mxScratchIter(mxMenu->make_iterator())
     , mxNonMenu(mxBuilder->weld_widget("nonmenu"))
+    , mxFieldsComboLabel(mxBuilder->weld_label("select_field_label"))
+    , mxFieldsCombo(mxBuilder->weld_combo_box("multi_field_combo"))
     , mxEdSearch(mxBuilder->weld_entry("search_edit"))
     , mxBox(mxBuilder->weld_widget("box"))
     , mxListChecks(mxBuilder->weld_tree_view("check_list_box"))
@@ -507,6 +530,8 @@ ScCheckListMenuControl::ScCheckListMenuControl(weld::Widget* pParent, ScViewData
     , mbIsPoppedUp(false)
     , maOpenTimer(this)
     , maCloseTimer(this)
+    , maSearchEditTimer("ScCheckListMenuControl maSearchEditTimer")
+    , mbIsMultiField(bIsMultiField)
 {
     mxTreeChecks->set_clicks_to_toggle(1);
     mxListChecks->set_clicks_to_toggle(1);
@@ -555,6 +580,16 @@ ScCheckListMenuControl::ScCheckListMenuControl(weld::Widget* pParent, ScViewData
     mxListChecks->enable_toggle_buttons(weld::ColumnToggleType::Check);
 
     mxBox->show();
+    if (mbIsMultiField)
+    {
+        mxFieldsComboLabel->show();
+        mxFieldsCombo->show();
+    }
+    else
+    {
+        mxFieldsComboLabel->hide();
+        mxFieldsCombo->hide();
+    }
     mxEdSearch->show();
     mxButtonBox->show();
 
@@ -564,6 +599,8 @@ ScCheckListMenuControl::ScCheckListMenuControl(weld::Widget* pParent, ScViewData
 
     mxBtnOk->connect_clicked(LINK(this, ScCheckListMenuControl, ButtonHdl));
     mxBtnCancel->connect_clicked(LINK(this, ScCheckListMenuControl, ButtonHdl));
+    if (mbIsMultiField)
+        mxFieldsCombo->connect_changed(LINK(this, ScCheckListMenuControl, ComboChangedHdl));
     mxEdSearch->connect_changed(LINK(this, ScCheckListMenuControl, EdModifyHdl));
     mxEdSearch->connect_activate(LINK(this, ScCheckListMenuControl, EdActivateHdl));
     mxTreeChecks->connect_toggled(LINK(this, ScCheckListMenuControl, CheckHdl));
@@ -583,6 +620,9 @@ ScCheckListMenuControl::ScCheckListMenuControl(weld::Widget* pParent, ScViewData
     // bulk_insert_for_each
     mxTreeChecks->set_size_request(mnCheckWidthReq, nChecksHeight);
     mxListChecks->set_size_request(mnCheckWidthReq, nChecksHeight);
+
+    maSearchEditTimer.SetTimeout(EDIT_UPDATEDATA_TIMEOUT);
+    maSearchEditTimer.SetInvokeHandler(LINK(this, ScCheckListMenuControl, SearchEditTimeoutHdl));
 }
 
 void ScCheckListMenuControl::GrabFocus()
@@ -612,6 +652,7 @@ void ScCheckListMenuControl::DropPendingEvents()
 
 ScCheckListMenuControl::~ScCheckListMenuControl()
 {
+    maSearchEditTimer.Stop();
     EndPopupMode();
     for (auto& rMenuItem : maMenuItems)
         rMenuItem.mxSubMenuWin.reset();
@@ -663,7 +704,7 @@ IMPL_LINK(ScCheckListMenuControl, CommandHdl, const CommandEvent&, rCEvt, bool)
     mxContextMenu->set_sensitive("less", mnCheckListVisibleRows > 4);
     mxContextMenu->set_sensitive("more", mnCheckListVisibleRows < 42);
 
-    OString sCommand = mxContextMenu->popup_at_rect(mpChecks, tools::Rectangle(rCEvt.GetMousePosPixel(), Size(1,1)));
+    OUString sCommand = mxContextMenu->popup_at_rect(mpChecks, tools::Rectangle(rCEvt.GetMousePosPixel(), Size(1,1)));
     if (sCommand.isEmpty())
         return true;
 
@@ -739,7 +780,13 @@ namespace
     }
 }
 
-IMPL_LINK_NOARG(ScCheckListMenuControl, EdModifyHdl, weld::Entry&, void)
+IMPL_LINK_NOARG(ScCheckListMenuControl, ComboChangedHdl, weld::ComboBox&, void)
+{
+    if (mbIsMultiField && mxFieldChangedAction)
+        mxFieldChangedAction->execute();
+}
+
+IMPL_LINK_NOARG(ScCheckListMenuControl, SearchEditTimeoutHdl, Timer*, void)
 {
     OUString aSearchText = mxEdSearch->get_text();
     aSearchText = ScGlobal::getCharClass().lowercase( aSearchText );
@@ -875,6 +922,11 @@ IMPL_LINK_NOARG(ScCheckListMenuControl, EdModifyHdl, weld::Entry&, void)
     }
 }
 
+IMPL_LINK_NOARG(ScCheckListMenuControl, EdModifyHdl, weld::Entry&, void)
+{
+    maSearchEditTimer.Start();
+}
+
 IMPL_LINK_NOARG(ScCheckListMenuControl, EdActivateHdl, weld::Entry&, bool)
 {
     if (mxBtnOk->get_sensitive())
@@ -1068,6 +1120,15 @@ void ScCheckListMenuControl::addMember(const OUString& rName, const double nVal,
     maMembers.emplace_back(std::move(aMember));
 }
 
+void ScCheckListMenuControl::clearMembers()
+{
+    maMembers.clear();
+
+    mpChecks->freeze();
+    mpChecks->clear();
+    mpChecks->thaw();
+}
+
 std::unique_ptr<weld::TreeIter> ScCheckListMenuControl::FindEntry(const weld::TreeIter* pParent, std::u16string_view sNode)
 {
     std::unique_ptr<weld::TreeIter> xEntry = mpChecks->make_iterator(pParent);
@@ -1491,6 +1552,11 @@ void ScCheckListMenuControl::setPopupEndAction(Action* p)
     mxPopupEndAction.reset(p);
 }
 
+void ScCheckListMenuControl::setFieldChangedAction(Action* p)
+{
+    mxFieldChangedAction.reset(p);
+}
+
 IMPL_LINK_NOARG(ScCheckListMenuControl, PopupModeEndHdl, weld::Popover&, void)
 {
     mbIsPoppedUp = false;
