@@ -82,7 +82,7 @@ void ScTabViewShell::ConnectObject( const SdrOle2Obj* pObj )
     if ( pClient )
         return;
 
-    pClient = new ScClient( this, pWin, GetScDrawView()->GetModel(), pObj );
+    pClient = new ScClient( this, pWin, &GetScDrawView()->GetModel(), pObj );
     ScViewData& rViewData = GetViewData();
     ScDocShell* pDocSh = rViewData.GetDocShell();
     ScDocument& rDoc = pDocSh->GetDocument();
@@ -169,7 +169,7 @@ void ScTabViewShell::ActivateObject(SdrOle2Obj* pObj, sal_Int32 nVerb)
         bool bNegativeX = comphelper::LibreOfficeKit::isActive() && rDoc.IsNegativePage(rViewData.GetTabNo());
         SfxInPlaceClient* pClient = FindIPClient( xObj, pWin );
         if ( !pClient )
-            pClient = new ScClient( this, pWin, GetScDrawView()->GetModel(), pObj );
+            pClient = new ScClient( this, pWin, &GetScDrawView()->GetModel(), pObj );
 
         if (bNegativeX)
             pClient->SetNegativeX(true);
@@ -364,28 +364,28 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
 
     MakeDrawLayer();
 
-    SfxBindings& rBindings = GetViewFrame()->GetBindings();
+    SfxBindings& rBindings = GetViewFrame().GetBindings();
     ScTabView*   pTabView  = GetViewData().GetView();
     vcl::Window*      pWin      = pTabView->GetActiveWin();
     ScDrawView*  pView     = pTabView->GetScDrawView();
     ScDocShell*  pDocSh    = GetViewData().GetDocShell();
     ScDocument&  rDoc      = pDocSh->GetDocument();
-    SdrModel*    pDrModel  = pView->GetModel();
+    SdrModel& rModel = pView->GetModel();
 
     switch ( nSlot )
     {
         case SID_INSERT_GRAPHIC:
-            FuInsertGraphic(*this, pWin, pView, pDrModel, rReq);
+            FuInsertGraphic(*this, pWin, pView, &rModel, rReq);
             // shell is set in MarkListHasChanged
             break;
 
         case SID_INSERT_AVMEDIA:
-            FuInsertMedia(*this, pWin, pView, pDrModel, rReq);
+            FuInsertMedia(*this, pWin, pView, &rModel, rReq);
             // shell is set in MarkListHasChanged
             break;
 
         case SID_INSERT_DIAGRAM:
-            FuInsertChart(*this, pWin, pView, pDrModel, rReq, LINK( this, ScTabViewShell, DialogClosedHdl ));
+            FuInsertChart(*this, pWin, pView, &rModel, rReq, LINK( this, ScTabViewShell, DialogClosedHdl ));
             if (comphelper::LibreOfficeKit::isActive())
                 pDocSh->SetModified();
             break;
@@ -393,7 +393,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
         case SID_INSERT_OBJECT:
         case SID_INSERT_SMATH:
         case SID_INSERT_FLOATINGFRAME:
-            FuInsertOLE(*this, pWin, pView, pDrModel, rReq);
+            FuInsertOLE(*this, pWin, pView, &rModel, rReq);
             break;
 
         case SID_INSERT_SIGNATURELINE:
@@ -548,7 +548,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
             break;
 
         case SID_FONTWORK_GALLERY_FLOATER:
-            svx::FontworkBar::execute(*pView, rReq, GetViewFrame()->GetBindings());
+            svx::FontworkBar::execute(*pView, rReq, GetViewFrame().GetBindings());
             rReq.Ignore();
             break;
     }
@@ -556,7 +556,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
 
 void ScTabViewShell::GetDrawInsState(SfxItemSet &rSet)
 {
-    bool bOle = GetViewFrame()->GetFrame().IsInPlace();
+    bool bOle = GetViewFrame().GetFrame().IsInPlace();
     bool bTabProt = GetViewData().GetDocument().IsTabProtected(GetViewData().GetTabNo());
     ScDocShell* pDocShell = GetViewData().GetDocShell();
     bool bShared = pDocShell && pDocShell->IsDocShared();
@@ -712,6 +712,9 @@ bool ScTabViewShell::IsSignatureLineSigned()
 void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
 {
     SfxShell* pSh = GetViewData().GetDispatcher().GetShell(0);
+    if (!pSh)
+        return;
+
     ScUndoManager* pUndoManager = static_cast<ScUndoManager*>(pSh->GetUndoManager());
 
     const SfxItemSet* pReqArgs = rReq.GetArgs();
@@ -801,17 +804,20 @@ void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
                 if ( bLockPaint )
                     pDocSh->UnlockPaint();
 
-                GetViewFrame()->GetBindings().InvalidateAll(false);
+                GetViewFrame().GetBindings().InvalidateAll(false);
             }
             break;
 //      default:
-//          GetViewFrame()->ExecuteSlot( rReq );
+//          GetViewFrame().ExecuteSlot( rReq );
     }
 }
 
 void ScTabViewShell::GetUndoState(SfxItemSet &rSet)
 {
     SfxShell* pSh = GetViewData().GetDispatcher().GetShell(0);
+    if (!pSh)
+        return;
+
     SfxUndoManager* pUndoManager = pSh->GetUndoManager();
     ScUndoManager* pScUndoManager = dynamic_cast<ScUndoManager*>(pUndoManager);
 
@@ -863,7 +869,7 @@ void ScTabViewShell::GetUndoState(SfxItemSet &rSet)
                 }
                 else
                     // get state from sfx view frame
-                    GetViewFrame()->GetSlotState( nWhich, nullptr, &rSet );
+                    GetViewFrame().GetSlotState( nWhich, nullptr, &rSet );
                 break;
             }
             case SID_REDO:
@@ -888,12 +894,12 @@ void ScTabViewShell::GetUndoState(SfxItemSet &rSet)
                 }
                 else
                     // get state from sfx view frame
-                    GetViewFrame()->GetSlotState( nWhich, nullptr, &rSet );
+                    GetViewFrame().GetSlotState( nWhich, nullptr, &rSet );
                 break;
             }
             default:
                 // get state from sfx view frame
-                GetViewFrame()->GetSlotState( nWhich, nullptr, &rSet );
+                GetViewFrame().GetSlotState( nWhich, nullptr, &rSet );
         }
 
         nWhich = aIter.NextWhich();
