@@ -141,7 +141,7 @@ SdPresLayoutTemplateDlg::SdPresLayoutTemplateDlg(SfxObjectShell const * pDocSh,
     AddTabPage( "RID_SVXPAGE_ALIGN_PARAGRAPH", pFact->GetTabPageCreatorFunc( RID_SVXPAGE_ALIGN_PARAGRAPH ), nullptr );
     AddTabPage( "RID_SVXPAGE_BKG", pFact->GetTabPageCreatorFunc( RID_SVXPAGE_BKG ), nullptr);
 
-    if (!SvtCJKOptions::IsAsianTypographyEnabled() || bBackground)
+    if( !SvtCJKOptions::IsAsianTypographyEnabled() )
         RemoveTabPage( "RID_SVXPAGE_PARA_ASIAN" );
 
     if (bBackground)
@@ -160,6 +160,7 @@ SdPresLayoutTemplateDlg::SdPresLayoutTemplateDlg(SfxObjectShell const * pDocSh,
         RemoveTabPage( "RID_SVXPAGE_NUM_OPTIONS");
         RemoveTabPage( "RID_SVXPAGE_TABULATOR");
         RemoveTabPage( "RID_SVXPAGE_ALIGN_PARAGRAPH");
+        RemoveTabPage( "RID_SVXPAGE_PARA_ASIAN" );
         RemoveTabPage( "RID_SVXPAGE_BKG" );
     }
 
@@ -208,7 +209,7 @@ SdPresLayoutTemplateDlg::~SdPresLayoutTemplateDlg()
 {
 }
 
-void SdPresLayoutTemplateDlg::PageCreated(const OString& rId, SfxTabPage &rPage)
+void SdPresLayoutTemplateDlg::PageCreated(const OUString& rId, SfxTabPage &rPage)
 {
     SfxAllItemSet aSet(*(aInputSet.GetPool()));
 
