@@ -220,20 +220,20 @@ void ViewShellBase::InitInterface_Impl()
 }
 
 ViewShellBase::ViewShellBase (
-    SfxViewFrame* _pFrame,
+    SfxViewFrame& _rFrame,
     SfxViewShell*)
-    : SfxViewShell (_pFrame, SfxViewShellFlags::HAS_PRINTOPTIONS),
+    : SfxViewShell(_rFrame, SfxViewShellFlags::HAS_PRINTOPTIONS),
       mpDocShell (nullptr),
       mpDocument (nullptr)
 {
     mpImpl.reset(new Implementation(*this));
-    mpImpl->mpViewWindow = VclPtr<FocusForwardingWindow>::Create(_pFrame->GetWindow(),*this);
+    mpImpl->mpViewWindow = VclPtr<FocusForwardingWindow>::Create(_rFrame.GetWindow(),*this);
     mpImpl->mpViewWindow->SetBackground(Wallpaper());
 
-    _pFrame->GetWindow().SetBackground(Application::GetSettings().GetStyleSettings().GetLightColor());
+    _rFrame.GetWindow().SetBackground(Application::GetSettings().GetStyleSettings().GetLightColor());
 
     // Set up the members in the correct order.
-    if (auto pDrawDocShell = dynamic_cast< DrawDocShell *>( GetViewFrame()->GetObjectShell() ))
+    if (auto pDrawDocShell = dynamic_cast< DrawDocShell *>( GetViewFrame().GetObjectShell() ))
         mpDocShell = pDrawDocShell;
     if (mpDocShell != nullptr)
         mpDocument = mpDocShell->GetDoc();
@@ -242,7 +242,7 @@ ViewShellBase::ViewShellBase (
     SetWindow(mpImpl->mpViewWindow.get());
 
     // Hide the window to avoid complaints from Sfx...SwitchViewShell...
-    _pFrame->GetWindow().Hide();
+    _rFrame.GetWindow().Hide();
 }
 
 /** In this destructor the order in which some of the members are destroyed
@@ -280,7 +280,7 @@ ViewShellBase::~ViewShellBase()
     mpImpl->mpToolBarManager->Shutdown();
     mpImpl->mpViewShellManager->Shutdown();
 
-    EndListening(*GetViewFrame());
+    EndListening(GetViewFrame());
     EndListening(*GetDocShell());
 
     SetWindow(nullptr);
@@ -290,7 +290,7 @@ ViewShellBase::~ViewShellBase()
 
 void ViewShellBase::LateInit (const OUString& rsDefaultView)
 {
-    StartListening(*GetViewFrame(), DuplicateHandling::Prevent);
+    StartListening(GetViewFrame(), DuplicateHandling::Prevent);
     StartListening(*GetDocShell(), DuplicateHandling::Prevent);
     mpImpl->LateInit();
     InitializeFramework();
@@ -306,9 +306,10 @@ void ViewShellBase::LateInit (const OUString& rsDefaultView)
 
     try
     {
-        Reference<XControllerManager> xControllerManager (GetDrawController(), UNO_QUERY_THROW);
-        Reference<XConfigurationController> xConfigurationController (
-            xControllerManager->getConfigurationController());
+        rtl::Reference<::sd::DrawController> xControllerManager (GetDrawController());
+        Reference<XConfigurationController> xConfigurationController;
+        if (xControllerManager)
+            xConfigurationController = xControllerManager->getConfigurationController();
         if (xConfigurationController.is())
         {
             OUString sView (rsDefaultView);
@@ -408,11 +409,8 @@ void ViewShellBase::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
             case SfxEventHintId::OpenDoc:
                 if( GetDocument() && GetDocument()->IsStartWithPresentation() )
                 {
-                    if( GetViewFrame() )
-                    {
-                        GetViewFrame()->GetDispatcher()->Execute(
-                            SID_PRESENTATION, SfxCallMode::ASYNCHRON );
-                    }
+                    GetViewFrame().GetDispatcher()->Execute(
+                        SID_PRESENTATION, SfxCallMode::ASYNCHRON );
                 }
                 break;
 
@@ -427,7 +425,7 @@ void ViewShellBase::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
         {
             case SfxHintId::LanguageChanged:
             {
-                GetViewFrame()->GetBindings().Invalidate(SID_LANGUAGE_STATUS);
+                GetViewFrame().GetBindings().Invalidate(SID_LANGUAGE_STATUS);
             }
             break;
 
@@ -486,8 +484,6 @@ void ViewShellBase::OuterResizePixel (const Point& rOrigin, const Size &rSize)
 
 void ViewShellBase::Rearrange()
 {
-    OSL_ASSERT(GetViewFrame()!=nullptr);
-
     // There is a bug in the communication between embedded objects and the
     // framework::LayoutManager that leads to missing resize updates.  The
     // following workaround enforces such an update by cycling the border to
@@ -502,7 +498,7 @@ void ViewShellBase::Rearrange()
         SAL_WARN("sd.view", "Rearrange: window missing");
     }
 
-    GetViewFrame()->Resize(true);
+    GetViewFrame().Resize(true);
 }
 
 ErrCode ViewShellBase::DoVerb(sal_Int32 nVerb)
@@ -676,7 +672,7 @@ void ViewShellBase::GetState (SfxItemSet& rSet)
 {
     mpImpl->GetSlotState(rSet);
 
-    FuBullet::GetSlotState( rSet, nullptr, GetViewFrame() );
+    FuBullet::GetSlotState( rSet, nullptr, &GetViewFrame() );
 }
 
 void ViewShellBase::WriteUserDataSequence (
@@ -937,11 +933,11 @@ std::shared_ptr<FormShellManager> const & ViewShellBase::GetFormShellManager() c
     return mpImpl->mpFormShellManager;
 }
 
-DrawController& ViewShellBase::GetDrawController() const
+DrawController* ViewShellBase::GetDrawController() const
 {
     OSL_ASSERT(mpImpl != nullptr);
 
-    return *mpImpl->mpController;
+    return mpImpl->mpController.get();
 }
 
 void ViewShellBase::SetViewTabBar (const ::rtl::Reference<ViewTabBar>& rViewTabBar)
@@ -1013,6 +1009,11 @@ void ViewShellBase::setEditMode(int nMode)
     }
 }
 
+void ViewShellBase::afterCallbackRegistered()
+{
+    // TODO: Add theme color palette changed callback
+}
+
 void ViewShellBase::NotifyCursor(SfxViewShell* pOtherShell) const
 {
     ViewShell* pThisShell = framework::FrameworkHelper::Instance(*const_cast<ViewShellBase*>(this))->GetViewShell(FrameworkHelper::msCenterPaneURL).get();
