@@ -49,7 +49,6 @@
 #include <sfx2/sfxdlg.hxx>
 #include <sfx2/stbitem.hxx>
 #include <sfx2/dockwin.hxx>
-#include <sidebar/ControllerFactory.hxx>
 
 #include <officecfg/Office/Common.hxx>
 #include <rtl/strbuf.hxx>
@@ -87,16 +86,6 @@ SfxModule* SfxApplication::GetModule(SfxToolsModule nSharedLib)
     return g_pSfxApplication->pImpl->aModules[nSharedLib].get();
 }
 
-namespace {
-    css::uno::Reference<css::frame::XToolbarController> SfxWeldToolBoxControllerFactory( const css::uno::Reference< css::frame::XFrame >& rFrame, weld::Toolbar* pToolbar, weld::Builder* pBuilder, const OUString& aCommandURL )
-    {
-        SolarMutexGuard aGuard;
-
-        return sfx2::sidebar::ControllerFactory::CreateToolBoxController(
-                *pToolbar, *pBuilder, aCommandURL, rFrame, rFrame->getController(), false);
-    }
-}
-
 SfxApplication* SfxApplication::GetOrCreate()
 {
     static std::mutex theApplicationMutex;
@@ -116,7 +105,6 @@ SfxApplication* SfxApplication::GetOrCreate()
 
         ::framework::SetRefreshToolbars( RefreshToolbars );
         ::framework::SetToolBoxControllerCreator( SfxToolBoxControllerFactory );
-        ::framework::SetWeldToolBoxControllerCreator( SfxWeldToolBoxControllerFactory );
         ::framework::SetStatusBarControllerCreator( SfxStatusBarControllerFactory );
         ::framework::SetDockingWindowCreator( SfxDockingWindowFactory );
         ::framework::SetIsDockingWindowVisible( IsDockingWindowVisible );
@@ -379,6 +367,11 @@ std::vector<SfxViewShell*>& SfxApplication::GetViewShells_Impl() const
     return pImpl->maViewShells;
 }
 
+std::unordered_map<OUString, css::uno::Reference<css::ui::XAcceleratorConfiguration>>& SfxApplication::GetAcceleratorConfs_Impl() const
+{
+    return pImpl->maAcceleratorConfs;
+}
+
 std::vector<SfxObjectShell*>& SfxApplication::GetObjectShells_Impl() const
 {
     return pImpl->maObjShells;
@@ -395,12 +388,12 @@ void SfxApplication::Invalidate( sal_uInt16 nId )
 #ifndef DISABLE_DYNLOADING
 
 typedef long (*basicide_handle_basic_error)(void const *);
-typedef void (*basicide_macro_organizer)(void *, sal_Int16);
+typedef void (*basicide_macro_organizer)(void *, void *, sal_Int16);
 
 #else
 
 extern "C" long basicide_handle_basic_error(void const*);
-extern "C" void basicide_macro_organizer(void*, sal_Int16);
+extern "C" void basicide_macro_organizer(void*, void*, sal_Int16);
 
 #endif
 
@@ -426,7 +419,7 @@ IMPL_STATIC_LINK( SfxApplication, GlobalBasicErrorHdl_Impl, StarBASIC*, pStarBas
                            VclMessageType::Error,
                            VclButtonsType::Ok,
                            aError,
-                           true));
+                           GetpApp()));
 
             xBox->runAsync(xBox, [](sal_Int32 /*nResult*/) {});
         }
@@ -512,7 +505,7 @@ SfxApplication::ChooseScript(weld::Window *pParent)
     return aScriptURL;
 }
 
-void SfxApplication::MacroOrganizer(weld::Window* pParent, sal_Int16 nTabId)
+void SfxApplication::MacroOrganizer(weld::Window* pParent, const uno::Reference<frame::XFrame>& xDocFrame, sal_Int16 nTabId)
 {
 #if !HAVE_FEATURE_SCRIPTING
     (void) pParent;
@@ -523,11 +516,11 @@ void SfxApplication::MacroOrganizer(weld::Window* pParent, sal_Int16 nTabId)
     basicide_macro_organizer pSymbol = reinterpret_cast<basicide_macro_organizer>(sfx2::getBasctlFunction("basicide_macro_organizer"));
 
     // call basicide_macro_organizer in basctl
-    pSymbol(pParent, nTabId);
+    pSymbol(pParent, xDocFrame.get(), nTabId);
 
 #else
 
-    basicide_macro_organizer(pParent, nTabId);
+    basicide_macro_organizer(pParent, xDocFrame.get(), nTabId);
 
 #endif
 
