@@ -28,6 +28,7 @@
 #include <sfx2/sfxdlg.hxx>
 #include <sfx2/viewsh.hxx>
 #include <unotools/viewoptions.hxx>
+#include <utility>
 #include <vcl/virdev.hxx>
 #include <sal/log.hxx>
 #include <tools/debug.hxx>
@@ -54,14 +55,14 @@ namespace {
 
 struct Data_Impl
 {
-    OString sId;                  // The ID
+    OUString sId;                 // The ID
     CreateTabPage fnCreatePage;   // Pointer to Factory
     GetTabPageRanges fnGetRanges; // Pointer to Ranges-Function
     std::unique_ptr<SfxTabPage> xTabPage;         // The TabPage itself
     bool bRefresh;                // Flag: Page must be re-initialized
 
     // Constructor
-    Data_Impl( const OString& rId, CreateTabPage fnPage,
+    Data_Impl( const OUString& rId, CreateTabPage fnPage,
                GetTabPageRanges fnRanges ) :
 
         sId         ( rId ),
@@ -105,7 +106,7 @@ struct TabDlg_Impl
     }
 };
 
-static Data_Impl* Find( const SfxTabDlgData_Impl& rArr, std::string_view rId, sal_uInt16* pPos = nullptr)
+static Data_Impl* Find( const SfxTabDlgData_Impl& rArr, std::u16string_view rId, sal_uInt16* pPos = nullptr)
 {
     const sal_uInt16 nCount = rArr.size();
 
@@ -125,26 +126,26 @@ static Data_Impl* Find( const SfxTabDlgData_Impl& rArr, std::string_view rId, sa
 
 void SfxTabPage::SetFrame(const css::uno::Reference< css::frame::XFrame >& xFrame)
 {
-    if (pImpl)
-        pImpl->mxFrame = xFrame;
+    if (mpImpl)
+        mpImpl->mxFrame = xFrame;
 }
 
 css::uno::Reference< css::frame::XFrame > SfxTabPage::GetFrame() const
 {
-    if (pImpl)
-        return pImpl->mxFrame;
+    if (mpImpl)
+        return mpImpl->mxFrame;
     return css::uno::Reference< css::frame::XFrame >();
 }
 
-SfxTabPage::SfxTabPage(weld::Container* pPage, weld::DialogController* pController, const OUString& rUIXMLDescription, const OString& rID, const SfxItemSet *rAttrSet)
+SfxTabPage::SfxTabPage(weld::Container* pPage, weld::DialogController* pController, const OUString& rUIXMLDescription, const OUString& rID, const SfxItemSet *rAttrSet)
     : BuilderPage(pPage, pController, rUIXMLDescription, rID,
                     comphelper::LibreOfficeKit::isActive() && SfxViewShell::Current()
                     && SfxViewShell::Current()->isLOKMobilePhone())
-    , pSet                ( rAttrSet )
-    , bHasExchangeSupport ( false )
-    , pImpl               ( new TabPageImpl )
+    , mpSet(rAttrSet)
+    , mbHasExchangeSupport(false)
+    , mpImpl(new TabPageImpl)
 {
-    pImpl->mpSfxDialogController = dynamic_cast<SfxOkDialogController*>(m_pDialogController);
+    mpImpl->mpSfxDialogController = dynamic_cast<SfxOkDialogController*>(m_pDialogController);
 }
 
 SfxTabPage::~SfxTabPage()
@@ -156,7 +157,7 @@ SfxTabPage::~SfxTabPage()
             xParent->move(m_xContainer.get(), nullptr);
     }
     m_xContainer.reset();
-    pImpl.reset();
+    mpImpl.reset();
     m_xBuilder.reset();
 }
 
@@ -255,7 +256,7 @@ const SfxPoolItem* SfxTabPage::GetOldItem( const SfxItemSet& rSet,
     sal_uInt16 nWh = GetWhich( nSlot, bDeep );
     const SfxPoolItem* pItem = nullptr;
 
-    if ( pImpl->mbStandard && rOldSet.GetParent() )
+    if (mpImpl->mbStandard && rOldSet.GetParent())
         pItem = GetItem( *rOldSet.GetParent(), nSlot );
     else if ( rSet.GetParent() &&
               SfxItemState::DONTCARE == rSet.GetItemState( nWh ) )
@@ -276,20 +277,20 @@ void SfxTabPage::ChangesApplied()
 
 void SfxTabPage::SetDialogController(SfxOkDialogController* pDialog)
 {
-    pImpl->mpSfxDialogController = pDialog;
-    m_pDialogController = pImpl->mpSfxDialogController;
+    mpImpl->mpSfxDialogController = pDialog;
+    m_pDialogController = mpImpl->mpSfxDialogController;
 }
 
 SfxOkDialogController* SfxTabPage::GetDialogController() const
 {
-    return pImpl->mpSfxDialogController;
+    return mpImpl->mpSfxDialogController;
 }
 
-OString SfxTabPage::GetHelpId() const
+OUString SfxTabPage::GetHelpId() const
 {
     if (m_xContainer)
         return m_xContainer->get_help_id();
-    return OString();
+    return {};
 }
 
 weld::Window* SfxTabPage::GetFrameWeld() const
@@ -301,15 +302,15 @@ weld::Window* SfxTabPage::GetFrameWeld() const
 
 const SfxItemSet* SfxTabPage::GetDialogExampleSet() const
 {
-    if (pImpl->mpSfxDialogController)
-        return pImpl->mpSfxDialogController->GetExampleSet();
+    if (mpImpl->mpSfxDialogController)
+        return mpImpl->mpSfxDialogController->GetExampleSet();
     return nullptr;
 }
 
 SfxTabDialogController::SfxTabDialogController
 (
     weld::Widget* pParent,              // Parent Window
-    const OUString& rUIXMLDescription, const OString& rID, // Dialog .ui path, Dialog Name
+    const OUString& rUIXMLDescription, const OUString& rID, // Dialog .ui path, Dialog Name
     const SfxItemSet* pItemSet,   // Itemset with the data;
                                   // can be NULL, when Pages are onDemand
     bool bEditFmt                 // when yes -> additional Button for standard
@@ -505,11 +506,15 @@ IMPL_LINK_NOARG(SfxTabDialogController, BaseFmtHdl, weld::Button&, void)
     // Set all Items as new  -> the call the current Page Reset()
     assert(pDataObject->xTabPage && "the Page is gone");
     pDataObject->xTabPage->Reset( &aTmpSet );
-    pDataObject->xTabPage->pImpl->mbStandard = true;
+    pDataObject->xTabPage->mpImpl->mbStandard = true;
 }
 
-IMPL_LINK(SfxTabDialogController, ActivatePageHdl, const OString&, rPage, void)
+IMPL_LINK(SfxTabDialogController, ActivatePageHdl, const OUString&, rPage, void)
+{
+    ActivatePage(rPage);
+}
 
+void SfxTabDialogController::ActivatePage(const OUString& rPage)
 /*  [Description]
 
     Handler that is called by StarView for switching to a different page.
@@ -543,8 +548,12 @@ IMPL_LINK(SfxTabDialogController, ActivatePageHdl, const OString&, rPage, void)
         m_xResetBtn->show();
 }
 
-IMPL_LINK(SfxTabDialogController, DeactivatePageHdl, const OString&, rPage, bool)
+IMPL_LINK(SfxTabDialogController, DeactivatePageHdl, const OUString&, rPage, bool)
+{
+    return DeactivatePage(rPage);
+}
 
+bool SfxTabDialogController::DeactivatePage(std::u16string_view aPage)
 /*  [Description]
 
     Handler that is called by StarView before leaving a page.
@@ -556,7 +565,7 @@ IMPL_LINK(SfxTabDialogController, DeactivatePageHdl, const OString&, rPage, bool
 
 {
     assert(!m_pImpl->aData.empty() && "no Pages registered");
-    Data_Impl* pDataObject = Find(m_pImpl->aData, rPage);
+    Data_Impl* pDataObject = Find(m_pImpl->aData, aPage);
     if (!pDataObject)
     {
         SAL_WARN("sfx.dialog", "Tab Page ID not known, this is pretty serious and needs investigation");
@@ -617,7 +626,7 @@ IMPL_LINK(SfxTabDialogController, DeactivatePageHdl, const OString&, rPage, bool
 
 bool SfxTabDialogController::PrepareLeaveCurrentPage()
 {
-    const OString sId = m_xTabCtrl->get_current_page_ident();
+    const OUString sId = m_xTabCtrl->get_current_page_ident();
     Data_Impl* pDataObject = Find(m_pImpl->aData, sId);
     DBG_ASSERT( pDataObject, "Id not known" );
     SfxTabPage* pPage = pDataObject ? pDataObject->xTabPage.get() : nullptr;
@@ -716,9 +725,7 @@ SfxTabDialogController::~SfxTabDialogController()
             if ( !aPageData.isEmpty() )
             {
                 // save settings of all pages (user data)
-                OUString sConfigId = OStringToOUString(elem->xTabPage->GetConfigId(),
-                    RTL_TEXTENCODING_UTF8);
-                SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
+                SvtViewOptions aPageOpt(EViewType::TabPage, elem->xTabPage->GetConfigId());
                 aPageOpt.SetUserItem( USERITEM_NAME, Any( aPageData ) );
             }
 
@@ -812,7 +819,7 @@ void SfxTabDialogController::PageCreated
 */
 
 (
-    const OString&, // Id of the created page
+    const OUString&, // Id of the created page
     SfxTabPage&     // Reference to the created page
 )
 {
@@ -821,7 +828,7 @@ void SfxTabDialogController::PageCreated
 void SfxTabDialogController::SavePosAndId()
 {
     // save settings (screen position and current page)
-    SvtViewOptions aDlgOpt(EViewType::TabDialog, OStringToOUString(m_xDialog->get_help_id(), RTL_TEXTENCODING_UTF8));
+    SvtViewOptions aDlgOpt(EViewType::TabDialog, m_xDialog->get_help_id());
     aDlgOpt.SetPageID(m_xTabCtrl->get_current_page_ident());
 }
 
@@ -829,14 +836,14 @@ void SfxTabDialogController::SavePosAndId()
     Adds a page to the dialog. The Name must correspond to an entry in the
     TabControl in the dialog .ui
 */
-void SfxTabDialogController::AddTabPage(const OString &rName /* Page ID */,
+void SfxTabDialogController::AddTabPage(const OUString &rName /* Page ID */,
                                         CreateTabPage pCreateFunc  /* Pointer to the Factory Method */,
                                         GetTabPageRanges pRangesFunc /* Pointer to the Method for querying Ranges onDemand */)
 {
     m_pImpl->aData.push_back(new Data_Impl(rName, pCreateFunc, pRangesFunc));
 }
 
-void SfxTabDialogController::AddTabPage(const OString &rName /* Page ID */,
+void SfxTabDialogController::AddTabPage(const OUString &rName /* Page ID */,
                                         sal_uInt16 nPageCreateId /* Identifier of the Factory Method to create the page */)
 {
     SfxAbstractDialogFactory* pFact = SfxAbstractDialogFactory::Create();
@@ -851,7 +858,7 @@ void SfxTabDialogController::AddTabPage(const OString &rName /* Page ID */,
     counterpart in the TabControl in the resource of the dialogue.
 */
 
-void SfxTabDialogController::AddTabPage(const OString &rName, /* Page ID */
+void SfxTabDialogController::AddTabPage(const OUString &rName, /* Page ID */
                                         const OUString& rRiderText,
                                         CreateTabPage pCreateFunc  /* Pointer to the Factory Method */)
 {
@@ -860,7 +867,7 @@ void SfxTabDialogController::AddTabPage(const OString &rName, /* Page ID */
     AddTabPage(rName, pCreateFunc, nullptr);
 }
 
-void SfxTabDialogController::AddTabPage(const OString &rName, const OUString& rRiderText,
+void SfxTabDialogController::AddTabPage(const OUString &rName, const OUString& rRiderText,
                                         sal_uInt16 nPageCreateId /* Identifier of the Factory Method to create the page */)
 {
     assert(!m_xTabCtrl->get_page(rName) && "Double Page-Ids in the Tabpage");
@@ -873,7 +880,7 @@ void SfxTabDialogController::AddTabPage(const OString &rName, const OUString& rR
     Default implementation of the virtual Method.
     This is called when pages create their sets onDemand.
 */
-SfxItemSet* SfxTabDialogController::CreateInputItemSet(const OString&)
+SfxItemSet* SfxTabDialogController::CreateInputItemSet(const OUString&)
 {
     SAL_WARN( "sfx.dialog", "CreateInputItemSet not implemented" );
     m_xItemSet = std::make_unique<SfxAllItemSet>(SfxGetpApp()->GetPool());
@@ -892,8 +899,7 @@ void SfxTabDialogController::CreatePages()
         else
             pDataObject->xTabPage = (pDataObject->fnCreatePage)(pPage, this, CreateInputItemSet(pDataObject->sId));
         pDataObject->xTabPage->SetDialogController(this);
-        OUString sConfigId = OStringToOUString(pDataObject->xTabPage->GetConfigId(), RTL_TEXTENCODING_UTF8);
-        SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
+        SvtViewOptions aPageOpt(EViewType::TabPage, pDataObject->xTabPage->GetConfigId());
         OUString sUserData;
         Any aUserItem = aPageOpt.GetUserItem(USERITEM_NAME);
         OUString aTemp;
@@ -939,7 +945,7 @@ void SfxTabDialogController::setPreviewsToSamePlace()
         m_xSizeGroup->add_widget(rGrid.get());
 }
 
-void SfxTabDialogController::RemoveTabPage(const OString& rId)
+void SfxTabDialogController::RemoveTabPage(const OUString& rId)
 
 /*  [Description]
 
@@ -960,9 +966,7 @@ void SfxTabDialogController::RemoveTabPage(const OString& rId)
             if ( !aPageData.isEmpty() )
             {
                 // save settings of this page (user data)
-                OUString sConfigId = OStringToOUString(pDataObject->xTabPage->GetConfigId(),
-                    RTL_TEXTENCODING_UTF8);
-                SvtViewOptions aPageOpt(EViewType::TabPage, sConfigId);
+                SvtViewOptions aPageOpt(EViewType::TabPage, pDataObject->xTabPage->GetConfigId());
                 aPageOpt.SetUserItem( USERITEM_NAME, Any( aPageData ) );
             }
 
@@ -991,17 +995,17 @@ void SfxTabDialogController::Start_Impl()
     // something that the sort dialog in calc depends on
     if (m_sAppPageId.isEmpty())
     {
-        SvtViewOptions aDlgOpt(EViewType::TabDialog, OStringToOUString(m_xDialog->get_help_id(), RTL_TEXTENCODING_UTF8));
+        SvtViewOptions aDlgOpt(EViewType::TabDialog, m_xDialog->get_help_id());
         if (aDlgOpt.Exists())
             m_xTabCtrl->set_current_page(aDlgOpt.GetPageID());
     }
 
-    ActivatePageHdl(m_xTabCtrl->get_current_page_ident());
+    ActivatePage(m_xTabCtrl->get_current_page_ident());
 
     m_pImpl->bStarted = true;
 }
 
-void SfxTabDialogController::SetCurPageId(const OString& rIdent)
+void SfxTabDialogController::SetCurPageId(const OUString& rIdent)
 {
     m_sAppPageId = rIdent;
     m_xTabCtrl->set_current_page(m_sAppPageId);
@@ -1011,13 +1015,13 @@ void SfxTabDialogController::SetCurPageId(const OString& rIdent)
 
     The TabPage is activated with the specified Id.
 */
-void SfxTabDialogController::ShowPage(const OString& rIdent)
+void SfxTabDialogController::ShowPage(const OUString& rIdent)
 {
     SetCurPageId(rIdent);
-    ActivatePageHdl(rIdent);
+    ActivatePage(rIdent);
 }
 
-OString SfxTabDialogController::GetCurPageId() const
+OUString SfxTabDialogController::GetCurPageId() const
 {
     return m_xTabCtrl->get_current_page_ident();
 }
@@ -1076,7 +1080,7 @@ void SfxTabDialogController::RemoveStandardButton()
     m_xBaseFmtBtn->hide();
 }
 
-SfxTabPage* SfxTabDialogController::GetTabPage(std::string_view rPageId) const
+SfxTabPage* SfxTabDialogController::GetTabPage(std::u16string_view rPageId) const
 
 /*  [Description]
 
@@ -1115,17 +1119,17 @@ bool SfxTabDialogController::Apply()
     return bApplied;
 }
 
-std::vector<OString> SfxTabDialogController::getAllPageUIXMLDescriptions() const
+std::vector<OUString> SfxTabDialogController::getAllPageUIXMLDescriptions() const
 {
     int nPages = m_xTabCtrl->get_n_pages();
-    std::vector<OString> aRet;
+    std::vector<OUString> aRet;
     aRet.reserve(nPages);
     for (int i = 0; i < nPages; ++i)
         aRet.push_back(m_xTabCtrl->get_page_ident(i));
     return aRet;
 }
 
-bool SfxTabDialogController::selectPageByUIXMLDescription(const OString& rUIXMLDescription)
+bool SfxTabDialogController::selectPageByUIXMLDescription(const OUString& rUIXMLDescription)
 {
     ShowPage(rUIXMLDescription);
     return m_xTabCtrl->get_current_page_ident() == rUIXMLDescription;
@@ -1143,14 +1147,14 @@ BitmapEx SfxTabDialogController::createScreenshot() const
     return xDialogSurface->GetBitmapEx(Point(), xDialogSurface->GetOutputSizePixel());
 }
 
-OString SfxTabDialogController::GetScreenshotId() const
+OUString SfxTabDialogController::GetScreenshotId() const
 {
-    const OString sId = m_xTabCtrl->get_current_page_ident();
+    const OUString sId = m_xTabCtrl->get_current_page_ident();
     Data_Impl* pDataObject = Find(m_pImpl->aData, sId);
     SfxTabPage* pPage = pDataObject ? pDataObject->xTabPage.get() : nullptr;
     if (pPage)
     {
-        OString sHelpId(pPage->GetHelpId());
+        OUString sHelpId(pPage->GetHelpId());
         if (!sHelpId.isEmpty())
             return sHelpId;
     }
