@@ -38,6 +38,12 @@
 #include <comphelper/diagnose_ex.hxx>
 #include <tools/urlobj.hxx>
 
+#if defined(_WIN32)
+#include <o3tl/char16_t2wchar_t.hxx>
+#include <officecfg/Office/Common.hxx>
+#include <systools/win32/comtools.hxx>
+#include <urlmon.h>
+#endif
 
 namespace sfx2
 {
@@ -48,7 +54,6 @@ namespace sfx2
     using ::com::sun::star::uno::Any;
     using ::com::sun::star::uno::Sequence;
     using ::com::sun::star::task::DocumentMacroConfirmationRequest;
-    using ::com::sun::star::task::ErrorCodeRequest;
     using ::com::sun::star::uno::Exception;
     using ::com::sun::star::security::DocumentDigitalSignatures;
     using ::com::sun::star::security::XDocumentDigitalSignatures;
@@ -66,56 +71,17 @@ namespace sfx2
     struct DocumentMacroMode_Data
     {
         IMacroDocumentAccess&       m_rDocumentAccess;
-        bool                    m_bMacroDisabledMessageShown;
-        bool                    m_bDocMacroDisabledMessageShown;
+        bool m_bHasUnsignedContentError;
 
         explicit DocumentMacroMode_Data( IMacroDocumentAccess& rDocumentAccess )
             :m_rDocumentAccess( rDocumentAccess )
-            ,m_bMacroDisabledMessageShown( false )
-            ,m_bDocMacroDisabledMessageShown( false )
+            ,m_bHasUnsignedContentError( false )
         {
         }
     };
 
-
-    //= helper
-
     namespace
     {
-
-        void lcl_showGeneralSfxErrorOnce( const Reference< XInteractionHandler >& rxHandler, ErrCode nSfxErrorCode, bool& rbAlreadyShown )
-        {
-            if ( rbAlreadyShown )
-                return;
-
-            ErrorCodeRequest aErrorCodeRequest;
-            aErrorCodeRequest.ErrCode = sal_uInt32(nSfxErrorCode);
-
-            SfxMedium::CallApproveHandler( rxHandler, Any( aErrorCodeRequest ), false );
-            rbAlreadyShown = true;
-        }
-
-
-        void lcl_showMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, bool& rbAlreadyShown )
-        {
-            lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_MACROS_SUPPORT_DISABLED, rbAlreadyShown );
-        }
-
-
-        void lcl_showDocumentMacrosDisabledError( const Reference< XInteractionHandler >& rxHandler, bool& rbAlreadyShown )
-        {
-#ifdef MACOSX
-            lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED_MAC, rbAlreadyShown );
-#else
-            lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED, rbAlreadyShown );
-#endif
-        }
-
-        void lcl_showMacrosDisabledUnsignedContentError( const Reference< XInteractionHandler >& rxHandler, bool& rbAlreadyShown )
-        {
-            lcl_showGeneralSfxErrorOnce( rxHandler, ERRCODE_SFX_DOCUMENT_MACRO_DISABLED_CONTENT_UNSIGNED, rbAlreadyShown );
-        }
-
         bool lcl_showMacroWarning( const Reference< XInteractionHandler >& rxHandler,
             const OUString& rDocumentLocation )
         {
@@ -150,7 +116,6 @@ namespace sfx2
         if ( SvtSecurityOptions::IsMacroDisabled() )
         {
             // no macro should be executed at all
-            lcl_showMacrosDisabledError( rxInteraction, m_xData->m_bMacroDisabledMessageShown );
             return disallowMacroExecution();
         }
 
@@ -200,12 +165,13 @@ namespace sfx2
         if ( nMacroExecutionMode == MacroExecMode::ALWAYS_EXECUTE_NO_WARN )
             return true;
 
+        const OUString sURL(m_xData->m_rDocumentAccess.getDocumentLocation());
         try
         {
             // get document location from medium name and check whether it is a trusted one
             // the service is created without document version, since it is not of interest here
             Reference< XDocumentDigitalSignatures > xSignatures(DocumentDigitalSignatures::createDefault(::comphelper::getProcessComponentContext()));
-            INetURLObject aURLReferer( m_xData->m_rDocumentAccess.getDocumentLocation() );
+            INetURLObject aURLReferer(sURL);
 
             OUString aLocation;
             if ( aURLReferer.removeSegment() )
@@ -219,7 +185,6 @@ namespace sfx2
             // at this point it is clear that the document is not in the secure location
             if ( nMacroExecutionMode == MacroExecMode::FROM_LIST_NO_WARN )
             {
-                lcl_showDocumentMacrosDisabledError( rxInteraction, m_xData->m_bDocMacroDisabledMessageShown );
                 return disallowMacroExecution();
             }
 
@@ -235,8 +200,6 @@ namespace sfx2
                 SignatureState nSignatureState = m_xData->m_rDocumentAccess.getScriptingSignatureState();
                 if ( nSignatureState == SignatureState::BROKEN )
                 {
-                    if (!bAllowUIToAddAuthor)
-                        lcl_showDocumentMacrosDisabledError(rxInteraction, m_xData->m_bDocMacroDisabledMessageShown);
                     return disallowMacroExecution();
                 }
                 else if ( m_xData->m_rDocumentAccess.macroCallsSeenWhileLoading() &&
@@ -244,7 +207,7 @@ namespace sfx2
                           !bHasValidContentSignature)
                 {
                     // When macros are signed, and the document has events which call macros, the document content needs to be signed too.
-                    lcl_showMacrosDisabledUnsignedContentError(rxInteraction, m_xData->m_bDocMacroDisabledMessageShown);
+                    m_xData->m_bHasUnsignedContentError = true;
                     return disallowMacroExecution();
                 }
                 else if ( bHasTrustedMacroSignature )
@@ -256,8 +219,6 @@ namespace sfx2
                        || nSignatureState == SignatureState::NOTVALIDATED )
                 {
                     // there is valid signature, but it is not from the trusted author
-                    if (!bAllowUIToAddAuthor)
-                        lcl_showDocumentMacrosDisabledError(rxInteraction, m_xData->m_bDocMacroDisabledMessageShown);
                     return disallowMacroExecution();
                 }
             }
@@ -267,9 +228,6 @@ namespace sfx2
                 ||  ( nMacroExecutionMode == MacroExecMode::FROM_LIST_AND_SIGNED_WARN )
                 )
             {
-                if  ( nMacroExecutionMode == MacroExecMode::FROM_LIST_AND_SIGNED_WARN )
-                    lcl_showDocumentMacrosDisabledError( rxInteraction, m_xData->m_bDocMacroDisabledMessageShown );
-
                 return disallowMacroExecution();
             }
         }
@@ -284,12 +242,64 @@ namespace sfx2
             }
         }
 
+#if defined(_WIN32)
+        // Windows specific: try to decide macros loading depending on Windows Security Zones
+        // (is the file local, or it was downloaded from internet, etc?)
+        OUString sFilePath;
+        osl::FileBase::getSystemPathFromFileURL(sURL, sFilePath);
+        sal::systools::COMReference<IZoneIdentifier> pZoneId;
+        pZoneId.CoCreateInstance(CLSID_PersistentZoneIdentifier);
+        sal::systools::COMReference<IPersistFile> pPersist(pZoneId, sal::systools::COM_QUERY_THROW);
+        DWORD dwZone;
+        if (!SUCCEEDED(pPersist->Load(o3tl::toW(sFilePath.getStr()), STGM_READ)) ||
+            !SUCCEEDED(pZoneId->GetId(&dwZone)))
+        {
+            // no Security Zone info found -> assume a local file, not
+            // from the internet
+            dwZone = URLZONE_LOCAL_MACHINE;
+        }
+
+        // determine action from zone and settings
+        sal_Int32 nAction;
+        switch (dwZone) {
+            case URLZONE_LOCAL_MACHINE:
+                nAction = officecfg::Office::Common::Security::Scripting::WindowsSecurityZone::ZoneLocal::get();
+                break;
+            case URLZONE_INTRANET:
+                nAction = officecfg::Office::Common::Security::Scripting::WindowsSecurityZone::ZoneIntranet::get();
+                break;
+            case URLZONE_TRUSTED:
+                nAction = officecfg::Office::Common::Security::Scripting::WindowsSecurityZone::ZoneTrusted::get();
+                break;
+            case URLZONE_INTERNET:
+                nAction = officecfg::Office::Common::Security::Scripting::WindowsSecurityZone::ZoneInternet::get();
+                break;
+            case URLZONE_UNTRUSTED:
+                nAction = officecfg::Office::Common::Security::Scripting::WindowsSecurityZone::ZoneUntrusted::get();
+                break;
+            default:
+                // unknown zone, let's ask the user
+                nAction = 0;
+                break;
+        }
+
+        // act on result
+        switch (nAction)
+        {
+            case 0: // Ask
+                break;
+            case 1: // Allow
+                return allowMacroExecution();
+            case 2: // Deny
+                return disallowMacroExecution();
+        }
+#endif
         // confirmation is required
         bool bSecure = false;
 
         if ( eAutoConfirm == eNoAutoConfirm )
         {
-            OUString sReferrer( m_xData->m_rDocumentAccess.getDocumentLocation() );
+            OUString sReferrer(sURL);
 
             OUString aSystemFileURL;
             if ( osl::FileBase::getSystemPathFromFileURL( sReferrer, aSystemFileURL ) == osl::FileBase::E_None )
@@ -373,6 +383,11 @@ namespace sfx2
         return bHasMacroLib;
     }
 
+    bool DocumentMacroMode::hasUnsignedContentError() const
+    {
+        return m_xData->m_bHasUnsignedContentError;
+    }
+
 
     bool DocumentMacroMode::storageHasMacros( const Reference< XStorage >& rxStorage )
     {
@@ -400,12 +415,8 @@ namespace sfx2
         return bHasMacros;
     }
 
-    bool DocumentMacroMode::hasMacros() const
-    {
-        return m_xData->m_rDocumentAccess.documentStorageHasMacros() || hasMacroLibrary() || m_xData->m_rDocumentAccess.macroCallsSeenWhileLoading();
-    }
 
-    bool DocumentMacroMode::checkMacrosOnLoading( const Reference< XInteractionHandler >& rxInteraction, bool bHasValidContentSignature, bool bHasMacros )
+    bool DocumentMacroMode::checkMacrosOnLoading( const Reference< XInteractionHandler >& rxInteraction, bool bHasValidContentSignature )
     {
         bool bAllow = false;
         if ( SvtSecurityOptions::IsMacroDisabled() )
@@ -415,7 +426,7 @@ namespace sfx2
         }
         else
         {
-            if (bHasMacros)
+            if (m_xData->m_rDocumentAccess.documentStorageHasMacros() || hasMacroLibrary() || m_xData->m_rDocumentAccess.macroCallsSeenWhileLoading())
             {
                 bAllow = adjustMacroMode( rxInteraction, bHasValidContentSignature );
             }
