@@ -58,16 +58,16 @@ constexpr OUStringLiteral TM_SETTING_LASTFOLDER = u"LastFolder";
 constexpr OUStringLiteral TM_SETTING_LASTAPPLICATION = u"LastApplication";
 constexpr OUStringLiteral TM_SETTING_VIEWMODE = u"ViewMode";
 
-#define MNI_ACTION_NEW_FOLDER "new"
-#define MNI_ACTION_RENAME_FOLDER "rename"
-#define MNI_ACTION_DELETE_FOLDER "delete"
-#define MNI_ACTION_DEFAULT   "default"
-#define MNI_ACTION_DEFAULT_WRITER   "default_writer"
-#define MNI_ACTION_DEFAULT_CALC   "default_calc"
-#define MNI_ACTION_DEFAULT_IMPRESS   "default_impress"
-#define MNI_ACTION_DEFAULT_DRAW   "default_draw"
-#define MNI_ACTION_IMPORT   "import_template"
-#define MNI_ACTION_EXTENSIONS   "extensions"
+constexpr OUStringLiteral MNI_ACTION_NEW_FOLDER = u"new";
+constexpr OUStringLiteral MNI_ACTION_RENAME_FOLDER = u"rename";
+constexpr OUStringLiteral MNI_ACTION_DELETE_FOLDER = u"delete";
+constexpr OUStringLiteral MNI_ACTION_DEFAULT   = u"default";
+constexpr OUStringLiteral MNI_ACTION_DEFAULT_WRITER   = u"default_writer";
+constexpr OUStringLiteral MNI_ACTION_DEFAULT_CALC   = u"default_calc";
+constexpr OUStringLiteral MNI_ACTION_DEFAULT_IMPRESS   = u"default_impress";
+constexpr OUStringLiteral MNI_ACTION_DEFAULT_DRAW   = u"default_draw";
+constexpr OUStringLiteral MNI_ACTION_IMPORT   = u"import_template";
+constexpr OUStringLiteral MNI_ACTION_EXTENSIONS = u"extensions";
 #define MNI_ALL_APPLICATIONS 0
 #define MNI_WRITER           1
 #define MNI_CALC             2
@@ -203,7 +203,7 @@ SfxTemplateManagerDlg::SfxTemplateManagerDlg(weld::Window *pParent)
 
     mxLocalView->ShowTooltips(true);
 
-    // Set width and height of the templates thumbnail viewer to acommodate 3 rows and 4 columns of items
+    // Set width and height of the templates thumbnail viewer to accommodate 3 rows and 4 columns of items
     mxLocalViewWeld->set_size_request(TEMPLATE_ITEM_MAX_WIDTH * 5, TEMPLATE_ITEM_MAX_HEIGHT_SUB * 3);
 
     mxOKButton->connect_clicked(LINK(this, SfxTemplateManagerDlg, OkClickHdl));
@@ -508,7 +508,7 @@ IMPL_LINK(SfxTemplateManagerDlg, TVItemStateHdl, const ThumbnailViewItem*, pItem
         OnTemplateState(pItem);
 }
 
-IMPL_LINK(SfxTemplateManagerDlg, MenuSelectHdl, const OString&, rIdent, void)
+IMPL_LINK(SfxTemplateManagerDlg, MenuSelectHdl, const OUString&, rIdent, void)
 {
     if (rIdent == MNI_ACTION_NEW_FOLDER)
         OnCategoryNew();
@@ -532,7 +532,7 @@ IMPL_LINK(SfxTemplateManagerDlg, MenuSelectHdl, const OString&, rIdent, void)
         ExtensionsActionHdl();
 }
 
-void SfxTemplateManagerDlg::DefaultTemplateMenuSelectHdl(std::string_view rIdent)
+void SfxTemplateManagerDlg::DefaultTemplateMenuSelectHdl(std::u16string_view rIdent)
 {
     SvtModuleOptions aModOpt;
     OUString aFactoryURL;
@@ -1265,9 +1265,7 @@ SfxTemplateCategoryDialog::SfxTemplateCategoryDialog(weld::Window* pParent)
     : GenericDialogController(pParent, "sfx/ui/templatecategorydlg.ui", "TemplatesCategoryDialog")
     , mbIsNewCategory(false)
     , mxLBCategory(m_xBuilder->weld_tree_view("categorylb"))
-    , mxSelectLabel(m_xBuilder->weld_label("select_label"))
     , mxNewCategoryEdit(m_xBuilder->weld_entry("category_entry"))
-    , mxCreateLabel(m_xBuilder->weld_label("create_label"))
     , mxOKButton(m_xBuilder->weld_button("ok"))
 {
     mxLBCategory->append_text(SfxResId(STR_CATEGORY_NONE));
