@@ -409,7 +409,10 @@ sub create_package
         {
             my $subdir = "$tempdir/$packagename/$volume_name_classic_app.app/Contents/Resources";
             if ( ! -d $subdir ) { installer::systemactions::create_directory($subdir); }
-            if ( $ENV{'MACOSX_CODESIGNING_IDENTITY'} )
+            # For non-release builds where no identity is, set entitlements
+            # to allow Xcode's Instruments application to connect to the
+            # application
+            if ( $ENV{'MACOSX_CODESIGNING_IDENTITY'} || !$ENV{'ENABLE_RELEASE_BUILD'} )
             {
                 $systemcall = "$ENV{'SRCDIR'}/solenv/bin/macosx-codesign-app-bundle $localtempdir/$folder/$volume_name_classic_app.app";
                 print "... $systemcall ...\n";
@@ -494,13 +497,14 @@ sub create_package
     if ( $makesystemcall )
     {
         print "... $systemcall ...\n";
-        my $returnvalue = system($systemcall);
+        my $systemcall_output = `$systemcall`;
+        my $returnvalue = $? >> 8;
         my $infoline = "Systemcall: $systemcall\n";
         push( @installer::globals::logfileinfo, $infoline);
 
         if ($returnvalue)
         {
-            $infoline = "ERROR: Could not execute \"$systemcall\": $returnvalue\n";
+            $infoline = "ERROR: Could not execute \"$systemcall\" - exitcode: $returnvalue - output:\n$systemcall_output\n";
             push( @installer::globals::logfileinfo, $infoline);
         }
         else
