@@ -44,10 +44,10 @@
 #include <com/sun/star/container/XContainerListener.hpp>
 #include <com/sun/star/container/XContainer.hpp>
 
-#include <utility>
 #include <vcl/canvastools.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
+#include <comphelper/lok.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/scopeguard.hxx>
 #include <cppuhelper/implbase.hxx>
@@ -58,6 +58,7 @@
 #include <basegfx/matrix/b2dhommatrixtools.hxx>
 #include <drawinglayer/primitive2d/controlprimitive2d.hxx>
 
+#include <utility>
 /*
 
 Form controls (more precise: UNO Controls) in the drawing layer are ... prone to breakage, since they have some
@@ -108,7 +109,6 @@ namespace sdr::contact {
     using ::com::sun::star::uno::UNO_QUERY;
     using ::com::sun::star::uno::UNO_QUERY_THROW;
     using ::com::sun::star::uno::Exception;
-    using ::com::sun::star::uno::RuntimeException;
     using ::com::sun::star::awt::XControl;
     using ::com::sun::star::awt::XControlModel;
     using ::com::sun::star::awt::XControlContainer;
@@ -279,6 +279,10 @@ namespace sdr::contact {
     static void adjustControlGeometry_throw( const ControlHolder& _rControl, const tools::Rectangle& _rLogicBoundingRect,
         const basegfx::B2DHomMatrix& _rViewTransformation, const ::basegfx::B2DHomMatrix& _rZoomLevelNormalization )
     {
+        // In the LOK case, control geometry is handled by LokControlHandler
+        if (comphelper::LibreOfficeKit::isActive())
+            return;
+
         OSL_PRECOND( _rControl.is(), "UnoControlContactHelper::adjustControlGeometry_throw: illegal control!" );
         if ( !_rControl.is() )
             return;
@@ -1563,7 +1567,9 @@ namespace sdr::contact {
         // create a primitive and hand over the existing xControl. This will
         // allow the primitive to not need to create another one on demand.
         rContainer.push_back( new ::drawinglayer::primitive2d::ControlPrimitive2D(
-            m_aTransformation, xControlModel, rControl.getControl() ) );
+            m_aTransformation, xControlModel, rControl.getControl(),
+            m_pVOCImpl->getViewContact().GetSdrObject().GetTitle(),
+            m_pVOCImpl->getViewContact().GetSdrObject().GetDescription()) );
     }
 
     sal_uInt32 LazyControlCreationPrimitive2D::getPrimitive2DID() const
