@@ -103,8 +103,8 @@ void SdrEditView::SetMarkedObjRect(const tools::Rectangle& rRect)
     {
         SdrMark* pM=GetSdrMarkByIndex(nm);
         SdrObject* pO=pM->GetMarkedSdrObj();
-        if( bUndo )
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+        if (bUndo)
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
 
         tools::Rectangle aR1(pO->GetSnapRect());
         if (!aR1.IsEmpty())
@@ -165,7 +165,7 @@ std::vector< std::unique_ptr<SdrUndoAction> > SdrEditView::CreateConnectorUndo(
                     if ( ( pPartObj->GetConnectedNode( false ) == &rO ) ||
                          ( pPartObj->GetConnectedNode( true  ) == &rO ) )
                     {
-                        vUndoActions.push_back( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject( *pPartObj ) );
+                        vUndoActions.push_back(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pPartObj));
                     }
                 }
             }
@@ -205,7 +205,7 @@ void SdrEditView::MoveMarkedObj(const Size& rSiz, bool bCopy)
         if( bUndo )
         {
             AddUndoActions( CreateConnectorUndo( *pO ) );
-            AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoMoveObject(*pO,rSiz));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoMoveObject(*pO,rSiz));
         }
         pO->Move(rSiz);
     }
@@ -237,7 +237,7 @@ void SdrEditView::ResizeMarkedObj(const Point& rRef, const Fraction& xFact, cons
         if( bUndo )
         {
             AddUndoActions( CreateConnectorUndo( *pO ) );
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
         }
         pO->Resize(rRef,xFact,yFact);
     }
@@ -266,7 +266,7 @@ void SdrEditView::ResizeMultMarkedObj(const Point& rRef,
         if( bUndo )
         {
             AddUndoActions( CreateConnectorUndo( *pO ) );
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
         }
 
         Fraction aFrac(1,1);
@@ -328,11 +328,11 @@ void SdrEditView::RotateMarkedObj(const Point& rRef, Degree100 nAngle, bool bCop
                 // extra undo actions for changed connector which now may hold its laid out path (SJ)
                 AddUndoActions( CreateConnectorUndo( *pO ) );
 
-                AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+                AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
             }
 
             // set up a scene updater if object is a 3d object
-            if(dynamic_cast< E3dObject* >(pO))
+            if(DynCastE3dObject(pO))
             {
                 aUpdaters.push_back(new E3DModifySceneSnapRectUpdater(pO));
             }
@@ -392,11 +392,11 @@ void SdrEditView::MirrorMarkedObj(const Point& rRef1, const Point& rRef2, bool b
                 // extra undo actions for changed connector which now may hold its laid out path (SJ)
                 AddUndoActions( CreateConnectorUndo( *pO ) );
 
-                AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+                AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
             }
 
             // set up a scene updater if object is a 3d object
-            if(dynamic_cast< E3dObject* >(pO))
+            if(DynCastE3dObject(pO))
             {
                 aUpdaters.push_back(new E3DModifySceneSnapRectUpdater(pO));
             }
@@ -477,7 +477,7 @@ void SdrEditView::ShearMarkedObj(const Point& rRef, Degree100 nAngle, bool bVShe
         if( bUndo )
         {
             AddUndoActions( CreateConnectorUndo( *pO ) );
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
         }
         pO->Shear(rRef,nAngle,nTan,bVShear);
     }
@@ -589,8 +589,8 @@ void SdrEditView::CrookMarkedObj(const Point& rRef, const Point& rRad, SdrCrookM
     {
         SdrMark* pM=GetSdrMarkByIndex(nm);
         SdrObject* pO=pM->GetMarkedSdrObj();
-        if( bUndo )
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+        if (bUndo)
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
 
         const SdrObjList* pOL=pO->GetSubList();
         if (bNoContortion || pOL==nullptr) {
@@ -663,8 +663,8 @@ void SdrEditView::DistortMarkedObj(const tools::Rectangle& rRef, const XPolygon&
     {
         SdrMark* pM=GetSdrMarkByIndex(nm);
         SdrObject* pO=pM->GetMarkedSdrObj();
-        if( bUndo )
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pO));
+        if (bUndo)
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pO));
 
         tools::Rectangle aRefRect(rRef);
         const SdrObjList* pOL=pO->GetSubList();
@@ -774,8 +774,8 @@ void SdrEditView::SetNotPersistAttrToMarked(const SfxItemSet& rAttr)
     {
         const SdrMark* pM=GetSdrMarkByIndex(nm);
         SdrObject* pObj=pM->GetMarkedSdrObj();
-        if( bUndo )
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
+        if (bUndo)
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
 
         pObj->ApplyNotPersistAttr(rAttr);
     }
@@ -890,7 +890,7 @@ void SdrEditView::MergeNotPersistAttrFromMarked(SfxItemSet& rAttr) const
 
 SfxItemSet SdrEditView::GetAttrFromMarked(bool bOnlyHardAttr) const
 {
-    SfxItemSet aSet(mpModel->GetItemPool());
+    SfxItemSet aSet(GetModel().GetItemPool());
     MergeAttrFromMarked(aSet,bOnlyHardAttr);
     //the EE_FEATURE items should not be set with SetAttrToMarked (see error message there)
     //so we do not set them here
@@ -1022,7 +1022,7 @@ void SdrEditView::MergeAttrFromMarked(SfxItemSet& rAttr, bool bOnlyHardAttr) con
 
                 if (!sPayload.isEmpty())
                     GetSfxViewShell()->libreOfficeKitViewCallback(LOK_CALLBACK_STATE_CHANGED,
-                        OUStringToOString(sPayload, RTL_TEXTENCODING_ASCII_US).getStr());
+                        OUStringToOString(sPayload, RTL_TEXTENCODING_ASCII_US));
             }
 
             nWhich = aIter.NextWhich();
@@ -1170,7 +1170,7 @@ void SdrEditView::SetAttrToMarked(const SfxItemSet& rAttr, bool bReplaceAll)
         if(bPossibleGeomChange && bUndo)
         {
             // save position and size of object, too
-            AddUndo( GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
+            AddUndo( GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
         }
 
         if( bUndo )
@@ -1181,14 +1181,14 @@ void SdrEditView::SetAttrToMarked(const SfxItemSet& rAttr, bool bReplaceAll)
             // multiple portions exist with multiple formats. If an OutlinerParaObject
             // really exists and needs to be rescued is evaluated in the undo
             // implementation itself.
-            const bool bRescueText = dynamic_cast< SdrTextObj* >(pObj) != nullptr;
+            const bool bRescueText = DynCastSdrTextObj(pObj) != nullptr;
 
             // add attribute undo
-            AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoAttrObject(*pObj,false,bHasEEItems || bPossibleGeomChange || bRescueText));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoAttrObject(*pObj,false,bHasEEItems || bPossibleGeomChange || bRescueText));
         }
 
         // set up a scene updater if object is a 3d object
-        if(dynamic_cast< E3dObject* >(pObj))
+        if(DynCastE3dObject(pObj))
         {
             aUpdaters.push_back(new E3DModifySceneSnapRectUpdater(pObj));
         }
@@ -1226,7 +1226,7 @@ void SdrEditView::SetAttrToMarked(const SfxItemSet& rAttr, bool bReplaceAll)
             }
         }
 
-        if(auto pTextObj = dynamic_cast<SdrTextObj*>( pObj))
+        if(auto pTextObj = DynCastSdrTextObj( pObj))
         {
             if(!aCharWhichIds.empty())
             {
@@ -1316,8 +1316,8 @@ void SdrEditView::SetStyleSheetToMarked(SfxStyleSheet* pStyleSheet, bool bDontRe
         SdrMark* pM=GetSdrMarkByIndex(nm);
         if( bUndo )
         {
-            AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pM->GetMarkedSdrObj()));
-            AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoAttrObject(*pM->GetMarkedSdrObj(),true,true));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pM->GetMarkedSdrObj()));
+            AddUndo(GetModel().GetSdrUndoFactory().CreateUndoAttrObject(*pM->GetMarkedSdrObj(),true,true));
         }
         pM->GetMarkedSdrObj()->SetStyleSheet(pStyleSheet,bDontRemoveHardAttr);
     }
@@ -1370,7 +1370,7 @@ void SdrEditView::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHard
 SfxItemSet SdrEditView::GetGeoAttrFromMarked() const
 {
     SfxItemSet aRetSet(
-        mpModel->GetItemPool(),
+        GetModel().GetItemPool(),
         svl::Items< // SID_ATTR_TRANSFORM_... from s:svxids.hrc
             SDRATTR_CORNER_RADIUS, SDRATTR_CORNER_RADIUS,
             SID_ATTR_TRANSFORM_POS_X, SID_ATTR_TRANSFORM_ANGLE,
@@ -1489,7 +1489,7 @@ SfxItemSet SdrEditView::GetGeoAttrFromMarked() const
             // multiple objects, range is collected in aRect
             aTransformation = basegfx::utils::createScaleTranslateB2DHomMatrix(
                 aRect.Left(), aRect.Top(),
-                aRect.getWidth(), aRect.getHeight());
+                aRect.getOpenWidth(), aRect.getOpenHeight());
         }
         else
         {
@@ -1603,7 +1603,7 @@ void SdrEditView::SetGeoAttrToMarked(const SfxItemSet& rAttr, bool addPageMargin
     bool bShear =false;
 
     bool bSetAttr=false;
-    SfxItemSet aSetAttr(mpModel->GetItemPool());
+    SfxItemSet aSetAttr(GetModel().GetItemPool());
 
     // position
     if (const SfxInt32Item *pPoolItem = rAttr.GetItemIfSet(SID_ATTR_TRANSFORM_POS_X))
@@ -1682,8 +1682,8 @@ void SdrEditView::SetGeoAttrToMarked(const SfxItemSet& rAttr, bool addPageMargin
             }
             bShear=nShearAngle!=0_deg100;
             if (bShear) {
-                nShearX=static_cast<const SfxInt32Item&>(rAttr.Get(SID_ATTR_TRANSFORM_SHEAR_X)).GetValue();
-                nShearY=static_cast<const SfxInt32Item&>(rAttr.Get(SID_ATTR_TRANSFORM_SHEAR_Y)).GetValue();
+                nShearX = rAttr.Get(SID_ATTR_TRANSFORM_SHEAR_X).GetValue();
+                nShearY = rAttr.Get(SID_ATTR_TRANSFORM_SHEAR_Y).GetValue();
             }
         }
     }
@@ -2001,10 +2001,10 @@ void SdrEditView::AlignMarkedObjects(SdrHorAlign eHor, SdrVertAlign eVert)
                 {
                     if( dynamic_cast<SdrEdgeObj*>(pObj) )
                     {
-                        AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
+                        AddUndo(GetModel().GetSdrUndoFactory().CreateUndoGeoObject(*pObj));
                     }
 
-                    AddUndo(GetModel()->GetSdrUndoFactory().CreateUndoMoveObject(*pObj,Size(nXMov,nYMov)));
+                    AddUndo(GetModel().GetSdrUndoFactory().CreateUndoMoveObject(*pObj,Size(nXMov,nYMov)));
                 }
 
                 pObj->Move(Size(nXMov,nYMov));
