@@ -161,7 +161,11 @@ bool PaletteManager::IsThemePaletteSelected() const
 
 bool PaletteManager::GetThemeAndEffectIndex(sal_uInt16 nItemId, sal_uInt16& rThemeIndex, sal_uInt16& rEffectIndex)
 {
-     // Each column is the same color with different effects.
+    // tdf#157034, nItemId begins with 1 but list of themes begin with 0
+    // so decrement nItemId
+    --nItemId;
+
+    // Each column is the same color with different effects.
     rThemeIndex = nItemId % 12;
 
     rEffectIndex = nItemId / 12;
@@ -378,6 +382,12 @@ void PaletteManager::AddRecentColor(const Color& rRecentColor, const OUString& r
     batch->commit();
 }
 
+void PaletteManager::SetSplitButtonColor(const NamedColor& rColor)
+{
+    if (mpBtnUpdater)
+        mpBtnUpdater->SetRecentColor(rColor);
+}
+
 void PaletteManager::SetBtnUpdater(svx::ToolboxButtonColorUpdaterBase* pBtnUpdater)
 {
     mpBtnUpdater = pBtnUpdater;
@@ -401,8 +411,7 @@ void PaletteManager::PopupColorPicker(weld::Window* pParent, const OUString& aCo
             Color aLastColor = m_pColorDlg->GetColor();
             OUString sColorName = "#" + aLastColor.AsRGBHexString().toAsciiUpperCase();
             NamedColor aNamedColor(aLastColor, sColorName);
-            if (mpBtnUpdater)
-                mpBtnUpdater->Update(aNamedColor);
+            SetSplitButtonColor(aNamedColor);
             AddRecentColor(aLastColor, sColorName);
             maColorSelectFunction(aCommandCopy, aNamedColor);
         }
