@@ -36,6 +36,7 @@
 #include <o3tl/any.hxx>
 #include <svl/itempool.hxx>
 #include <editeng/memberids.h>
+#include <docmodel/uno/UnoGradientTools.hxx>
 #include <docmodel/uno/UnoComplexColor.hxx>
 #include <docmodel/color/ComplexColorJSON.hxx>
 #include <tools/mapunit.hxx>
@@ -2200,7 +2201,7 @@ bool XFillGradientItem::QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId ) c
         case 0:
         {
             // fill values
-            const css::awt::Gradient2 aGradient2(GetGradientValue().getAsGradient2());
+            const css::awt::Gradient2 aGradient2 = model::gradient::createUnoGradient2(GetGradientValue());
 
             // create sequence
             uno::Sequence< beans::PropertyValue > aPropSeq{
@@ -2214,7 +2215,7 @@ bool XFillGradientItem::QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId ) c
         case MID_FILLGRADIENT:
         {
             // fill values
-            const css::awt::Gradient2 aGradient2(GetGradientValue().getAsGradient2());
+            const css::awt::Gradient2 aGradient2 = model::gradient::createUnoGradient2(GetGradientValue());
 
             // create sequence
             rVal <<= aGradient2;
@@ -2230,8 +2231,7 @@ bool XFillGradientItem::QueryValue( css::uno::Any& rVal, sal_uInt8 nMemberId ) c
         case MID_GRADIENT_COLORSTOPSEQUENCE:
         {
             // fill values
-            const css::awt::ColorStopSequence aColorStopSequence(
-                GetGradientValue().GetColorStops().getAsColorStopSequence());
+            const css::awt::ColorStopSequence aColorStopSequence = model::gradient::createColorStopSequence(GetGradientValue().GetColorStops());
 
             // create sequence
             rVal <<= aColorStopSequence;
@@ -2282,8 +2282,7 @@ bool XFillGradientItem::PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId
 
                 if (aGradientAny.hasValue() && (aGradientAny.has<css::awt::Gradient>() || aGradientAny.has<css::awt::Gradient2>()))
                 {
-                    const basegfx::BGradient aBGradient(aGradientAny);
-                    SetGradientValue(aBGradient);
+                    SetGradientValue(model::gradient::getFromAny(aGradientAny));
                 }
 
                 return true;
@@ -2305,8 +2304,7 @@ bool XFillGradientItem::PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId
         {
             if (rVal.hasValue() && (rVal.has<css::awt::Gradient>() || rVal.has<css::awt::Gradient2>()))
             {
-                const basegfx::BGradient aBGradient(rVal);
-                SetGradientValue(aBGradient);
+                SetGradientValue(model::gradient::getFromAny(rVal));
             }
 
             break;
@@ -2317,7 +2315,8 @@ bool XFillGradientItem::PutValue( const css::uno::Any& rVal, sal_uInt8 nMemberId
             // check if we have a awt::ColorStopSequence
             if (rVal.hasValue() && rVal.has<css::awt::ColorStopSequence>())
             {
-                const basegfx::BColorStops aColorStops(rVal);
+
+                const basegfx::BColorStops aColorStops = model::gradient::getColorStopsFromAny(rVal);
 
                 if (!aColorStops.empty())
                 {
