@@ -1010,6 +1010,99 @@ CPPUNIT_TEST_FIXTURE(Test, testSplitFlyIntoTable)
     // second part of a floating table into a table on the next page, not before that table.
     calcLayout();
 }
+
+CPPUNIT_TEST_FIXTURE(Test, testSplitFlyFromAsCharAnchor)
+{
+    // Given a document with a footnote that has a table (imported in an as-char anchored frame in
+    // Writer):
+    createSwDoc("table-in-footnote.docx");
+
+    // When changing the anchor type of that frame to to-para:
+    // Then make sure we don't crash:
+    selectShape(1);
+    // Without the accompanying fix in place, this test would have crashed, we tried to split a
+    // frame+table inside a footnote.
+    dispatchCommand(mxComponent, ".uno:SetAnchorToPara", {});
+}
+
+CPPUNIT_TEST_FIXTURE(Test, testSplitFlyNested)
+{
+    // Given a document with a nested, multi-page floating table:
+    // When calculating the layout:
+    createSwDoc("floattable-nested.odt");
+    calcLayout();
+
+    // Then make sure we don't crash:
+    // Without the accompanying fix in place, this test would have crashed.
+    // Check that we have exactly 4 fly frames, all of them on the expected pages: master outer,
+    // follow outer, master inner and follow inner.
+    SwDoc* pDoc = getSwDoc();
+    SwRootFrame* pLayout = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
+    auto pPage1 = pLayout->Lower()->DynCastPageFrame();
+    CPPUNIT_ASSERT(pPage1);
+    CPPUNIT_ASSERT(pPage1->GetSortedObjs());
+    SwSortedObjs& rPage1Objs = *pPage1->GetSortedObjs();
+    CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(2), rPage1Objs.size());
+    auto pPage1Fly1 = rPage1Objs[0]->DynCastFlyFrame()->DynCastFlyAtContentFrame();
+    CPPUNIT_ASSERT(pPage1Fly1);
+    CPPUNIT_ASSERT(pPage1Fly1->GetAnchorFrameContainingAnchPos()->IsInFly());
+    CPPUNIT_ASSERT(pPage1Fly1->GetFollow());
+    auto pPage1Fly2 = rPage1Objs[1]->DynCastFlyFrame()->DynCastFlyAtContentFrame();
+    CPPUNIT_ASSERT(pPage1Fly2);
+    CPPUNIT_ASSERT(!pPage1Fly2->GetAnchorFrameContainingAnchPos()->IsInFly());
+    CPPUNIT_ASSERT(pPage1Fly2->GetFollow());
+    auto pPage2 = pPage1->GetNext()->DynCastPageFrame();
+    CPPUNIT_ASSERT(pPage2);
+    CPPUNIT_ASSERT(pPage2->GetSortedObjs());
+    SwSortedObjs& rPage2Objs = *pPage2->GetSortedObjs();
+    CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(2), rPage2Objs.size());
+    auto pPage2Fly1 = rPage2Objs[0]->DynCastFlyFrame()->DynCastFlyAtContentFrame();
+    CPPUNIT_ASSERT(pPage2Fly1);
+    CPPUNIT_ASSERT(pPage2Fly1->GetAnchorFrameContainingAnchPos()->IsInFly());
+    CPPUNIT_ASSERT(pPage2Fly1->GetPrecede());
+
+    // Without the accompanying fix in place, this test would have failed with:
+    // - Expected greater than: 6204
+    // - Actual  : 1725
+    // i.e. the inner follow fly had a bad position, it was outside the page rectangle, it was not
+    // rendered and this way the inner anchor had no fly portion, either.
+    CPPUNIT_ASSERT_GREATER(pPage2->getFrameArea().Top(), pPage2Fly1->getFrameArea().Top());
+
+    // Without the accompanying fix in place, this test would have failed with:
+    // - Expected less than: 12523
+    // - Actual  : 15312
+    // i.e. the inner follow fly was not "moved back" to its place to have the wanted 4400 position,
+    // which makes the "Inner A2" text visible.
+    CPPUNIT_ASSERT_LESS(pPage2->getFrameArea().Right(), pPage2Fly1->getFrameArea().Right());
+
+    auto pPage2Fly2 = rPage2Objs[1]->DynCastFlyFrame()->DynCastFlyAtContentFrame();
+    CPPUNIT_ASSERT(pPage2Fly2);
+    CPPUNIT_ASSERT(!pPage2Fly2->GetAnchorFrameContainingAnchPos()->IsInFly());
+    CPPUNIT_ASSERT(pPage2Fly2->GetPrecede());
+}
+
+CPPUNIT_TEST_FIXTURE(Test, testSplitFlyNestedOverlap)
+{
+    // Given a document with a nested, multi-page floating table, enabling the "don't overlap" logic:
+    // When calculating the layout:
+    createSwDoc("floattable-nested-overlap.odt");
+    calcLayout();
+
+    // Then make sure we get 2 pages (2 flys on each page):
+    // Without the accompanying fix in place, this test would have failed with a layout loop.
+    SwDoc* pDoc = getSwDoc();
+    SwRootFrame* pLayout = pDoc->getIDocumentLayoutAccess().GetCurrentLayout();
+    auto pPage1 = pLayout->Lower()->DynCastPageFrame();
+    CPPUNIT_ASSERT(pPage1);
+    CPPUNIT_ASSERT(pPage1->GetSortedObjs());
+    SwSortedObjs& rPage1Objs = *pPage1->GetSortedObjs();
+    CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(2), rPage1Objs.size());
+    auto pPage2 = pPage1->GetNext()->DynCastPageFrame();
+    CPPUNIT_ASSERT(pPage2);
+    CPPUNIT_ASSERT(pPage2->GetSortedObjs());
+    SwSortedObjs& rPage2Objs = *pPage2->GetSortedObjs();
+    CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(2), rPage2Objs.size());
+}
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
