@@ -247,10 +247,8 @@ public:
         std::cout << filename << ",";
         mnStartTime = osl_getGlobalTimer();
         mxComponent = loadFromDesktop(msMailMergeOutputURL + "/" + filename, "com.sun.star.text.TextDocument");
-        OString name2 = OUStringToOString( filename, RTL_TEXTENCODING_UTF8 );
         discardDumpedLayout();
-        if (mustCalcLayoutOf(name2.getStr()))
-            calcLayout();
+        calcLayout();
     }
 
     /**
@@ -513,7 +511,8 @@ DECLARE_SHELL_MAILMERGE_TEST(exportDirectToPDF_shell, "linked-with-condition.odt
     SvMemoryStream aMemory;
     aMemory.WriteStream(aPDFFile);
     std::shared_ptr<vcl::pdf::PDFium> pPDFium = vcl::pdf::PDFiumLibrary::get();
-    CPPUNIT_ASSERT(pPDFium);
+    if (!pPDFium)
+        return;
 
     std::unique_ptr<vcl::pdf::PDFiumDocument> pPdfDocument
         = pPDFium->openDocument(aMemory.GetData(), aMemory.GetSize(), OString());
