@@ -1192,11 +1192,27 @@ public:
         if (startFly
             && startFly->GetFlyFormat()->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
         {
-            auto pIssue = lclAddIssue(m_rIssueCollection, SwResId(STR_FLOATING_TEXT));
-            pIssue->setIssueObject(IssueObject::TEXTFRAME);
-            pIssue->setObjectID(startFly->GetFlyFormat()->GetName());
-            pIssue->setDoc(pCurrent->GetDoc());
-            pIssue->setNode(pCurrent);
+            SwNodeIndex aCurrentIdx(*pCurrent);
+            SwNodeIndex aIdx(*startFly);
+            SwNode* pFirstTextNode = &aIdx.GetNode();
+            SwNodeOffset nEnd = startFly->EndOfSectionIndex();
+            while (aIdx < nEnd)
+            {
+                if (pFirstTextNode->IsContentNode() && pFirstTextNode->IsTextNode())
+                {
+                    if (aIdx == aCurrentIdx)
+                    {
+                        auto pIssue = lclAddIssue(m_rIssueCollection, SwResId(STR_FLOATING_TEXT));
+                        pIssue->setIssueObject(IssueObject::TEXTFRAME);
+                        pIssue->setObjectID(startFly->GetFlyFormat()->GetName());
+                        pIssue->setDoc(pCurrent->GetDoc());
+                        pIssue->setNode(pCurrent);
+                    }
+                    break;
+                }
+                ++aIdx;
+                pFirstTextNode = &aIdx.GetNode();
+            }
         }
     }
 };
@@ -1317,8 +1333,11 @@ public:
         LanguageType eLanguage = rLang.GetLanguage();
         if (eLanguage == LANGUAGE_NONE)
         {
-            lclAddIssue(m_rIssueCollection, SwResId(STR_DOCUMENT_DEFAULT_LANGUAGE),
-                        sfx::AccessibilityIssueID::DOCUMENT_LANGUAGE);
+            auto pIssue = lclAddIssue(m_rIssueCollection, SwResId(STR_DOCUMENT_DEFAULT_LANGUAGE),
+                                      sfx::AccessibilityIssueID::DOCUMENT_LANGUAGE);
+            pIssue->setIssueObject(IssueObject::LANGUAGE_NOT_SET);
+            pIssue->setObjectID(OUString());
+            pIssue->setDoc(*pDoc);
         }
         else
         {
@@ -1330,8 +1349,12 @@ public:
                     OUString sName = pTextFormatCollection->GetName();
                     OUString sIssueText
                         = SwResId(STR_STYLE_NO_LANGUAGE).replaceAll("%STYLE_NAME%", sName);
-                    lclAddIssue(m_rIssueCollection, sIssueText,
-                                sfx::AccessibilityIssueID::STYLE_LANGUAGE);
+
+                    auto pIssue = lclAddIssue(m_rIssueCollection, sIssueText,
+                                              sfx::AccessibilityIssueID::STYLE_LANGUAGE);
+                    pIssue->setIssueObject(IssueObject::LANGUAGE_NOT_SET);
+                    pIssue->setObjectID(sName);
+                    pIssue->setDoc(*pDoc);
                 }
             }
         }
