@@ -81,22 +81,10 @@ SwUpdateAttr::SwUpdateAttr( sal_Int32 nS, sal_Int32 nE, sal_uInt16 nW, std::vect
 {
 }
 
-SwRefMarkFieldUpdate::SwRefMarkFieldUpdate( OutputDevice* pOutput )
-    : SwMsgPoolItem( RES_REFMARKFLD_UPDATE ),
-    pOut( pOutput )
-{
-    OSL_ENSURE( pOut, "No OutputDevice pointer" );
-}
-
-SwDocPosUpdate::SwDocPosUpdate( const SwTwips nDcPos )
-    : SwMsgPoolItem( RES_DOCPOS_UPDATE ), nDocPos(nDcPos)
-{
-}
-
-SwTableFormulaUpdate::SwTableFormulaUpdate( const SwTable* pNewTable )
-    : SwMsgPoolItem( RES_TABLEFML_UPDATE ),
-    m_pTable( pNewTable ), m_pHistory( nullptr ), m_nSplitLine( USHRT_MAX ),
-    m_eFlags( TBL_CALC )
+SwTableFormulaUpdate::SwTableFormulaUpdate(const SwTable* pNewTable)
+    : m_pTable(pNewTable)
+    , m_nSplitLine(USHRT_MAX)
+    , m_eFlags(TBL_CALC)
 {
     m_aData.pDelTable = nullptr;
     m_bModified = m_bBehindSplitLine = false;
