@@ -645,8 +645,11 @@ SetNextCursor:
                 RestoreSavePos();
             return true;
         }
-        else if( pNd->IsTableNode() && aCellStt++ )
+        else if( pNd->IsTableNode() )
+        {
+            ++aCellStt;
             goto GoNextCell;
+        }
 
         bProt = false; // index is now on a content node
         goto SetNextCursor;
@@ -697,8 +700,11 @@ SetPrevCursor:
                 RestoreSavePos();
             return true;
         }
-        else if( pNd->StartOfSectionNode()->IsTableNode() && aCellStt-- )
+        else if( pNd->StartOfSectionNode()->IsTableNode() )
+        {
+            --aCellStt;
             goto GoPrevCell;
+        }
 
         bProt = false; // index is now on a content node
         goto SetPrevCursor;
@@ -1423,7 +1429,7 @@ bool SwCursor::SelectWordWT( SwViewShell const * pViewShell, sal_Int16 nWordType
     {
         // Should we select the whole fieldmark?
         const IDocumentMarkAccess* pMarksAccess = GetDoc().getIDocumentMarkAccess( );
-        sw::mark::IFieldmark const*const pMark(pMarksAccess->getFieldmarkFor(*GetPoint()));
+        sw::mark::IFieldmark const*const pMark(pMarksAccess->getInnerFieldmarkFor(*GetPoint()));
         if (pMark && (IDocumentMarkAccess::GetType(*pMark) == IDocumentMarkAccess::MarkType::TEXT_FIELDMARK
                       || IDocumentMarkAccess::GetType(*pMark) == IDocumentMarkAccess::MarkType::DATE_FIELDMARK))
         {
@@ -1680,10 +1686,8 @@ SwCursor::DoSetBidiLevelLeftRight(
         const SwTextNode& rTNd = *rNode.GetTextNode();
         sal_Int32 nPos = GetPoint()->GetContentIndex();
 
-        const SvtCTLOptions& rCTLOptions = SW_MOD()->GetCTLOptions();
-        if ( bVisualAllowed && rCTLOptions.IsCTLFontEnabled() &&
-             SvtCTLOptions::MOVEMENT_VISUAL ==
-             rCTLOptions.GetCTLCursorMovement() )
+        if ( bVisualAllowed && SvtCTLOptions::IsCTLFontEnabled() &&
+             SvtCTLOptions::MOVEMENT_VISUAL == SvtCTLOptions::GetCTLCursorMovement() )
         {
             // for visual cursor travelling (used in bidi layout)
             // we first have to convert the logic to a visual position
@@ -2617,4 +2621,18 @@ bool SwTableCursor::HasReadOnlyBoxSel() const
     return bRet;
 }
 
+bool SwTableCursor::HasHiddenBoxSel() const
+{
+    bool bRet = false;
+    for (size_t n = m_SelectedBoxes.size(); n; )
+    {
+        if (m_SelectedBoxes[--n]->GetFrameFormat()->IsHidden())
+        {
+            bRet = true;
+            break;
+        }
+    }
+    return bRet;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
