@@ -106,7 +106,6 @@ sw::DocumentSettingManager::DocumentSettingManager(SwDoc &rDoc)
     mbFootnoteInColumnToPageEnd(false),
     mnImagePreferredDPI(0),
     mbAutoFirstLineIndentDisregardLineSpace(true),
-    mbWrapAsCharFlysLikeInOOXML(false),
     mbNoNumberingShowFollowBy(false),
     mbDropCapPunctuation(true)
 
@@ -248,7 +247,8 @@ bool sw::DocumentSettingManager::get(/*[in]*/ DocumentSettingId id) const
         case DocumentSettingId::AUTO_FIRST_LINE_INDENT_DISREGARD_LINE_SPACE:
             return mbAutoFirstLineIndentDisregardLineSpace;
         case DocumentSettingId::HYPHENATE_URLS: return mbHyphenateURLs;
-        case DocumentSettingId::WRAP_AS_CHAR_FLYS_LIKE_IN_OOXML: return mbWrapAsCharFlysLikeInOOXML;
+        case DocumentSettingId::DO_NOT_BREAK_WRAPPED_TABLES:
+            return mbDoNotBreakWrappedTables;
         case DocumentSettingId::NO_NUMBERING_SHOW_FOLLOWBY: return mbNoNumberingShowFollowBy;
         case DocumentSettingId::DROP_CAP_PUNCTUATION: return mbDropCapPunctuation;
         default:
@@ -433,8 +433,8 @@ void sw::DocumentSettingManager::set(/*[in]*/ DocumentSettingId id, /*[in]*/ boo
             mbHyphenateURLs = value;
             break;
 
-        case DocumentSettingId::WRAP_AS_CHAR_FLYS_LIKE_IN_OOXML:
-            mbWrapAsCharFlysLikeInOOXML = value;
+        case DocumentSettingId::DO_NOT_BREAK_WRAPPED_TABLES:
+            mbDoNotBreakWrappedTables = value;
             break;
 
         case DocumentSettingId::NO_NUMBERING_SHOW_FOLLOWBY:
@@ -1039,10 +1039,17 @@ void sw::DocumentSettingManager::dumpAsXml(xmlTextWriterPtr pWriter) const
     (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbFootnoteInColumnToPageEnd"));
     (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"),
                                 BAD_CAST(OString::boolean(mbFootnoteInColumnToPageEnd).getStr()));
+    (void)xmlTextWriterEndElement(pWriter);
 
     (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbHyphenateURLs"));
     (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"),
                                 BAD_CAST(OString::boolean(mbHyphenateURLs).getStr()));
+    (void)xmlTextWriterEndElement(pWriter);
+
+    (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mbDoNotBreakWrappedTables"));
+    (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"),
+                                BAD_CAST(OString::boolean(mbDoNotBreakWrappedTables).getStr()));
+    (void)xmlTextWriterEndElement(pWriter);
 
     (void)xmlTextWriterStartElement(pWriter, BAD_CAST("mnImagePreferredDPI"));
     (void)xmlTextWriterWriteAttribute(pWriter, BAD_CAST("value"),
