@@ -83,6 +83,8 @@ SwXFlatParagraph::getPropertySetInfo()
     static const comphelper::PropertyMapEntry s_Entries[] = {
         { OUString("FieldPositions"), -1, ::cppu::UnoType<uno::Sequence<sal_Int32>>::get(), beans::PropertyAttribute::READONLY, 0 },
         { OUString("FootnotePositions"), -1, ::cppu::UnoType<uno::Sequence<sal_Int32>>::get(), beans::PropertyAttribute::READONLY, 0 },
+        { OUString("SortedTextId"), -1, ::cppu::UnoType<sal_Int32>::get(), beans::PropertyAttribute::READONLY, 0 },
+        { OUString("DocumentElementsCount"), -1, ::cppu::UnoType<sal_Int32>::get(), beans::PropertyAttribute::READONLY, 0 },
     };
     return new comphelper::PropertySetInfo(s_Entries);
 }
@@ -107,6 +109,22 @@ SwXFlatParagraph::getPropertyValue(const OUString& rPropertyName)
     {
         return uno::Any( comphelper::containerToSequence( GetConversionMap().getFootnotePositions() ) );
     }
+    else if (rPropertyName == "SortedTextId")
+    {
+        SwTextNode const*const pCurrentNode = GetTextNode();
+        sal_Int32 nIndex = -1;
+        if ( pCurrentNode )
+            nIndex = pCurrentNode->GetIndex().get();
+        return uno::Any( nIndex );
+    }
+    else if (rPropertyName == "DocumentElementsCount")
+    {
+        SwTextNode const*const pCurrentNode = GetTextNode();
+        sal_Int32 nCount = -1;
+        if ( pCurrentNode )
+            nCount = pCurrentNode->GetDoc().GetNodes().Count().get();
+        return uno::Any( nCount );
+    }
     return uno::Any();
 }
 
@@ -310,20 +328,6 @@ css::uno::Sequence< ::sal_Int32 > SAL_CALL SwXFlatParagraph::getLanguagePortions
     return css::uno::Sequence< ::sal_Int32>();
 }
 
-const uno::Sequence< sal_Int8 >&
-SwXFlatParagraph::getUnoTunnelId()
-{
-    static const comphelper::UnoIdInit theSwXFlatParagraphUnoTunnelId;
-    return theSwXFlatParagraphUnoTunnelId.getSeq();
-}
-
-sal_Int64 SAL_CALL
-SwXFlatParagraph::getSomething(
-        const uno::Sequence< sal_Int8 >& rId)
-{
-    return comphelper::getSomethingImpl(rId, this);
-}
-
 SwXFlatParagraphIterator::SwXFlatParagraphIterator( SwDoc& rDoc, sal_Int32 nType, bool bAutomatic )
     : mpDoc( &rDoc ),
       mnType( nType ),
@@ -499,10 +503,8 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaAfter(co
     if (!mpDoc)
         return xRet;
 
-    const uno::Reference<lang::XUnoTunnel> xFPTunnel(xPara, uno::UNO_QUERY);
-    SAL_WARN_IF(!xFPTunnel.is(), "sw.core", "invalid argument");
-    SwXFlatParagraph* const pFlatParagraph(comphelper::getFromUnoTunnel<SwXFlatParagraph>(xFPTunnel));
-
+    SwXFlatParagraph* const pFlatParagraph(dynamic_cast<SwXFlatParagraph*>(xPara.get()));
+    SAL_WARN_IF(!pFlatParagraph, "sw.core", "invalid argument");
     if ( !pFlatParagraph )
         return xRet;
 
@@ -542,11 +544,8 @@ uno::Reference< text::XFlatParagraph > SwXFlatParagraphIterator::getParaBefore(c
     if (!mpDoc)
         return xRet;
 
-    const uno::Reference<lang::XUnoTunnel> xFPTunnel(xPara, uno::UNO_QUERY);
-
-    SAL_WARN_IF(!xFPTunnel.is(), "sw.core", "invalid argument");
-    SwXFlatParagraph* const pFlatParagraph(comphelper::getFromUnoTunnel<SwXFlatParagraph>(xFPTunnel));
-
+    SwXFlatParagraph* const pFlatParagraph(dynamic_cast<SwXFlatParagraph*>(xPara.get()));
+    SAL_WARN_IF(!pFlatParagraph, "sw.core", "invalid argument");
     if ( !pFlatParagraph )
         return xRet;
 
