@@ -358,31 +358,31 @@ void WrapOleGraphicInRtf(SvStream& rRtf, sal_uInt32 nWidth, sal_uInt32 nHeight,
                          const sal_uInt8* pPresentationData, sal_uInt64 nPresentationData)
 {
     // Start result.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_RESULT);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_RESULT);
 
     // Start pict.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_PICT);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_PICT);
 
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_WMETAFILE "8");
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICW);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_WMETAFILE "8");
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICW);
     rRtf.WriteOString(OString::number(nWidth));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICH);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICH);
     rRtf.WriteOString(OString::number(nHeight));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICWGOAL);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICWGOAL);
     rRtf.WriteOString(OString::number(nWidth));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICHGOAL);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICHGOAL);
     rRtf.WriteOString(OString::number(nHeight));
     if (pPresentationData)
     {
-        rRtf.WriteCharPtr(SAL_NEWLINE_STRING);
+        rRtf.WriteOString(SAL_NEWLINE_STRING);
         msfilter::rtfutil::WriteHex(pPresentationData, nPresentationData, &rRtf);
     }
 
     // End pict.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     // End result.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 }
 }
 
@@ -462,28 +462,28 @@ bool WrapOleInRtf(SvStream& rOle2, SvStream& rRtf, SwOLENode& rOLENode,
                                           pPresentationData, nPresentationData);
 
     // Start object.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_OBJECT);
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJEMB);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_OBJECT);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJEMB);
 
     // Start objclass.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJCLASS " ");
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJCLASS " ");
     rRtf.WriteOString(aClassName);
     // End objclass.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     // Object size.
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJW);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJW);
     rRtf.WriteOString(OString::number(nWidth));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJH);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJH);
     rRtf.WriteOString(OString::number(nHeight));
 
     // Start objdata.
-    rRtf.WriteCharPtr(
+    rRtf.WriteOString(
         "{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJDATA SAL_NEWLINE_STRING);
     msfilter::rtfutil::WriteHex(static_cast<const sal_uInt8*>(aOLE1.GetData()), aOLE1.GetSize(),
                                 &rRtf);
     // End objdata.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     if (pPresentationData)
     {
@@ -491,7 +491,7 @@ bool WrapOleInRtf(SvStream& rOle2, SvStream& rRtf, SwOLENode& rOLENode,
     }
 
     // End object.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     return true;
 }
@@ -499,29 +499,29 @@ bool WrapOleInRtf(SvStream& rOle2, SvStream& rRtf, SwOLENode& rOLENode,
 bool WrapGraphicInRtf(const Graphic& rGraphic, const SwFrameFormat& rFormat, SvStream& rRtf)
 {
     // Start object.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_OBJECT);
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJEMB);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_OBJECT);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJEMB);
 
     // Object size: as used in the document model (not pixel size)
     Size aSize = rFormat.GetFrameSize().GetSize();
     sal_uInt32 nWidth = aSize.getWidth();
     sal_uInt32 nHeight = aSize.getHeight();
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJW);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJW);
     rRtf.WriteOString(OString::number(nWidth));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_OBJH);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_OBJH);
     rRtf.WriteOString(OString::number(nHeight));
     rRtf.WriteOString(SAL_NEWLINE_STRING);
 
     // Start objclass.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJCLASS " ");
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJCLASS " ");
     OString aClassName("PBrush");
     rRtf.WriteOString(aClassName);
     // End objclass.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
     rRtf.WriteOString(SAL_NEWLINE_STRING);
 
     // Start objdata.
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJDATA " ");
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_IGNORE OOO_STRING_SVTOOLS_RTF_OBJDATA " ");
 
     SvMemoryStream aOle1;
     // Write ObjectHeader, see [MS-OLEDS] 2.2.4.
@@ -612,23 +612,23 @@ bool WrapGraphicInRtf(const Graphic& rGraphic, const SwFrameFormat& rFormat, SvS
     // End objdata.
     msfilter::rtfutil::WriteHex(static_cast<const sal_uInt8*>(aOle1.GetData()), aOle1.GetSize(),
                                 &rRtf);
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
     rRtf.WriteOString(SAL_NEWLINE_STRING);
 
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_RESULT);
-    rRtf.WriteCharPtr("{" OOO_STRING_SVTOOLS_RTF_PICT);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_RESULT);
+    rRtf.WriteOString("{" OOO_STRING_SVTOOLS_RTF_PICT);
 
     Size aMapped(rGraphic.GetPrefSize());
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICW);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICW);
     rRtf.WriteOString(OString::number(aMapped.Width()));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICH);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICH);
     rRtf.WriteOString(OString::number(aMapped.Height()));
 
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICWGOAL);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICWGOAL);
     rRtf.WriteOString(OString::number(nWidth));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_PICHGOAL);
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_PICHGOAL);
     rRtf.WriteOString(OString::number(nHeight));
-    rRtf.WriteCharPtr(OOO_STRING_SVTOOLS_RTF_WMETAFILE "8");
+    rRtf.WriteOString(OOO_STRING_SVTOOLS_RTF_WMETAFILE "8");
     rRtf.WriteOString(SAL_NEWLINE_STRING);
 
     if (pPresentationData)
@@ -638,13 +638,13 @@ bool WrapGraphicInRtf(const Graphic& rGraphic, const SwFrameFormat& rFormat, SvS
     }
 
     // End pict.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     // End result.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
 
     // End object.
-    rRtf.WriteCharPtr("}");
+    rRtf.WriteOString("}");
     return true;
 }
 }
