@@ -490,7 +490,8 @@ public:
     /// Writes wp wrapper code around an SdrObject, which itself is written using drawingML syntax.
 
     void textFrameShadow(const SwFrameFormat& rFrameFormat);
-    static bool isSupportedDMLShape(const uno::Reference<drawing::XShape>& xShape);
+    static bool isSupportedDMLShape(const uno::Reference<drawing::XShape>& xShape,
+                                    const SdrObject* pSdrObject);
 
     void setSerializer(const sax_fastparser::FSHelperPtr& pSerializer)
     {
@@ -852,10 +853,10 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
         }
         attrList->add(XML_behindDoc, bOpaque ? "0" : "1");
 
-        attrList->add(XML_distT, OString::number(TwipsToEMU(nDistT)).getStr());
-        attrList->add(XML_distB, OString::number(TwipsToEMU(nDistB)).getStr());
-        attrList->add(XML_distL, OString::number(TwipsToEMU(nDistL)).getStr());
-        attrList->add(XML_distR, OString::number(TwipsToEMU(nDistR)).getStr());
+        attrList->add(XML_distT, OString::number(TwipsToEMU(nDistT)));
+        attrList->add(XML_distB, OString::number(TwipsToEMU(nDistB)));
+        attrList->add(XML_distL, OString::number(TwipsToEMU(nDistL)));
+        attrList->add(XML_distR, OString::number(TwipsToEMU(nDistR)));
 
         attrList->add(XML_simplePos, "0");
         attrList->add(XML_locked, "0");
@@ -869,6 +870,15 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
             if (xShapeProps.is())
                 xShapeProps->getPropertyValue("IsFollowingTextFlow") >>= bLclInTabCell;
         }
+
+        if (pFrameFormat->GetSurround().GetValue() == text::WrapTextMode_THROUGH
+            && pFrameFormat->GetHoriOrient().GetRelationOrient() == text::RelOrientation::FRAME)
+        {
+            // "In front of text" and horizontal positioning relative to Column is ignored on
+            // import, add it back here.
+            bLclInTabCell = true;
+        }
+
         if (bLclInTabCell)
             attrList->add(XML_layoutInCell, "1");
         else
@@ -888,8 +898,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
         {
             OUString sAnchorId = lclGetAnchorIdFromGrabBag(pObj);
             if (!sAnchorId.isEmpty())
-                attrList->addNS(XML_wp14, XML_anchorId,
-                                OUStringToOString(sAnchorId, RTL_TEXTENCODING_UTF8));
+                attrList->addNS(XML_wp14, XML_anchorId, sAnchorId);
         }
 
         m_pImpl->getSerializer()->startElementNS(XML_wp, XML_anchor, attrList);
@@ -1096,16 +1105,15 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
         // nDist is forced to zero above and ignored by Word anyway, so write 0 directly.
         rtl::Reference<sax_fastparser::FastAttributeList> aAttrList
             = sax_fastparser::FastSerializerHelper::createAttrList();
-        aAttrList->add(XML_distT, OString::number(0).getStr());
-        aAttrList->add(XML_distB, OString::number(0).getStr());
-        aAttrList->add(XML_distL, OString::number(0).getStr());
-        aAttrList->add(XML_distR, OString::number(0).getStr());
+        aAttrList->add(XML_distT, OString::number(0));
+        aAttrList->add(XML_distB, OString::number(0));
+        aAttrList->add(XML_distL, OString::number(0));
+        aAttrList->add(XML_distR, OString::number(0));
         if (pObj)
         {
             OUString sAnchorId = lclGetAnchorIdFromGrabBag(pObj);
             if (!sAnchorId.isEmpty())
-                aAttrList->addNS(XML_wp14, XML_anchorId,
-                                 OUStringToOString(sAnchorId, RTL_TEXTENCODING_UTF8));
+                aAttrList->addNS(XML_wp14, XML_anchorId, sAnchorId);
         }
         m_pImpl->getSerializer()->startElementNS(XML_wp, XML_inline, aAttrList);
     }
@@ -1375,11 +1383,31 @@ static bool lcl_isLockedCanvas(const uno::Reference<drawing::XShape>& xShape)
     });
 }
 
+void AddExtLst(sax_fastparser::FSHelperPtr const& pFS, DocxExport const& rExport,
+               uno::Reference<beans::XPropertySet> const& xShape)
+{
+    if (xShape->getPropertyValue("Decorative").get<bool>())
+    {
+        pFS->startElementNS(XML_a, XML_extLst,
+                            // apparently for DOCX the namespace isn't declared on the root
+                            FSNS(XML_xmlns, XML_a),
+                            rExport.GetFilter().getNamespaceURL(OOX_NS(dml)));
+        pFS->startElementNS(XML_a, XML_ext,
+                            // Word uses this "URI" which is obviously not a URI
+                            XML_uri, "{C183D7F6-B498-43B3-948B-1728B52AA6E4}");
+        pFS->singleElementNS(XML_adec, XML_decorative, FSNS(XML_xmlns, XML_adec),
+                             "http://schemas.microsoft.com/office/drawing/2017/decorative", XML_val,
+                             "1");
+        pFS->endElementNS(XML_a, XML_ext);
+        pFS->endElementNS(XML_a, XML_extLst);
+    }
+}
+
 void DocxSdrExport::writeDMLDrawing(const SdrObject* pSdrObject, const SwFrameFormat* pFrameFormat,
                                     int nAnchorId)
 {
     uno::Reference<drawing::XShape> xShape(const_cast<SdrObject*>(pSdrObject)->getUnoShape());
-    if (!Impl::isSupportedDMLShape(xShape))
+    if (!Impl::isSupportedDMLShape(xShape, pSdrObject))
         return;
 
     m_pImpl->getExport().DocxAttrOutput().GetSdtEndBefore(pSdrObject);
@@ -1391,18 +1419,16 @@ void DocxSdrExport::writeDMLDrawing(const SdrObject* pSdrObject, const SwFrameFo
 
     rtl::Reference<sax_fastparser::FastAttributeList> pDocPrAttrList
         = sax_fastparser::FastSerializerHelper::createAttrList();
-    pDocPrAttrList->add(XML_id, OString::number(nAnchorId).getStr());
-    pDocPrAttrList->add(XML_name, OUStringToOString(pSdrObject->GetName(), RTL_TEXTENCODING_UTF8));
+    pDocPrAttrList->add(XML_id, OString::number(nAnchorId));
+    pDocPrAttrList->add(XML_name, pSdrObject->GetName());
     if (!pSdrObject->GetTitle().isEmpty())
-        pDocPrAttrList->add(XML_title,
-                            OUStringToOString(pSdrObject->GetTitle(), RTL_TEXTENCODING_UTF8));
+        pDocPrAttrList->add(XML_title, pSdrObject->GetTitle());
     if (!pSdrObject->GetDescription().isEmpty())
-        pDocPrAttrList->add(XML_descr,
-                            OUStringToOString(pSdrObject->GetDescription(), RTL_TEXTENCODING_UTF8));
+        pDocPrAttrList->add(XML_descr, pSdrObject->GetDescription());
     if (!pSdrObject->IsVisible()
         && pFrameFormat->GetAnchor().GetAnchorId() != RndStdIds::FLY_AS_CHAR)
 
-        pDocPrAttrList->add(XML_hidden, OString::number(1).getStr());
+        pDocPrAttrList->add(XML_hidden, OString::number(1));
 
     pFS->startElementNS(XML_wp, XML_docPr, pDocPrAttrList);
     OUString sHyperlink = pSdrObject->getHyperlink();
@@ -1416,6 +1442,9 @@ void DocxSdrExport::writeDMLDrawing(const SdrObject* pSdrObject, const SwFrameFo
                              FSNS(XML_xmlns, XML_a),
                              m_pImpl->getExport().GetFilter().getNamespaceURL(OOX_NS(dml)));
     }
+    uno::Reference<beans::XPropertySet> const xShapeProps(xShape, uno::UNO_QUERY_THROW);
+    AddExtLst(pFS, m_pImpl->getExport(), xShapeProps);
+
     pFS->endElementNS(XML_wp, XML_docPr);
 
     uno::Reference<lang::XServiceInfo> xServiceInfo(xShape, uno::UNO_QUERY_THROW);
@@ -1539,23 +1568,33 @@ void DocxSdrExport::Impl::textFrameShadow(const SwFrameFormat& rFrameFormat)
                                    XML_offset, aOffset);
 }
 
-bool DocxSdrExport::Impl::isSupportedDMLShape(const uno::Reference<drawing::XShape>& xShape)
+bool DocxSdrExport::Impl::isSupportedDMLShape(const uno::Reference<drawing::XShape>& xShape,
+                                              const SdrObject* pSdrObject)
 {
     uno::Reference<lang::XServiceInfo> xServiceInfo(xShape, uno::UNO_QUERY_THROW);
     if (xServiceInfo->supportsService("com.sun.star.drawing.PolyPolygonShape")
         || xServiceInfo->supportsService("com.sun.star.drawing.PolyLineShape"))
         return false;
 
+    uno::Reference<beans::XPropertySet> xShapeProperties(xShape, uno::UNO_QUERY);
     // For signature line shapes, we don't want DML, just the VML shape.
     if (xServiceInfo->supportsService("com.sun.star.drawing.GraphicObjectShape"))
     {
-        uno::Reference<beans::XPropertySet> xShapeProperties(xShape, uno::UNO_QUERY);
         bool bIsSignatureLineShape = false;
         xShapeProperties->getPropertyValue("IsSignatureLine") >>= bIsSignatureLineShape;
         if (bIsSignatureLineShape)
             return false;
     }
 
+    // A FontWork shape with bitmap fill cannot be expressed as a modern 'abc transform'
+    // in Word. Only the legacy VML WordArt allows bitmap fill.
+    if (pSdrObject->IsTextPath())
+    {
+        css::drawing::FillStyle eFillStyle = css::drawing::FillStyle_SOLID;
+        xShapeProperties->getPropertyValue("FillStyle") >>= eFillStyle;
+        if (eFillStyle == css::drawing::FillStyle_BITMAP)
+            return false;
+    }
     return true;
 }
 
@@ -1575,7 +1614,7 @@ void DocxSdrExport::writeDMLAndVMLDrawing(const SdrObject* sdrObj,
 
     // In case we are already inside a DML block, then write the shape only as VML, turn out that's allowed to do.
     // A common service created in util to check for VML shapes which are allowed to have textbox in content
-    if ((msfilter::util::HasTextBoxContent(eShapeType)) && Impl::isSupportedDMLShape(xShape)
+    if ((msfilter::util::HasTextBoxContent(eShapeType)) && Impl::isSupportedDMLShape(xShape, sdrObj)
         && (!bDMLAndVMLDrawingOpen || lcl_isLockedCanvas(xShape))) // Locked canvas is OK inside DML
     {
         m_pImpl->getSerializer()->startElementNS(XML_mc, XML_AlternateContent);
@@ -1785,9 +1824,8 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
 
         rtl::Reference<sax_fastparser::FastAttributeList> pDocPrAttrList
             = sax_fastparser::FastSerializerHelper::createAttrList();
-        pDocPrAttrList->add(XML_id, OString::number(nAnchorId).getStr());
-        pDocPrAttrList->add(XML_name,
-                            OUStringToOString(rFrameFormat.GetName(), RTL_TEXTENCODING_UTF8));
+        pDocPrAttrList->add(XML_id, OString::number(nAnchorId));
+        pDocPrAttrList->add(XML_name, rFrameFormat.GetName());
 
         pFS->startElementNS(XML_wp, XML_docPr, pDocPrAttrList);
 
@@ -2083,8 +2121,7 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
     {
         OUString sAnchorId = lclGetAnchorIdFromGrabBag(pObject);
         if (!sAnchorId.isEmpty())
-            m_pImpl->getFlyAttrList()->addNS(XML_w14, XML_anchorId,
-                                             OUStringToOString(sAnchorId, RTL_TEXTENCODING_UTF8));
+            m_pImpl->getFlyAttrList()->addNS(XML_w14, XML_anchorId, sAnchorId);
 
         uno::Reference<drawing::XShape> xShape(const_cast<SdrObject*>(pObject)->getUnoShape(),
                                                uno::UNO_QUERY);
@@ -2093,8 +2130,7 @@ void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bText
         if (xShapeProps.is())
             xShapeProps->getPropertyValue("HyperLinkURL") >>= sHyperlink;
         if (!sHyperlink.isEmpty())
-            m_pImpl->getFlyAttrList()->add(XML_href,
-                                           OUStringToOString(sHyperlink, RTL_TEXTENCODING_UTF8));
+            m_pImpl->getFlyAttrList()->add(XML_href, sHyperlink);
     }
     rtl::Reference<FastAttributeList> xFlyAttrList(m_pImpl->getFlyAttrList());
     m_pImpl->getFlyAttrList().clear();
