@@ -210,7 +210,7 @@ public:
     // empty styles have not to be exported
     if( !pFrameSize && !pBrush && !pRowSplit && !pHasTextChangesOnly )
     {
-        m_rFormatMap.emplace(&rFrameFormat, ::std::optional<OUString>()); // empty just to enable assert
+        m_rFormatMap.try_emplace(&rFrameFormat); // empty just to enable assert
         return {};
     }
 
@@ -293,13 +293,13 @@ public:
         // found!
         auto const oName(m_rFormatMap.find(pTestFormat)->second);
         assert(oName);
-        m_rFormatMap.emplace(&rFrameFormat, oName);
+        m_rFormatMap.try_emplace(&rFrameFormat, oName);
         return {};
     }
 
     {
         OUString const name(OUString::Concat(rNamePrefix) + "." + OUString::number(nLine+1));
-        m_rFormatMap.emplace(&rFrameFormat, ::std::optional<OUString>(name));
+        m_rFormatMap.try_emplace(&rFrameFormat, name);
         if ( i != m_aFormatList.end() ) ++i;
         m_aFormatList.insert( i, &rFrameFormat );
         return ::std::optional<OUString>(name);
@@ -334,11 +334,13 @@ static OUString lcl_xmltble_appendBoxPrefix(std::u16string_view rNamePrefix,
                                                 false );
     const SvXMLAttrContainerItem *pAttCnt = rItemSet.GetItemIfSet( RES_UNKNOWNATR_CONTAINER,
                                                 false );
+    const SvxPrintItem *pHasTextChangesOnly = rItemSet.GetItemIfSet( RES_PRINT, false);
 
     // empty styles have not to be exported
-    if( !pVertOrient && !pBrush && !pBox && !pNumFormat && !pFrameDir && !pAttCnt )
+    if( !pVertOrient && !pBrush && !pBox && !pNumFormat && !pFrameDir && !pAttCnt &&
+        !pHasTextChangesOnly )
     {
-        m_rFormatMap.emplace(&rFrameFormat, ::std::optional<OUString>()); // empty just to enable assert
+        m_rFormatMap.try_emplace(&rFrameFormat); // empty just to enable assert
         return {};
     }
 
@@ -357,6 +359,7 @@ static OUString lcl_xmltble_appendBoxPrefix(std::u16string_view rNamePrefix,
         const SwTableBoxNumFormat *pTestNumFormat = nullptr;
         const SvxFrameDirectionItem *pTestFrameDir = nullptr;
         const SvXMLAttrContainerItem *pTestAttCnt = nullptr;
+        const SvxPrintItem *pTestHasTextChangesOnly = rItemSet.GetItemIfSet( RES_PRINT, false);
         const SwFrameFormat* pTestFormat = *i;
         const SfxItemSet& rTestSet = pTestFormat->GetAttrSet();
         if( const SwFormatVertOrient* pItem = rTestSet.GetItemIfSet( RES_VERT_ORIENT, false ) )
@@ -443,6 +446,19 @@ static OUString lcl_xmltble_appendBoxPrefix(std::u16string_view rNamePrefix,
 
         }
 
+        if( const SvxPrintItem* pItem = rTestSet.GetItemIfSet( RES_PRINT, false ) )
+        {
+            if( !pHasTextChangesOnly )
+                break;
+
+            pTestHasTextChangesOnly = pItem;
+        }
+        else
+        {
+            if( pHasTextChangesOnly )
+                continue;
+        }
+
         if( pVertOrient &&
             pVertOrient->GetVertOrient() != pTestVertOrient->GetVertOrient() )
             continue;
@@ -462,16 +478,19 @@ static OUString lcl_xmltble_appendBoxPrefix(std::u16string_view rNamePrefix,
         if( pAttCnt && ( *pAttCnt != *pTestAttCnt ) )
             continue;
 
+        if( pHasTextChangesOnly && (!pHasTextChangesOnly->GetValue() != !pTestHasTextChangesOnly->GetValue()) )
+            continue;
+
         // found!
         auto const oName(m_rFormatMap.find(pTestFormat)->second);
         assert(oName);
-        m_rFormatMap.emplace(&rFrameFormat, oName);
+        m_rFormatMap.try_emplace(&rFrameFormat, oName);
         return {};
     }
 
     {
         OUString const name(lcl_xmltble_appendBoxPrefix(rNamePrefix, nCol, nRow, bTop));
-        m_rFormatMap.emplace(&rFrameFormat, ::std::optional<OUString>(name));
+        m_rFormatMap.try_emplace(&rFrameFormat, name);
         if ( i != m_aFormatList.end() ) ++i;
         m_aFormatList.insert( i, &rFrameFormat );
         return ::std::optional<OUString>(name);
@@ -537,9 +556,9 @@ void SwXMLExport::ExportTableColumnStyle( const SwXMLTableColumn_Impl& rCol )
     {
         SvXMLElementExport aElem( *this, XML_NAMESPACE_STYLE, XML_STYLE, true,
                                   true );
-        OUStringBuffer sValue;
         if( rCol.GetWidthOpt() )
         {
+            OUStringBuffer sValue;
             GetTwipUnitConverter().convertMeasureToXML( sValue,
                     rCol.GetWidthOpt() );
             AddAttribute( XML_NAMESPACE_STYLE, XML_COLUMN_WIDTH,
@@ -547,10 +566,9 @@ void SwXMLExport::ExportTableColumnStyle( const SwXMLTableColumn_Impl& rCol )
         }
         if( rCol.GetRelWidth() )
         {
-            sValue.append( static_cast<sal_Int32>(rCol.GetRelWidth()) );
-            sValue.append( '*' );
+            OUString sValue = OUString::number(static_cast<sal_Int32>(rCol.GetRelWidth()) ) + "*";
             AddAttribute( XML_NAMESPACE_STYLE, XML_REL_COLUMN_WIDTH,
-                          sValue.makeStringAndClear() );
+                          sValue );
         }
 
         {
@@ -648,7 +666,7 @@ void SwXMLExport::ExportTableLinesAutoStyles( const SwTableLines& rLines,
         SwFrameFormat *pFrameFormat = pLine->GetFrameFormat();
         if (auto oNew = rExpRows.AddRow(*pFrameFormat, rNamePrefix, nLine))
         {
-            ExportFormat(*pFrameFormat, XML_TABLE_ROW, oNew);
+            ExportFormat(*pFrameFormat, XML_TABLE_ROW, std::move(oNew));
         }
 
         const SwTableBoxes& rBoxes = pLine->GetTabBoxes();
@@ -679,7 +697,7 @@ void SwXMLExport::ExportTableLinesAutoStyles( const SwTableLines& rLines,
                 if (auto oNew = rExpCells.AddCell(*pFrameFormat2, rNamePrefix, nOldCol, nLine,
                                        bTop) )
                 {
-                    ExportFormat(*pFrameFormat2, XML_TABLE_CELL, oNew);
+                    ExportFormat(*pFrameFormat2, XML_TABLE_CELL, std::move(oNew));
                 }
 
                 Reference < XCell > xCell = SwXCell::CreateXCell(
@@ -1208,8 +1226,7 @@ void SwXMLTextParagraphExport::exportTable(
     OSL_ENSURE( xTextTable.is(), "text table missing" );
     if( xTextTable.is() )
     {
-        Reference<XUnoTunnel> xTableTunnel( rTextContent, UNO_QUERY);
-        SwXTextTable* pXTable = comphelper::getFromUnoTunnel<SwXTextTable>(xTableTunnel);
+        SwXTextTable* pXTable = dynamic_cast<SwXTextTable*>(rTextContent.get());
         if( pXTable )
         {
             SwFrameFormat *const pFormat = pXTable->GetFrameFormat();
@@ -1220,7 +1237,6 @@ void SwXMLTextParagraphExport::exportTable(
             OSL_ENSURE( pTableNd, "table node missing" );
             if( bAutoStyles )
             {
-                SwNodeIndex aIdx( *pTableNd );
                 // AUTOSTYLES: Optimization: Do not export table autostyle if
                 // we are currently exporting the content.xml stuff and
                 // the table is located in header/footer:
@@ -1228,10 +1244,10 @@ void SwXMLTextParagraphExport::exportTable(
                 // ALL flags are set at the same time.
                 const bool bExportStyles = bool( GetExport().getExportFlags() & SvXMLExportFlags::STYLES );
                 if (!isAutoStylesCollected()
-                    && (bExportStyles || !pFormat->GetDoc()->IsInHeaderFooter(aIdx)))
+                    && (bExportStyles || !pFormat->GetDoc()->IsInHeaderFooter(*pTableNd)))
                 {
                     maTableNodes.push_back(pTableNd);
-                    m_TableFormats.emplace(pTableNd, ::std::make_pair(SwXMLTextParagraphExport::FormatMap(), SwXMLTextParagraphExport::FormatMap()));
+                    m_TableFormats.try_emplace(pTableNd);
                     // Collect all tables inside cells of this table, too
                     CollectTableLinesAutoStyles(pTable->GetTabLines(), *pFormat, _bProgress);
                 }
