@@ -19,6 +19,7 @@
 
 #include <sal/config.h>
 
+#include <optional>
 #include <utility>
 
 #include <hintids.hxx>
@@ -71,7 +72,7 @@ SwAsciiFilterDlg::SwAsciiFilterDlg( weld::Window* pParent, SwDocShell& rDocSh,
 
     SwAsciiOptions aOpt;
     {
-        SvtViewOptions aDlgOpt(EViewType::Dialog, OStringToOUString(m_xDialog->get_help_id(), RTL_TEXTENCODING_UTF8));
+        SvtViewOptions aDlgOpt(EViewType::Dialog, m_xDialog->get_help_id());
         if (aDlgOpt.Exists())
         {
             css::uno::Any aUserItem = aDlgOpt.GetUserItem("UserItem");
@@ -265,7 +266,7 @@ SwAsciiFilterDlg::SwAsciiFilterDlg( weld::Window* pParent, SwDocShell& rDocSh,
 
 SwAsciiFilterDlg::~SwAsciiFilterDlg()
 {
-    SvtViewOptions aDlgOpt(EViewType::Dialog, OStringToOUString(m_xDialog->get_help_id(), RTL_TEXTENCODING_UTF8));
+    SvtViewOptions aDlgOpt(EViewType::Dialog, m_xDialog->get_help_id());
     aDlgOpt.SetUserItem("UserItem", uno::Any(m_sExtraData));
 }
 
@@ -364,7 +365,8 @@ void SwAsciiFilterDlg::UpdateIncludeBOMSensitiveState()
 
 IMPL_LINK_NOARG(SwAsciiFilterDlg, CharSetSelHdl, weld::ComboBox&, void)
 {
-    LineEnd eOldEnd = GetCRLF(), eEnd = LineEnd(-1);
+    LineEnd eOldEnd = GetCRLF();
+    std::optional<LineEnd> eEnd;
     LanguageType nLng = m_xFontLB->get_visible()
                     ? m_xLanguageLB->get_active_id()
                     : LANGUAGE_SYSTEM,
@@ -418,10 +420,10 @@ IMPL_LINK_NOARG(SwAsciiFilterDlg, CharSetSelHdl, weld::ComboBox&, void)
     }
 
     m_bSaveLineStatus = false;
-    if( eEnd != LineEnd(-1) )       // changed?
+    if( eEnd )       // changed?
     {
-        if( eOldEnd != eEnd )
-            SetCRLF( eEnd );
+        if( eOldEnd != *eEnd )
+            SetCRLF( *eEnd );
     }
     else
     {
