@@ -72,6 +72,8 @@
 #include <viewopt.hxx>
 #include <txmsrt.hxx>
 #include <unotools/useroptions.hxx>
+#include <IDocumentContentOperations.hxx>
+#include <translatehelper.hxx>
 
 using namespace com::sun::star::uno;
 using namespace com::sun::star::container;
@@ -157,14 +159,14 @@ const TranslateId FMT_AUTHOR_ARY[] =
 
 const TranslateId FLD_DATE_ARY[] =
 {
-    FLD_DATE_FIX,
     FLD_DATE_STD,
+    FLD_DATE_FIX
 };
 
 const TranslateId FLD_TIME_ARY[] =
 {
-    FLD_TIME_FIX,
-    FLD_TIME_STD
+    FLD_TIME_STD,
+    FLD_TIME_FIX
 };
 
 const TranslateId FMT_NUM_ARY[] =
@@ -355,10 +357,8 @@ const SwFieldPack aSwFields[] =
 // access to the shell
 static SwWrtShell* lcl_GetShell()
 {
-    SwView* pView = ::GetActiveView();
-    if ( nullptr != pView )
+    if (SwView* pView = GetActiveView())
         return pView->GetWrtShellPtr();
-    OSL_FAIL("no current shell found!");
     return nullptr;
 }
 
@@ -1071,7 +1071,40 @@ bool SwFieldMgr::InsertField(
         {
             if( !rData.m_sPar1.isEmpty() && CanInsertRefMark( rData.m_sPar1 ) )
             {
+                const OUString& rRefmarkText = rData.m_sPar2;
+                SwPaM* pCursorPos = pCurShell->GetCursor();
+                pCurShell->StartAction();
+                if (!rRefmarkText.isEmpty())
+                {
+                    // Split node to remember where the start position is.
+                    bool bSuccess = pCurShell->GetDoc()->getIDocumentContentOperations().SplitNode(
+                            *pCursorPos->GetPoint(), /*bChkTableStart=*/false);
+                    if (bSuccess)
+                    {
+                        SwPaM aRefmarkPam(*pCursorPos->GetPoint());
+                        aRefmarkPam.Move(fnMoveBackward, GoInContent);
+
+                        // Paste HTML content.
+                        SwTranslateHelper::PasteHTMLToPaM(
+                                *pCurShell, pCursorPos, rRefmarkText.toUtf8(), /*bSetSelection=*/true);
+
+                        // Undo the above SplitNode().
+                        aRefmarkPam.SetMark();
+                        aRefmarkPam.Move(fnMoveForward, GoInContent);
+                        pCurShell->GetDoc()->getIDocumentContentOperations().DeleteAndJoin(
+                                aRefmarkPam);
+                        *aRefmarkPam.GetMark() = *pCursorPos->GetPoint();
+                        *pCursorPos = aRefmarkPam;
+                    }
+                }
+
                 pCurShell->SetAttrItem( SwFormatRefMark( rData.m_sPar1 ) );
+
+                if (!rRefmarkText.isEmpty())
+                {
+                    pCursorPos->DeleteMark();
+                }
+                pCurShell->EndAction();
                 return true;
             }
             return false;
@@ -1410,7 +1443,7 @@ bool SwFieldMgr::InsertField(
                 if (pEntry)
                 {
                     SfxStringItem aFormat(FN_NUMBER_FORMAT, pEntry->GetFormatstring());
-                    pCurShell->GetView().GetViewFrame()->GetDispatcher()->
+                    pCurShell->GetView().GetViewFrame().GetDispatcher()->
                         ExecuteList(FN_NUMBER_FORMAT, SfxCallMode::SYNCHRON,
                                 { &aFormat });
                 }
