@@ -31,7 +31,6 @@
 #include <sfx2/infobar.hxx>
 #include <sfx2/request.hxx>
 #include <svl/whiter.hxx>
-#include <svl/visitem.hxx>
 #include <svx/srchdlg.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/bindings.hxx>
@@ -116,12 +115,11 @@ view::XSelectionSupplier* SwView::GetUNOObject()
     return m_pViewImpl->GetUNOObject();
 }
 
-void SwView::ApplyAccessibilityOptions(SvtAccessibilityOptions const & rAccessibilityOptions)
+void SwView::ApplyAccessibilityOptions()
 {
 #if ENABLE_WASM_STRIP_ACCESSIBILITY
-    (void)rAccessibilityOptions;
 #else
-    m_pWrtShell->ApplyAccessibilityOptions(rAccessibilityOptions);
+    m_pWrtShell->ApplyAccessibilityOptions();
     //to enable the right state of the selection cursor in readonly documents
     if(GetDocShell()->IsReadOnly())
         m_pWrtShell->ShowCursor();
@@ -143,13 +141,13 @@ static bool lcl_IsViewMarks( const SwViewOption& rVOpt )
 {
     return  rVOpt.IsHardBlank() &&
             rVOpt.IsSoftHyph() &&
-            SwViewOption::IsFieldShadings();
+            rVOpt.IsFieldShadings();
 }
 static void lcl_SetViewMarks(SwViewOption& rVOpt, bool bOn )
 {
     rVOpt.SetHardBlank(bOn);
     rVOpt.SetSoftHyph(bOn);
-    SwViewOption::SetAppearanceFlag(
+    rVOpt.SetAppearanceFlag(
             ViewOptFlags::FieldShadings, bOn, true);
 }
 
@@ -193,6 +191,7 @@ void SwView::RecheckBrowseMode()
             FN_VLINEAL,             /*20216*/
             FN_VSCROLLBAR,      /*20217*/
             FN_HSCROLLBAR,      /*20218*/
+            FN_VIEW_SECTION_BOUNDARIES, /*20219*/
             FN_VIEW_META_CHARS, /**/
             FN_VIEW_MARKS,      /**/
             //FN_VIEW_FIELDNAME,    /**/
@@ -203,7 +202,7 @@ void SwView::RecheckBrowseMode()
             0
         };
     // the view must not exist!
-    GetViewFrame()->GetBindings().Invalidate(aInva);
+    GetViewFrame().GetBindings().Invalidate(aInva);
     CheckVisArea();
 
     SvxZoomType eType;
@@ -225,7 +224,7 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
     while(nWhich)
     {
         bool bReadonly = GetDocShell()->IsReadOnly();
-        if ( bReadonly && nWhich != FN_VIEW_GRAPHIC )
+        if (bReadonly && nWhich != FN_VIEW_GRAPHIC && nWhich != FN_HIGHLIGHT_CHAR_DF)
         {
             rSet.DisableItem(nWhich);
             nWhich = 0;
@@ -253,11 +252,13 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
             }
             break;
             case FN_VIEW_BOUNDS:
-                aBool.SetValue( SwViewOption::IsDocBoundaries()); break;
+                aBool.SetValue( pOpt->IsDocBoundaries()); break;
+            case FN_VIEW_SECTION_BOUNDARIES:
+                aBool.SetValue(pOpt->IsSectionBoundaries()); break;
             case FN_VIEW_GRAPHIC:
                 aBool.SetValue( pOpt->IsGraphic() ); break;
             case FN_VIEW_FIELDS:
-                aBool.SetValue( SwViewOption::IsFieldShadings() ); break;
+                aBool.SetValue( pOpt->IsFieldShadings() ); break;
             case FN_VIEW_FIELDNAME:
                 aBool.SetValue( pOpt->IsFieldName() ); break;
             case FN_VIEW_MARKS:
@@ -265,7 +266,7 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
             case FN_VIEW_META_CHARS:
                 aBool.SetValue( pOpt->IsViewMetaChars() ); break;
             case FN_VIEW_TABLEGRID:
-                aBool.SetValue( SwViewOption::IsTableBoundaries() ); break;
+                aBool.SetValue( pOpt->IsTableBoundaries() ); break;
             case SID_TOGGLE_NOTES:
             {
                 if (!GetPostItMgr()->HasNotes())
@@ -332,17 +333,8 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
             break;
             case SID_ACCESSIBILITY_CHECK_ONLINE:
             {
-                // visible only when experimental mode is enabled
-                if (!officecfg::Office::Common::Misc::ExperimentalMode::get())
-                {
-                    rSet.Put(SfxVisibilityItem(nWhich, false));
-                    nWhich = 0;
-                }
-                else
-                {
-                    bool bOnlineAccessibilityCheck = officecfg::Office::Common::Accessibility::OnlineAccessibilityCheck::get();
-                    aBool.SetValue(bOnlineAccessibilityCheck);
-                }
+                bool bOnlineAccessibilityCheck = officecfg::Office::Common::Accessibility::OnlineAccessibilityCheck::get();
+                aBool.SetValue(bOnlineAccessibilityCheck);
             }
             break;
             case FN_SHADOWCURSOR:
@@ -366,6 +358,9 @@ void SwView::StateViewOptions(SfxItemSet &rSet)
             case FN_SHOW_CHANGES_IN_MARGIN:
               aBool.SetValue( pOpt->IsShowChangesInMargin() );
             break;
+            case FN_HIGHLIGHT_CHAR_DF:
+              aBool.SetValue(m_bIsHighlightCharDF);
+            break;
         }
 
         if( nWhich )
@@ -411,14 +406,20 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
 
     case FN_VIEW_FIELDS:
         if( STATE_TOGGLE == eState )
-            bFlag = !SwViewOption::IsFieldShadings() ;
-        SwViewOption::SetAppearanceFlag(ViewOptFlags::FieldShadings, bFlag, true );
+            bFlag = !pOpt->IsFieldShadings() ;
+        pOpt->SetAppearanceFlag(ViewOptFlags::FieldShadings, bFlag, true );
         break;
 
     case FN_VIEW_BOUNDS:
         if( STATE_TOGGLE == eState )
-            bFlag = !SwViewOption::IsDocBoundaries();
-        SwViewOption::SetAppearanceFlag(ViewOptFlags::DocBoundaries, bFlag, true );
+            bFlag = !pOpt->IsDocBoundaries();
+        pOpt->SetAppearanceFlag(ViewOptFlags::DocBoundaries, bFlag, true );
+        break;
+
+    case FN_VIEW_SECTION_BOUNDARIES:
+        if( STATE_TOGGLE == eState )
+            bFlag = !pOpt->IsSectionBoundaries();
+        pOpt->SetAppearanceFlag(ViewOptFlags::SectionBoundaries, bFlag, true );
         break;
 
     case SID_GRID_VISIBLE:
@@ -532,8 +533,8 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
 
     case FN_VIEW_TABLEGRID:
         if( STATE_TOGGLE == eState )
-            bFlag = !SwViewOption::IsTableBoundaries();
-        SwViewOption::SetAppearanceFlag(ViewOptFlags::TableBoundaries, bFlag, true );
+            bFlag = !pOpt->IsTableBoundaries();
+        pOpt->SetAppearanceFlag(ViewOptFlags::TableBoundaries, bFlag, true );
         break;
 
     case FN_VIEW_FIELDNAME:
@@ -550,6 +551,12 @@ void SwView::ExecViewOptions(SfxRequest &rReq)
         lcl_SetViewMarks( *pOpt, bFlag );
         break;
 
+    case FN_HIGHLIGHT_CHAR_DF:
+        if (STATE_TOGGLE == eState)
+            bFlag = !m_bIsHighlightCharDF;
+        m_bIsHighlightCharDF = bFlag;
+        break;
+
     case FN_VIEW_META_CHARS:
         if( STATE_TOGGLE == eState )
             bFlag = !pOpt->IsViewMetaChars();
