@@ -37,9 +37,10 @@
 #include <toolkit/awt/vclxwindows.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <toolkit/helper/convert.hxx>
-#include <toolkit/helper/property.hxx>
+#include <helper/property.hxx>
 #include <rtl/math.hxx>
 #include <sal/log.hxx>
+#include <utility>
 #include <vcl/toolkit/floatwin.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/window.hxx>
@@ -404,10 +405,10 @@ namespace
 {
     struct CallWindow2Listener
     {
-        CallWindow2Listener( ::comphelper::OInterfaceContainerHelper3<css::awt::XWindowListener2>& i_rWindow2Listeners, const bool i_bEnabled, const EventObject& i_rEvent )
+        CallWindow2Listener( ::comphelper::OInterfaceContainerHelper3<css::awt::XWindowListener2>& i_rWindow2Listeners, const bool i_bEnabled, EventObject i_Event )
             :m_rWindow2Listeners( i_rWindow2Listeners )
             ,m_bEnabled( i_bEnabled )
-            ,m_aEvent( i_rEvent )
+            ,m_aEvent(std::move( i_Event ))
         {
         }
 
@@ -902,10 +903,6 @@ Size VCLXWindow::ImplCalcWindowSize( const Size& rOutSz ) const
 }
 
 
-// css::lang::XUnoTunnel
-UNO3_GETIMPLEMENTATION2_IMPL(VCLXWindow, VCLXDevice);
-
-
 // css::lang::Component
 void VCLXWindow::dispose(  )
 {
@@ -1149,7 +1146,7 @@ void VCLXWindow::setPointer( const css::uno::Reference< css::awt::XPointer >& rx
 {
     SolarMutexGuard aGuard;
 
-    VCLXPointer* pPointer = comphelper::getFromUnoTunnel<VCLXPointer>( rxPointer );
+    VCLXPointer* pPointer = dynamic_cast<VCLXPointer*>( rxPointer.get() );
     if ( pPointer && GetWindow() )
         GetWindow()->SetPointer( pPointer->GetPointer() );
 }
@@ -1348,12 +1345,12 @@ void VCLXWindow::GetPropertyIds( std::vector< sal_uInt16 >& _out_rIds )
     return ImplGetPropertyIds( _out_rIds, mpImpl->mbWithDefaultProps );
 }
 
-::comphelper::OInterfaceContainerHelper3<css::awt::XVclContainerListener>& VCLXWindow::GetContainerListeners()
+ListenerMultiplexerBase<css::awt::XVclContainerListener>& VCLXWindow::GetContainerListeners()
 {
     return mpImpl->getContainerListeners();
 }
 
-::comphelper::OInterfaceContainerHelper3<css::awt::XTopWindowListener>& VCLXWindow::GetTopWindowListeners()
+ListenerMultiplexerBase<css::awt::XTopWindowListener>& VCLXWindow::GetTopWindowListeners()
 {
     return mpImpl->getTopWindowListeners();
 }
@@ -1535,9 +1532,9 @@ void VCLXWindow::setProperty( const OUString& PropertyName, const css::uno::Any&
             {
                 INetURLObject aHelpURL( aURL );
                 if ( aHelpURL.GetProtocol() == INetProtocol::Hid )
-                    pWindow->SetHelpId( OUStringToOString( aHelpURL.GetURLPath(), RTL_TEXTENCODING_UTF8 ) );
+                    pWindow->SetHelpId( aHelpURL.GetURLPath() );
                 else
-                    pWindow->SetHelpId( OUStringToOString( aURL, RTL_TEXTENCODING_UTF8 ) );
+                    pWindow->SetHelpId( aURL );
             }
         }
         break;
@@ -1701,6 +1698,46 @@ void VCLXWindow::setProperty( const OUString& PropertyName, const css::uno::Any&
                     pWindow->GetOutDev()->SetLineColor( nColor );
             }
         break;
+        case BASEPROPERTY_HIGHLIGHT_COLOR:
+        {
+            Color nColor = 0;
+            if ( bVoid )
+            {
+                nColor = Application::GetSettings().GetStyleSettings().GetHighlightColor();
+            }
+            else
+            {
+                if (!(Value >>= nColor))
+                    break;
+            }
+
+            AllSettings aSettings(pWindow->GetSettings());
+            StyleSettings aStyle(aSettings.GetStyleSettings());
+            aStyle.SetHighlightColor(nColor);
+            aSettings.SetStyleSettings(aStyle);
+            pWindow->SetSettings(aSettings);
+        }
+        break;
+        case BASEPROPERTY_HIGHLIGHT_TEXT_COLOR:
+        {
+            Color nColor = 0;
+            if (bVoid)
+            {
+                nColor = Application::GetSettings().GetStyleSettings().GetHighlightTextColor();
+            }
+            else
+            {
+                if (!(Value >>= nColor))
+                    break;
+            }
+
+            AllSettings aSettings(pWindow->GetSettings());
+            StyleSettings aStyle(aSettings.GetStyleSettings());
+            aStyle.SetHighlightTextColor(nColor);
+            aSettings.SetStyleSettings(aStyle);
+            pWindow->SetSettings(aSettings);
+        }
+        break;
         case BASEPROPERTY_BORDER:
         {
             WinBits nStyle = pWindow->GetStyle();
@@ -1912,6 +1949,21 @@ css::uno::Any VCLXWindow::getProperty( const OUString& PropertyName )
     css::uno::Any aProp;
     if ( GetWindow() )
     {
+        if (PropertyName == "ParentIs100thmm")
+        {
+            bool bParentIs100thmm = false;
+            VclPtr<vcl::Window> pWindow = GetWindow();
+            if (pWindow)
+            {
+                pWindow = pWindow->GetParent();
+                if(pWindow && MapUnit::Map100thMM == pWindow->GetMapMode().GetMapUnit())
+                {
+                    bParentIs100thmm = true;
+                }
+            }
+            aProp <<= bParentIs100thmm;
+            return aProp;
+        }
         WindowType eWinType = GetWindow()->GetType();
         sal_uInt16 nPropType = GetPropertyId( PropertyName );
         switch ( nPropType )
@@ -1990,10 +2042,7 @@ css::uno::Any VCLXWindow::getProperty( const OUString& PropertyName )
             }
             break;
             case BASEPROPERTY_HELPURL:
-            {
-                OUString aHelpId( OStringToOUString( GetWindow()->GetHelpId(), RTL_TEXTENCODING_UTF8 ) );
-                aProp <<= aHelpId;
-            }
+                aProp <<= GetWindow()->GetHelpId();
             break;
             case BASEPROPERTY_FONTDESCRIPTOR:
             {
@@ -2026,6 +2075,12 @@ css::uno::Any VCLXWindow::getProperty( const OUString& PropertyName )
             case BASEPROPERTY_LINECOLOR:
                 aProp <<= GetWindow()->GetOutDev()->GetLineColor();
             break;
+            case BASEPROPERTY_HIGHLIGHT_COLOR:
+                aProp <<= GetWindow()->GetSettings().GetStyleSettings().GetHighlightColor();
+            break;
+            case BASEPROPERTY_HIGHLIGHT_TEXT_COLOR:
+                aProp <<= GetWindow()->GetSettings().GetStyleSettings().GetHighlightTextColor();
+            break;
             case BASEPROPERTY_BORDER:
             {
                 WindowBorderStyle nBorder = WindowBorderStyle::NONE;
