@@ -68,6 +68,7 @@
 #include <ucbhelper/propertyvalueset.hxx>
 #include <ucbhelper/cancelcommandexecution.hxx>
 #include <ucbhelper/macros.hxx>
+#include <utility>
 #include "pkgcontent.hxx"
 #include "pkgprovider.hxx"
 #include "pkgresultset.hxx"
@@ -168,7 +169,7 @@ rtl::Reference<Content> Content::create(
 
         uno::Reference< ucb::XContentIdentifier > xId
             = new ::ucbhelper::ContentIdentifier( aURI.getUri() );
-        return new Content( rxContext, pProvider, xId, xPackage, aURI, aProps );
+        return new Content( rxContext, pProvider, xId, xPackage, aURI, std::move(aProps) );
     }
     else
     {
@@ -217,7 +218,7 @@ rtl::Reference<Content> Content::create(
 
     uno::Reference< ucb::XContentIdentifier > xId
         = new ::ucbhelper::ContentIdentifier( aURI.getUri() );
-    return new Content( rxContext, pProvider, xId, xPackage, aURI, Info );
+    return new Content( rxContext, pProvider, xId, xPackage, std::move(aURI), Info );
 }
 
 
@@ -237,14 +238,14 @@ Content::Content(
         const uno::Reference< uno::XComponentContext >& rxContext,
         ContentProvider* pProvider,
         const uno::Reference< ucb::XContentIdentifier >& Identifier,
-        const uno::Reference< container::XHierarchicalNameAccess > & Package,
-        const PackageUri& rUri,
-        const ContentProperties& rProps )
+        uno::Reference< container::XHierarchicalNameAccess > Package,
+        PackageUri aUri,
+        ContentProperties aProps )
 : ContentImplHelper( rxContext, pProvider, Identifier ),
-  m_aUri( rUri ),
-  m_aProps( rProps ),
+  m_aUri(std::move( aUri )),
+  m_aProps(std::move( aProps )),
   m_eState( PERSISTENT ),
-  m_xPackage( Package ),
+  m_xPackage(std::move( Package )),
   m_pProvider( pProvider ),
   m_nModifiedProps( NONE_MODIFIED )
 {
@@ -255,14 +256,14 @@ Content::Content(
         const uno::Reference< uno::XComponentContext >& rxContext,
         ContentProvider* pProvider,
         const uno::Reference< ucb::XContentIdentifier >& Identifier,
-        const uno::Reference< container::XHierarchicalNameAccess > & Package,
-        const PackageUri& rUri,
+        uno::Reference< container::XHierarchicalNameAccess > Package,
+        PackageUri aUri,
         const ucb::ContentInfo& Info )
   : ContentImplHelper( rxContext, pProvider, Identifier ),
-  m_aUri( rUri ),
+  m_aUri(std::move( aUri )),
   m_aProps( Info.Type ),
   m_eState( TRANSIENT ),
-  m_xPackage( Package ),
+  m_xPackage(std::move( Package )),
   m_pProvider( pProvider ),
   m_nModifiedProps( NONE_MODIFIED )
 {
@@ -1258,8 +1259,8 @@ uno::Sequence< uno::Any > Content::setPropertyValues(
         uno::Reference< ucb::XContentIdentifier > xOldId = m_xIdentifier;
 
         // Assemble new content identifier...
-        OUString aNewURL = m_aUri.getParentUri() + "/";
-        aNewURL += ::ucb_impl::urihelper::encodeSegment( aNewTitle );
+        OUString aNewURL = m_aUri.getParentUri() + "/" +
+            ::ucb_impl::urihelper::encodeSegment( aNewTitle );
         uno::Reference< ucb::XContentIdentifier > xNewId
             = new ::ucbhelper::ContentIdentifier( aNewURL );
 
@@ -1537,8 +1538,7 @@ void Content::insert(
 
                 do
                 {
-                    OUString aNew = aNewUri.getUri() + "_";
-                    aNew += OUString::number( ++nTry );
+                    OUString aNew = aNewUri.getUri() + "_" + OUString::number( ++nTry );
                     aNewUri.setUri( aNew );
                 }
                 while ( hasData( aNewUri ) && ( nTry < 1000 ) );
