@@ -381,44 +381,6 @@ CPPUNIT_TEST_FIXTURE(VclComplexTextTest, testGdefCaret)
 #endif
 }
 
-CPPUNIT_TEST_FIXTURE(VclComplexTextTest, testTdf152048)
-{
-#if HAVE_MORE_FONTS
-    OUString aText(u"می‌شود");
-
-    vcl::Font aFont(u"Noto Naskh Arabic", u"Regular", Size(0, 72));
-
-    ScopedVclPtrInstance<VirtualDevice> pOutDev;
-    pOutDev->SetFont(aFont);
-
-    // get an compare the default text array
-    std::vector<sal_Int32> aRefCharWidths{ 33, 82, 82, 129, 163, 193 };
-    tools::Long nRefTextWidth(193);
-
-    KernArray aCharWidths;
-    tools::Long nTextWidth = pOutDev->GetTextArray(aText, &aCharWidths);
-
-    CPPUNIT_ASSERT_EQUAL(aRefCharWidths, aCharWidths.get_subunit_array());
-    CPPUNIT_ASSERT_EQUAL(nRefTextWidth, nTextWidth);
-    CPPUNIT_ASSERT_EQUAL(sal_Int32(nTextWidth), aCharWidths.back());
-
-    // Simulate Kashida insertion using Kashida array and extending text array
-    // to have room for Kashida.
-    std::vector<sal_Bool> aKashidaArray{ false, false, false, true, false, false };
-    auto nKashida = 200;
-
-    aCharWidths.set(3, aCharWidths[3] + nKashida);
-    aCharWidths.set(4, aCharWidths[4] + nKashida);
-    aCharWidths.set(5, aCharWidths[5] + nKashida);
-    auto pLayout = pOutDev->ImplLayout(aText, 0, -1, Point(0, 0), 0, aCharWidths, aKashidaArray);
-
-    // Without the fix this fails with:
-    // - Expected: 393
-    // - Actual  : 511
-    CPPUNIT_ASSERT_EQUAL(DeviceCoordinate(nRefTextWidth + nKashida), pLayout->GetTextWidth());
-#endif
-}
-
 CPPUNIT_TEST_FIXTURE(VclComplexTextTest, testTdf152048_2)
 {
 #if HAVE_MORE_FONTS
@@ -531,4 +493,37 @@ CPPUNIT_TEST_FIXTURE(VclComplexTextTest, testTdf107718)
 #endif
 }
 
+CPPUNIT_TEST_FIXTURE(VclComplexTextTest, testTdf107612)
+{
+#if HAVE_MORE_FONTS
+    vcl::Font aFont(u"DejaVu Sans", u"Book", Size(0, 72));
+
+    ScopedVclPtrInstance<VirtualDevice> pOutDev;
+    pOutDev->SetFont(aFont);
+
+    auto pLayout = pOutDev->ImplLayout(u"a\u202F\u1823", 0, -1, Point(0, 0), 0, {}, {});
+
+    // If font fallback happened, then the returned layout must be a
+    // MultiSalLayout instance.
+    auto pMultiLayout = dynamic_cast<MultiSalLayout*>(pLayout.get());
+    CPPUNIT_ASSERT(pMultiLayout);
+
+    auto pFallbackRuns = pMultiLayout->GetFallbackRuns();
+    CPPUNIT_ASSERT(!pFallbackRuns->IsEmpty());
+
+    bool bRTL;
+    int nCharPos = -1;
+    std::vector<sal_Int32> aFallbacks;
+    while (pFallbackRuns->GetNextPos(&nCharPos, &bRTL))
+        aFallbacks.push_back(nCharPos);
+
+    // Assert that U+202F is included in the fallback run.
+    // Without the fix this fails with:
+    // - Expected: { 2 }
+    // - Actual  : { 1, 2 }
+    std::vector<sal_Int32> aExpctedFallbacks = { 1, 2 };
+    CPPUNIT_ASSERT_EQUAL(aFallbacks, aExpctedFallbacks);
+#endif
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
