@@ -741,19 +741,19 @@ void QtFrame::StartPresentation(bool bStart)
     // meh - so there's no Qt platform independent solution
     // https://forum.qt.io/topic/38504/solved-qdialog-in-fullscreen-disable-os-screensaver
     assert(m_aSystemData.platform != SystemEnvData::Platform::Invalid);
-    const bool bIsX11 = m_aSystemData.platform == SystemEnvData::Platform::Xcb;
-    std::optional<unsigned int> aRootWindow;
+    unsigned int nRootWindow(0);
     std::optional<Display*> aDisplay;
 
 #if CHECK_QT5_USING_X11
     if (QX11Info::isPlatformX11())
     {
-        aRootWindow = QX11Info::appRootWindow();
+        nRootWindow = QX11Info::appRootWindow();
         aDisplay = QX11Info::display();
     }
 #endif
 
-    m_ScreenSaverInhibitor.inhibit(bStart, u"presentation", bIsX11, aRootWindow, aDisplay);
+    m_SessionManagerInhibitor.inhibit(bStart, u"presentation", APPLICATION_INHIBIT_IDLE,
+                                      nRootWindow, aDisplay);
 #else
     Q_UNUSED(bStart)
 #endif
@@ -1143,6 +1143,8 @@ void QtFrame::UpdateSettings(AllSettings& rSettings)
     style.SetWorkspaceColor(aMid);
 
     // Selection
+    // https://invent.kde.org/plasma/plasma-workspace/-/merge_requests/305
+    style.SetAccentColor(aHigh);
     style.SetHighlightColor(aHigh);
     style.SetHighlightTextColor(aHighText);
     style.SetListBoxWindowHighlightColor(aHigh);
