@@ -41,7 +41,7 @@
 #endif
 #include <quartz/utils.h>
 #ifdef IOS
-#include <svdata.hxx>
+#include <ios/iosinst.hxx>
 #endif
 
 using namespace vcl;
@@ -199,7 +199,7 @@ AquaGraphicsBackend::~AquaGraphicsBackend() {}
 void AquaGraphicsBackend::Init() {}
 void AquaGraphicsBackend::freeResources() {}
 
-bool AquaGraphicsBackend::setClipRegion(vcl::Region const& rRegion)
+void AquaGraphicsBackend::setClipRegion(vcl::Region const& rRegion)
 {
     // release old clip path
     mrShared.unsetClipPath();
@@ -227,8 +227,6 @@ bool AquaGraphicsBackend::setClipRegion(vcl::Region const& rRegion)
     // set the current path as clip region
     if (mrShared.checkContext())
         mrShared.setState();
-
-    return true;
 }
 
 void AquaGraphicsBackend::ResetClipRegion()
