@@ -159,6 +159,8 @@ std::vector<fontID> PrintFontManager::addFontFile( std::u16string_view rFileUrl
     std::vector<fontID> aFontIds = findFontFileIDs( nDirID, aName );
     if( aFontIds.empty() )
     {
+        addFontconfigFile(OUStringToOString(aPath.GetFull(), osl_getThreadTextEncoding()));
+
         std::vector<PrintFont> aNewFonts = analyzeFontFile(nDirID, aName);
         for (auto & font : aNewFonts)
         {
@@ -179,25 +181,36 @@ std::vector<PrintFontManager::PrintFont> PrintFontManager::analyzeFontFile( int
 
     OString aFullPath = aDir + "/" + rFontFile;
 
-    // #i1872# reject unreadable files
-    if( access( aFullPath.getStr(), R_OK ) )
-        return aNewFonts;
-
-    bool bSupported = false;
-    if (pFormat)
+    bool bSupported;
+    int nFD;
+    int n;
+    if (sscanf(aFullPath.getStr(), "/:FD:/%d%n", &nFD, &n) == 1 && aFullPath.getStr()[n] == '\0')
     {
-        if (!strcmp(pFormat, "TrueType") ||
-            !strcmp(pFormat, "CFF"))
-            bSupported = true;
+        // Hack, pathname that actually means we will use a pre-opened file descriptor
+        bSupported = true;
     }
-    if (!bSupported)
+    else
     {
-        OString aExt( rFontFile.copy( rFontFile.lastIndexOf( '.' )+1 ) );
-        if( aExt.equalsIgnoreAsciiCase("ttf")
-             ||  aExt.equalsIgnoreAsciiCase("ttc")
-             ||  aExt.equalsIgnoreAsciiCase("tte")   // #i33947# for Gaiji support
-             ||  aExt.equalsIgnoreAsciiCase("otf") ) // check for TTF- and PS-OpenType too
-            bSupported = true;
+        // #i1872# reject unreadable files
+        if( access( aFullPath.getStr(), R_OK ) )
+            return aNewFonts;
+
+        bSupported = false;
+        if (pFormat)
+        {
+            if (!strcmp(pFormat, "TrueType") ||
+                !strcmp(pFormat, "CFF"))
+                bSupported = true;
+        }
+        if (!bSupported)
+        {
+            OString aExt( rFontFile.copy( rFontFile.lastIndexOf( '.' )+1 ) );
+            if( aExt.equalsIgnoreAsciiCase("ttf")
+                 ||  aExt.equalsIgnoreAsciiCase("ttc")
+                 ||  aExt.equalsIgnoreAsciiCase("tte")   // #i33947# for Gaiji support
+                 ||  aExt.equalsIgnoreAsciiCase("otf") ) // check for TTF- and PS-OpenType too
+                bSupported = true;
+        }
     }
 
     if (bSupported)
@@ -208,34 +221,6 @@ std::vector<PrintFontManager::PrintFont> PrintFontManager::analyzeFontFile( int
         {
             SAL_INFO("vcl.fonts", "ttc: " << aFullPath << " contains " << nLength << " fonts");
 
-            sal_uInt64 fileSize = 0;
-
-            OUString aURL;
-            if (osl::File::getFileURLFromSystemPath(OStringToOUString(aFullPath, osl_getThreadTextEncoding()),
-                aURL) == osl::File::E_None)
-            {
-                osl::File aFile(aURL);
-                if (aFile.open(osl_File_OpenFlag_Read | osl_File_OpenFlag_NoLock) == osl::File::E_None)
-                {
-                    osl::DirectoryItem aItem;
-                    if (osl::DirectoryItem::get(aURL, aItem) == osl::File::E_None)
-                    {
-                        osl::FileStatus aFileStatus( osl_FileStatus_Mask_FileSize );
-                        if (aItem.getFileStatus(aFileStatus) == osl::File::E_None)
-                            fileSize = aFileStatus.getFileSize();
-                    }
-                }
-            }
-
-            //Feel free to calc the exact max possible number of fonts a file
-            //could contain given its physical size. But this will clamp it to
-            //a sane starting point
-            //http://processingjs.nihongoresources.com/the_smallest_font/
-            //https://github.com/grzegorzrolek/null-ttf
-            const int nMaxFontsPossible = fileSize / 528;
-            if (nLength > nMaxFontsPossible)
-                nLength = nMaxFontsPossible;
-
             for( int i = 0; i < nLength; i++ )
             {
                 PrintFont aFont;
@@ -420,12 +405,14 @@ OUString PrintFontManager::convertSfntName( const NameRecord& rNameRecord )
                 eEncoding = RTL_TEXTENCODING_UTF8;
                 break;
             default:
-                if (o3tl::starts_with(aName, "Khmer OS") ||
-                    o3tl::starts_with(aName, "YoavKtav Black")) // tdf#152278
+                if (o3tl::starts_with(aName, "Khmer OS") || // encoding '20' (Khmer) isn't implemented
+                    o3tl::starts_with(aName, "YoavKtav")) // tdf#152278
                 {
                     eEncoding = RTL_TEXTENCODING_UTF8;
                 }
-                SAL_WARN_IF(eEncoding == RTL_TEXTENCODING_DONTKNOW, "vcl.fonts", "Unimplemented mac encoding " << rNameRecord.encodingID << " to unicode conversion for fontname " << aName);
+                SAL_WARN_IF(eEncoding == RTL_TEXTENCODING_DONTKNOW, "vcl.fonts", "mac encoding " <<
+                            rNameRecord.encodingID << " in font '" << aName << "'" <<
+                            (rNameRecord.encodingID > 32 ? " is invalid" : " has unimplemented conversion"));
                 break;
         }
         if (eEncoding != RTL_TEXTENCODING_DONTKNOW)
