@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <utility>
 #include <xmloff/xmlerror.hxx>
 #include <rtl/ustring.hxx>
 #include <sal/log.hxx>
@@ -44,11 +45,11 @@ public:
 
     ErrorRecord( sal_Int32 nId,
                  const Sequence<OUString>& rParams,
-                 const OUString& rExceptionMessage,
+                 OUString aExceptionMessage,
                  sal_Int32 nRow,
                  sal_Int32 nColumn,
-                 const OUString& rPublicId,
-                 const OUString& rSystemId);
+                 OUString aPublicId,
+                 OUString aSystemId);
 
     sal_Int32 nId;  /// error ID
 
@@ -66,14 +67,14 @@ public:
 
 
 ErrorRecord::ErrorRecord( sal_Int32 nID, const Sequence<OUString>& rParams,
-    const OUString& rExceptionMessage, sal_Int32 nRowNumber, sal_Int32 nCol,
-    const OUString& rPublicId, const OUString& rSystemId) :
+    OUString aExceptionMessage, sal_Int32 nRowNumber, sal_Int32 nCol,
+    OUString aPublicId, OUString aSystemId) :
         nId(nID),
-        sExceptionMessage(rExceptionMessage),
+        sExceptionMessage(std::move(aExceptionMessage)),
         nRow(nRowNumber),
         nColumn(nCol),
-        sPublicId(rPublicId),
-        sSystemId(rSystemId),
+        sPublicId(std::move(aPublicId)),
+        sSystemId(std::move(aSystemId)),
         aParams(rParams)
 {
 }
@@ -95,21 +96,20 @@ void XMLErrors::AddRecord(
     const OUString& rPublicId,
     const OUString& rSystemId )
 {
-    aErrors.emplace_back( nId, rParams, rExceptionMessage,
+    m_aErrors.emplace_back( nId, rParams, rExceptionMessage,
                                     nRow, nColumn, rPublicId, rSystemId );
 
 #ifdef DBG_UTIL
 
     // give detailed assertion on this message
 
-    OUStringBuffer sMessage;
-
-    sMessage.append( "An error or a warning has occurred during XML import/export!\n" );
+    OUStringBuffer sMessage( "An error or a warning has occurred during XML import/export!\n" );
 
     // ID & flags
-    sMessage.append( "Error-Id: 0x");
-    sMessage.append( nId, 16 );
-    sMessage.append( "\n    Flags: " );
+    sMessage.append(
+        "Error-Id: 0x"
+        + OUString::number( nId, 16 )
+        + "\n    Flags: " );
     sal_Int32 nFlags = (nId & XMLERROR_MASK_FLAG);
     sMessage.append( nFlags >> 28, 16 );
     if( (nFlags & XMLERROR_FLAG_WARNING) != 0 )
@@ -131,8 +131,8 @@ void XMLErrors::AddRecord(
         sMessage.append( " OTHER" );
     sMessage.append( "\n    Number: " );
     sal_Int32 nNumber = (nId & XMLERROR_MASK_NUMBER);
-    sMessage.append( nNumber, 16 );
-    sMessage.append( "\n");
+    sMessage.append( OUString::number(nNumber, 16)
+        + "\n" );
 
     // the parameters
     sMessage.append( "Parameters:\n" );
@@ -140,30 +140,24 @@ void XMLErrors::AddRecord(
     const OUString* pParams = rParams.getConstArray();
     for( sal_Int32 i = 0; i < nLength; i++ )
     {
-        sMessage.append( "    " );
-        sMessage.append( i );
-        sMessage.append( ": " );
-        sMessage.append( pParams[i] );
-        sMessage.append( "\n" );
+        sMessage.append( "    " + OUString::number(i) + ": " + pParams[i] + "\n" );
     }
 
     // the exception message
-    sMessage.append( "Exception-Message: " );
-    sMessage.append( rExceptionMessage );
-    sMessage.append( "\n" );
+    sMessage.append( "Exception-Message: " + rExceptionMessage + "\n" );
 
     // position (if given)
     if( (nRow != -1) || (nColumn != -1) )
     {
-        sMessage.append( "Position:\n    Public Identifier: " );
-        sMessage.append( rPublicId );
-        sMessage.append( "\n    System Identifier: " );
-        sMessage.append( rSystemId );
-        sMessage.append( "\n    Row, Column: " );
-        sMessage.append( nRow );
-        sMessage.append( "," );
-        sMessage.append( nColumn );
-        sMessage.append( "\n" );
+        sMessage.append( "Position:\n    Public Identifier: "
+            + rPublicId
+            + "\n    System Identifier: "
+            + rSystemId
+            + "\n    Row, Column: "
+            + OUString::number( nRow )
+            + ","
+            + OUString::number( nColumn )
+            + "\n" );
     }
 
     SAL_WARN( "xmloff", sMessage.makeStringAndClear() );
@@ -192,12 +186,12 @@ void XMLErrors::AddRecord(
 void XMLErrors::ThrowErrorAsSAXException(sal_Int32 nIdMask)
 {
     // search first error/warning that matches the nIdMask
-    for( const auto& rError : aErrors )
+    for( const auto& rError : m_aErrors )
     {
         if ( (rError.nId & nIdMask) != 0 )
         {
             // we throw the error
-            ErrorRecord& rErr = aErrors[0];
+            ErrorRecord& rErr = m_aErrors[0];
             throw SAXParseException(
                 rErr.sExceptionMessage, nullptr, Any(rErr.aParams),
                 rErr.sPublicId, rErr.sSystemId, rErr.nRow, rErr.nColumn );
