@@ -84,7 +84,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > XMLShapePropertySetCon
         return new XMLTextColumnsContext(GetImport(), nElement, xAttrList, rProp, rProperties);
 
     case CTF_COMPLEX_COLOR:
-        return new XMLComplexColorContext(GetImport(), nElement, xAttrList, rProp, rProperties);
+        return new XMLPropertyComplexColorContext(GetImport(), nElement, xAttrList, rProp, rProperties);
     }
 
     return SvXMLPropertySetContext::createFastChildContext( nElement,
