@@ -22,6 +22,7 @@
 #include <sal/log.hxx>
 #include <comphelper/diagnose_ex.hxx>
 #include <comphelper/base64.hxx>
+#include <comphelper/mediamimetype.hxx>
 #include <com/sun/star/frame/XModel.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
 #include <com/sun/star/text/TextContentAnchorType.hpp>
@@ -55,7 +56,6 @@
 #include <xmloff/XMLEventsImportContext.hxx>
 #include <XMLImageMapContext.hxx>
 #include "XMLTextFrameContext.hxx"
-#include <xmloff/attrlist.hxx>
 #include <basegfx/polygon/b2dpolygon.hxx>
 #include <basegfx/polygon/b2dpolygontools.hxx>
 #include <basegfx/polygon/b2dpolypolygon.hxx>
@@ -371,6 +371,7 @@ class XMLTextFrameContext_Impl : public SvXMLImportContext
     bool    bOwnBase64Stream : 1;
     bool    mbMultipleContent : 1; // This context is created based on a multiple content (image)
     bool    m_isDecorative = false;
+    bool    m_isSplitAllowed = false;
 
     void Create();
 
@@ -688,6 +689,11 @@ void XMLTextFrameContext_Impl::Create()
         xPropSet->setPropertyValue("Decorative", uno::Any(true));
     }
 
+    if (m_isSplitAllowed && xPropSetInfo->hasPropertyByName("IsSplitAllowed"))
+    {
+        xPropSet->setPropertyValue("IsSplitAllowed", uno::Any(true));
+    }
+
     if( XML_TEXT_FRAME_OBJECT != nType  &&
         XML_TEXT_FRAME_OBJECT_OLE != nType  &&
         XML_TEXT_FRAME_APPLET != nType &&
@@ -1074,6 +1080,10 @@ XMLTextFrameContext_Impl::XMLTextFrameContext_Impl(
         case XML_ELEMENT(DRAW, XML_DECORATIVE):
             ::sax::Converter::convertBool(m_isDecorative, aIter.toString());
             break;
+        case XML_ELEMENT(LO_EXT, XML_MAY_BREAK_BETWEEN_PAGES):
+        case XML_ELEMENT(DRAW, XML_MAY_BREAK_BETWEEN_PAGES):
+            sax::Converter::convertBool(m_isSplitAllowed, aIter.toString());
+            break;
         default:
             SAL_INFO("xmloff", "unknown attribute " << SvXMLImport::getPrefixAndNameFromToken(aIter.getToken()) << " value=" << aIter.toString());
         }
@@ -1484,7 +1494,7 @@ css::uno::Reference< css::xml::sax::XFastContextHandler > XMLTextFrameContext::c
                     {
                         if( aIter.getToken() == XML_ELEMENT(DRAW, XML_MIME_TYPE) )
                         {
-                            if( aIter.toView() == "application/vnd.sun.star.media" )
+                            if (::comphelper::IsMediaMimeType(aIter.toView()))
                                 bMedia = true;
 
                             // leave this loop
