@@ -36,10 +36,11 @@
 #include <com/sun/star/ui/dialogs/FolderPicker.hpp>
 #include <com/sun/star/ui/dialogs/ExecutableDialogResults.hpp>
 #include <sfx2/filedlghelper.hxx>
-#include <tools/diagnose_ex.h>
+#include <comphelper/diagnose_ex.hxx>
 #include <tools/urlobj.hxx>
 #include <unotools/datetime.hxx>
 
+#include <utility>
 #include <vcl/svapp.hxx>
 
 using namespace comphelper;
@@ -54,9 +55,9 @@ IMPL_LINK_NOARG(MacroSecurity, OkBtnHdl, weld::Button&, void)
 }
 
 MacroSecurity::MacroSecurity(weld::Window* pParent,
-    const css::uno::Reference<css::xml::crypto::XSecurityEnvironment>& rxSecurityEnvironment)
+    css::uno::Reference<css::xml::crypto::XSecurityEnvironment> xSecurityEnvironment)
     : GenericDialogController(pParent, "xmlsec/ui/macrosecuritydialog.ui", "MacroSecurityDialog")
-    , m_xSecurityEnvironment(rxSecurityEnvironment)
+    , m_xSecurityEnvironment(std::move(xSecurityEnvironment))
     , m_xTabCtrl(m_xBuilder->weld_notebook("tabcontrol"))
     , m_xOkBtn(m_xBuilder->weld_button("ok"))
     , m_xResetBtn(m_xBuilder->weld_button("reset"))
@@ -70,7 +71,7 @@ MacroSecurity::MacroSecurity(weld::Window* pParent,
     m_xOkBtn->connect_clicked(LINK(this, MacroSecurity, OkBtnHdl));
 }
 
-IMPL_LINK(MacroSecurity, ActivatePageHdl, const OString&, rPage, void)
+IMPL_LINK(MacroSecurity, ActivatePageHdl, const OUString&, rPage, void)
 {
     if (rPage == "SecurityLevelPage")
         m_xLevelTP->ActivatePage();
@@ -79,7 +80,7 @@ IMPL_LINK(MacroSecurity, ActivatePageHdl, const OString&, rPage, void)
 }
 
 MacroSecurityTP::MacroSecurityTP(weld::Container* pParent, const OUString& rUIXMLDescription,
-                                 const OString& rID, MacroSecurity* pDlg)
+                                 const OUString& rID, MacroSecurity* pDlg)
     : m_xBuilder(Application::CreateBuilder(pParent, rUIXMLDescription))
     , m_xContainer(m_xBuilder->weld_container(rID))
     , m_pDlg(pDlg)
